#-- encoding: UTF-8
require 'spec_helper'

RSpec.describe "Nomener::Titles" do
  it "has the constant regex TITLES" do
    expect(Nomener::Titles::TITLES).to be_a_kind_of(Regexp)
  end

  context "in the names" do
    [
      { name: "خانم Augusta Ada King", result: "خانم" },
      { name: "רעב Bertrand Russell", result: "רעב" },
      { skip: "Something is typed, or we clean it, improperly",
        name: "'ר Bertrand Russell", result: "'ר" },
      { name: "አቶ Bertrand Russell", result: "አቶ" },
      { name: "Adi Augusta Ada King", result: "Adi" },
      { name: "Air Commander Bertrand Russell", result: "Air Commander" },
      { name: "Air Commodore Bertrand Russell", result: "Air Commodore" },
      { name: "Air Marshall Bertrand Russell", result: "Air Marshall" },
      { name: "Ald. Bertrand Russell", result: "Ald" },
      { name: "Alderman Bertrand Russell", result: "Alderman" },
      { name: "Archduke Bertrand Russell", result: "Archduke" },
      { name: "Duke Bertrand Russell", result: "Duke" },
      { name: "Archduchess Augusta Ada King", result: "Archduchess" },
      { name: "Duchess Augusta Ada King", result: "Duchess" },
      { name: "Ato Bertrand Russell", result: "Ato" },
      { name: "Baron Bertrand Russell", result: "Baron" },
      { name: "Baroness Augusta Ada King", result: "Baroness" },
      { name: "Bishop Bertrand Russell", result: "Bishop" },
      { name: "Brig Bertrand Russell", result: "Brig" },
      { name: "Brig. Bertrand Russell", result: "Brig" },
      { name: "Brigadier Bertrand Russell", result: "Brigadier" },
      { name: "Brother Bertrand Russell", result: "Brother" },
      { name: "Bulou Augusta Ada King", result: "Bulou" },
      { name: "Capt Bertrand Russell", result: "Capt" },
      { name: "Capt. Bertrand Russell", result: "Capt" },
      { name: "Captain Bertrand Russell", result: "Captain" },
      { name: "Cdr Bertrand Russell", result: "Cdr" },
      { name: "Cdr. Bertrand Russell", result: "Cdr" },
      { name: "Chaplain Bertrand Russell", result: "Chaplain" },
      { name: "Colonel Bertrand Russell", result: "Colonel" },
      { name: "Commander Bertrand Russell", result: "Commander" },
      { name: "Commodore Bertrand Russell", result: "Commodore" },
      { name: "Count Bertrand Russell", result: "Count" },
      { name: "Countess Augusta Ada King", result: "Countess" },
      { name: "Dame Augusta Ada King", result: "Dame" },
      { name: "Det Bertrand Russell", result: "Det" },
      { name: "Det. Bertrand Russell", result: "Det" },
      { name: "Dhr Bertrand Russell", result: "Dhr" },
      { name: "Dhr. Bertrand Russell", result: "Dhr" },
      { name: "Doctor Bertrand Russell", result: "Doctor" },
      { name: "Dr Bertrand Russell", result: "Dr" },
      { name: "Dr. Bertrand Russell", result: "Dr" },
      { name: "Dom Bertrand Russell", result: "Dom" },
#      { name: "Don Bertrand Russell", result: "Don" },
#      { name: "Dona Augusta Ada King", result: "Dona" },
      { name: "Erzherzog Bertrand Russell", result: "Erzherzog" },
      { name: "Erzherzogin Augusta Ada King", result: "Erzherzogin" },
      { name: "Father Bertrand Russell", result: "Father" },
      { name: "Field Marshall Bertrand Russell", result: "Field Marshall" },
      { name: "Fl Lt Bertrand Russell", result: "Fl Lt" },
      { name: "Fl. Lt. Bertrand Russell", result: "Fl Lt" },
      { name: "Flt Lt Bertrand Russell", result: "Flt Lt" },
      { name: "Flt. Lt. Bertrand Russell", result: "Flt Lt" },
      { name: "Fl Off Bertrand Russell", result: "Fl Off" },
      { name: "Fl. Off. Bertrand Russell", result: "Fl Off" },
      { name: "Flt Off Bertrand Russell", result: "Flt Off" },
      { name: "Flt. Off. Bertrand Russell", result: "Flt Off" },
      { name: "Flight Officer Bertrand Russell", result: "Flight Officer" },
      { name: "Flight Lieutenant Bertrand Russell", result: "Flight Lieutenant" },
      { name: "Frau Augusta Ada King", result: "Frau" },
      { name: "Fr Augusta Ada King", result: "Fr" },
      { name: "Fr. Augusta Ada King", result: "Fr" },
      { name: "Gen. Bertrand Russell", result: "Gen" },
      { name: "General Bertrand Russell", result: "General" },
      { name: "Herra Bertrand Russell", result: "Herra" },
      { name: "Härra Bertrand Russell", result: "Härra" },
      { name: "Herr Bertrand Russell", result: "Herr" },
      { name: "Hra Bertrand Russell", result: "Hra" },
      { name: "Hra. Bertrand Russell", result: "Hra" },
      { name: "Hr Bertrand Russell", result: "Hr" },
      { name: "Hr. Bertrand Russell", result: "Hr" },
      { name: "Rt Hon Bertrand Russell", result: "Rt Hon" },
      { name: "Rt. Hon. Bertrand Russell", result: "Rt Hon" },
      { name: "Hon Bertrand Russell", result: "Hon" },
      { name: "Hon. Bertrand Russell", result: "Hon" },
      { name: "Right Honourable Bertrand Russell", result: "Right Honourable" },
      { name: "Honourable Bertrand Russell", result: "Honourable" },
      { name: "Insp Bertrand Russell", result: "Insp" },
      { name: "Insp. Bertrand Russell", result: "Insp" },
      { name: "Inspector Bertrand Russell", result: "Inspector" },
      { name: "Judge Bertrand Russell", result: "Judge" },
      { name: "Justice Bertrand Russell", result: "Justice" },
      { name: "Khaanom Augusta Ada King", result: "Khaanom" },
      { name: "Lady Augusta Ada King", result: "Lady" },
      { name: "Lieutenant Bertrand Russell", result: "Lieutenant" },
      { name: "Lieutenant Commander Bertrand Russell", result: "Lieutenant Commander" },
      { name: "Lieutenant Colonel Bertrand Russell", result: "Lieutenant Colonel" },
      { name: "Lieutenant General Bertrand Russell", result: "Lieutenant General" },
      { name: "Lt Col Bertrand Russell", result: "Lt Col" },
      { name: "Lt. Col. Bertrand Russell", result: "Lt Col" },
      { name: "Lt Cdr Bertrand Russell", result: "Lt Cdr" },
      { name: "Lt. Cdr. Bertrand Russell", result: "Lt Cdr" },
      { name: "Lt Col Bertrand Russell", result: "Lt Col" },
      { name: "Lt. Col. Bertrand Russell", result: "Lt Col" },
      { name: "Lt Gen Bertrand Russell", result: "Lt Gen" },
      { name: "Lt. Gen. Bertrand Russell", result: "Lt Gen" },
      { name: "Lt Bertrand Russell", result: "Lt" },
      { name: "Lt. Bertrand Russell", result: "Lt" },
      { name: "Leut Bertrand Russell", result: "Leut" },
      { name: "Leut. Bertrand Russell", result: "Leut" },
      { name: "Lieut Bertrand Russell", result: "Lieut" },
      { name: "Lieut. Bertrand Russell", result: "Lieut" },
      { name: "Lord Bertrand Russell", result: "Lord" },
      { name: "Madam Augusta Ada King", result: "Madam" },
      { name: "Madame Augusta Ada King", result: "Madame" },
      { name: "Mademoiselle Augusta Ada King", result: "Mademoiselle" },
      { name: "Maid Augusta Ada King", result: "Maid" },
      { name: "Maître Bertrand Russell", result: "Maître" },
      { name: "Major Bertrand Russell", result: "Major" },
      { name: "Major General Bertrand Russell", result: "Major General" },
      { name: "Maj Bertrand Russell", result: "Maj" },
      { name: "Maj. Bertrand Russell", result: "Maj" },
      { name: "Maj Gen Bertrand Russell", result: "Maj Gen" },
      { name: "Maj. Gen. Bertrand Russell", result: "Maj Gen" },
      { name: "Mast Bertrand Russell", result: "Mast" },
      { name: "Mast. Bertrand Russell", result: "Mast" },
      { name: "Master Bertrand Russell", result: "Master" },
      { name: "Master Sergeant Bertrand Russell", result: "Master Sergeant" },
      { name: "Matron Augusta Ada King", result: "Matron" },
      { name: "Menina Augusta Ada King", result: "Menina" },
      { name: "Messrs Bertrand Russell", result: "Messrs" },
      { name: "Meneer Bertrand Russell", result: "Meneer" },
      { name: "Mlle Augusta Ada King", result: "Mlle" },
      { name: "Miss Augusta Ada King", result: "Miss" },
      { name: "Miss. Augusta Ada King", result: "Miss" },
      { name: "Mister Bertrand Russell", result: "Mister" },
      { name: "Mne Bertrand Russell", result: "Mne" },
      { name: "Mne. Bertrand Russell", result: "Mne" },
      { name: "Mme. Augusta Ada King", result: "Mme" },
      { name: "Mnr Bertrand Russell", result: "Mnr" },
      { name: "Mnr. Bertrand Russell", result: "Mnr" },
      { name: "Mons Bertrand Russell", result: "Mons" },
      { name: "Mons. Bertrand Russell", result: "Mons" },
      { name: "Monsignor Bertrand Russell", result: "Monsignor" },
      { name: "Monsieur Bertrand Russell", result: "Monsieur" },
      { name: "Most Reverend Bertrand Russell", result: "Most Reverend" },
      { name: "Most Reverand Bertrand Russell", result: "Most Reverand" },
      { name: "Mother Augusta Ada King", result: "Mother" },
      { name: "Mother Superior Augusta Ada King", result: "Mother Superior" },
      { name: "Mr Bertrand Russell", result: "Mr" },
      { name: "Mr. Bertrand Russell", result: "Mr" },
      { name: "Mrs Augusta Ada King", result: "Mrs" },
      { name: "Mrs. Augusta Ada King", result: "Mrs" },
      { name: "Msgr. Bertrand Russell", result: "Msgr" },
      { name: "Ms Augusta Ada King", result: "Ms" },
      { name: "Ms. Augusta Ada King", result: "Ms" },
      { name: "MSgt Bertrand Russell", result: "MSgt" },
      { name: "MSgt. Bertrand Russell", result: "MSgt" },
      { name: "Mt Rev Bertrand Russell", result: "Mt Rev" },
      { name: "Mt. Rev. Bertrand Russell", result: "Mt Rev" },
      { name: "Mt Revd Bertrand Russell", result: "Mt Revd" },
      { name: "Mt. Revd. Bertrand Russell", result: "Mt Revd" },
      { name: "Mx Bertrand Russell", result: "Mx" },
      { name: "Mx. Bertrand Russell", result: "Mx" },
      { name: "ông Bertrand Russell", result: "ông" },
      { name: "Pastor Bertrand Russell", result: "Pastor" },
      { name: "Private Bertrand Russell", result: "Private" },
      { name: "Prof Bertrand Russell", result: "Prof" },
      { name: "Prof. Bertrand Russell", result: "Prof" },
      { name: "Professor Bertrand Russell", result: "Professor" },
      { name: "Professeur Bertrand Russell", result: "Professeur" },
      { name: "Pte Bertrand Russell", result: "Pte" },
      { name: "Pte. Bertrand Russell", result: "Pte" },
      { name: "Pvt Bertrand Russell", result: "Pvt" },
      { name: "Pvt. Bertrand Russell", result: "Pvt" },
      { name: "PFC Bertrand Russell", result: "PFC" },
      { name: "Rabbi Bertrand Russell", result: "Rabbi" },
      { name: "Ratu Bertrand Russell", result: "Ratu" },
      { name: "Reb Bertrand Russell", result: "Reb" },
      { name: "Reb. Bertrand Russell", result: "Reb" },
      { name: "Rev Bertrand Russell", result: "Rev" },
      { name: "Revd Bertrand Russell", result: "Revd" },
      { name: "Reverand Bertrand Russell", result: "Reverand" },
      { name: "Reverend Bertrand Russell", result: "Reverend" },
      { name: "Ro Bertrand Russell", result: "Ro" },
      { name: "Roko Bertrand Russell", result: "Roko" },
      { name: "Senora Augusta Ada King", result: "Senora" },
      { name: "Señora Augusta Ada King", result: "Señora" },
      { name: "Senhora Augusta Ada King", result: "Senhora" },
      { name: "Senor Bertrand Russell", result: "Senor" },
      { name: "Señor Bertrand Russell", result: "Señor" },
      { name: "Senhor Bertrand Russell", result: "Senhor" },
      { name: "Senyor Bertrand Russell", result: "Senyor" },
      { name: "Sénher Bertrand Russell", result: "Sénher" },
      { name: "Senor Dom Bertrand Russell", result: "Senor Dom" },
      { name: "Senorita Augusta Ada King", result: "Senorita" },
      { name: "Señorita Augusta Ada King", result: "Señorita" },
      { name: "Senhorita Augusta Ada King", result: "Senhorita" },
      { name: "Seigneur Bertrand Russell", result: "Seigneur" },
      { name: "Signore Bertrand Russell", result: "Signore" },
      { name: "Signora Augusta Ada King", result: "Signora" },
      { name: "Sig Bertrand Russell", result: "Sig" },
      { name: "Sig. Bertrand Russell", result: "Sig" },
      { name: "Siga Bertrand Russell", result: "Siga" },
      { name: "Siga. Bertrand Russell", result: "Siga" },
      { name: "Sigra Bertrand Russell", result: "Sigra" },
      { name: "Sigra. Bertrand Russell", result: "Sigra" },
      { name: "Sioro Bertrand Russell", result: "Sioro" },
      { name: "Sro Bertrand Russell", result: "Sro" },
      { name: "Sro. Bertrand Russell", result: "Sro" },
      { name: "Sgt Bertrand Russell", result: "Sgt" },
      { name: "Sgt. Bertrand Russell", result: "Sgt" },
      { name: "Sergeant Bertrand Russell", result: "Sergeant" },
      { name: "SSgt Bertrand Russell", result: "SSgt" },
      { name: "SSgt. Bertrand Russell", result: "SSgt" },
      { name: "Sir Bertrand Russell", result: "Sir" },
      { name: "Sister Augusta Ada King", result: "Sister" },
      { name: "Sr Bertrand Russell", result: "Sr" },
      { name: "Sr. Bertrand Russell", result: "Sr" },
      { name: "Sra Augusta Ada King", result: "Sra" },
      { name: "Sra. Augusta Ada King", result: "Sra" },
      { name: "Srta Augusta Ada King", result: "Srta" },
      { name: "Srta. Augusta Ada King", result: "Srta" },
      { name: "Staff Sergeant Bertrand Russell", result: "Staff Sergeant" },
      { name: "Technical Sergeant Bertrand Russell", result: "Technical Sergeant" },
      { name: "TSgt Bertrand Russell", result: "TSgt" },
      { name: "TSgt. Bertrand Russell", result: "TSgt" },
      { name: "V Revd Bertrand Russell", result: "V Revd" },
      { name: "V. Revd. Bertrand Russell", result: "V Revd" },
      { name: "Very Reverend Bertrand Russell", result: "Very Reverend" },
      { name: "Very Reverand Bertrand Russell", result: "Very Reverand" },
    ].each do |name|
      it "parses #{name[:result]} from #{name[:name]}" do
        skip name[:skip] if name.has_key?(:skip)
        parsed = Nomener::Titles.parse_title!(name[:name])
        expect(parsed).to eq name[:result]
      end
    end
  end
end