#-- encoding: UTF-8
require 'spec_helper'
# lots of names from wikiquote http://simple.wikiquote.org/wiki/List_of_people_by_name
# minimal changes
# names are approximately in the form of last, first
# removed mononyms

# to add, in some manner.... we should be able to parse each name on this page
# names like 'Deng Xiaoping' will give problems as they are the normal Chinese order, but we can't tell if they are Chinese
#
#      Acton, John (Lord Acton)
#      Anne, Princess Royal of the United Kingdom
#      Akinola, Peter Jasper (Archbishop)
#      Baden-Powell, Sir Robert (B-P)
#      Banks, Tony (Lord Stratford)
#      Beaumont and Fletcher
#      Benedict XVI (Pope)
#      Bojaxhi, Agnes Gonxha (Mother Teresa)
#      Butler, Samuel (1835-1902)
#      Butler, Samuel (1612-1680)
#
#
#      Cecil, Robert (1st Viscount Cecil of Chelwood)
#      Chaplin, Charlie (Sir Charles Spencer Chaplin)
#      Chuang Chou (Chuang Tzu; Chuang Tse; Zhuang Zi)
#      Churchill, Sarah (Duchess of Marlborough)
#      Cooper, Diana (Lady Diana Manners)
#      Courtney, Leonard H. (Lord Courtney)
#      Dalai Lama; see Tenzin Gyatso (His Holiness the 14th Dalai Lama)
#      Deng Xiaoping
#      Hossein Elahi Ghomshei
#      Elizabeth I of England
#      Elizabeth II of England
#      Francis of Assisi
#      Frederick II of Prussia
#      Gallagher (Leo Anthony Gallagher)
#      Gwanghae-gun of Joseon
#      Han Shan
#      Hall, Evelyn Beatrice (also known by pseudonym "Stephen G. Tallentyre")
#      Henry VIII
#      Hillel the Elder
#      Hubbard, Kin (Frank McKinney Hubbard)
#      James I of England
#      Joan of Arc
#      John of the Cross
#      John Paul II (Pope)
#      Julian (Emperor)
#      Julian of Norwich
#      Kennedy Lisa
#      Lao Tzu
#      Leo X (Pope)
#      Li Bai
#      Lu Xun
#      Maharaji (Prem Rawat)
#      Mao Zedong
#      Mary I of England
#      Michelangelo Buonarroti
#      Mother Teresa (Agnes Gonxha Bojaxhi)
#      Munshi Premchand
#      Miyamoto Musashi
#      Nero (Emperor)
#      Czar Nicholas II
#      Osama bin Laden
#      Osho (also known as Bhagwan Shree Rajneesh)
#      Paul VI (Pope)
#      Peter Kay
#      Pompey the Great
#      Pushkin, Aleksandr (Alexander Pushkin)
#      Qin Shi Huang
#      Sathya Sai Baba
#      Savitri Devi
#      Simonides of Ceos
#      Sixtus V (pope)
#      Scanderbeg|Skenderbeu(The prince of Arberia)
#      Snoop Dogg (Calvin Cordozar Broadus)
#      Soong May-ling
#      Sun Tzu
#      Tenzin Gyatso (14th Dalai Lama)
#      Teresa of Avila (Teresa de Jesús)
#      Thomas Aquinas
#      Tweed, William Marcy ("Boss")
#      Tzu Hsi
#      Jarmo Visakorpi
#      William of Occam
#      X, Malcolm (Malcolm Little)
#      Yankovic, "Weird Al"
#      Zé Tom
#

RSpec.describe "WikiQuote list parsing" do
  context "with the name" do
    [
      { from: "Aaron, Hank", to: { full: "Hank Aaron", first: "Hank", last: "Aaron"} },
      { from: "Abagnale, Frank", to: { full: "Frank Abagnale", first: "Frank", last: "Abagnale"} },
      { from: "Abbey, Edward", to: { full: "Edward Abbey", first: "Edward", last: "Abbey"} },
      { from: "Abel, Reuben", to: { full: "Reuben Abel", first: "Reuben", last: "Abel"} },
      { from: "Abelson, Hal", to: { full: "Hal Abelson", first: "Hal", last: "Abelson"} },
      { from: "Abourezk, James", to: { full: "James Abourezk", first: "James", last: "Abourezk"} },
      { from: "Abrams, Creighton", to: { full: "Creighton Abrams", first: "Creighton", last: "Abrams"} },
      { from: "Ace, Jane", to: { full: "Jane Ace", first: "Jane", last: "Ace"} },
      { from: "Adams, Abigail", to: { full: "Abigail Adams", first: "Abigail", last: "Adams"} },
      { from: "Adams, Douglas", to: { full: "Douglas Adams", first: "Douglas", last: "Adams"} },
      { from: "Adams, Henry", to: { full: "Henry Adams", first: "Henry", last: "Adams"} },
      { from: "Adams, John", to: { full: "John Adams", first: "John", last: "Adams"} },
      { from: "Adams, John Quincy", to: { full: "John Quincy Adams", first: "John Quincy", last: "Adams"} },
      { from: "Adams, Samuel", to: { full: "Samuel Adams", first: "Samuel", last: "Adams"} },
      { from: "Adams, Scott", to: { full: "Scott Adams", first: "Scott", last: "Adams"} },
      { from: "Addams, Jane", to: { full: "Jane Addams", first: "Jane", last: "Addams"} },
      { from: "Addison, Joseph", to: { full: "Joseph Addison", first: "Joseph", last: "Addison"} },
      { from: "Adorno, Theodor", to: { full: "Theodor Adorno", first: "Theodor", last: "Adorno"} },
      { from: "Adler, Alfred", to: { full: "Alfred Adler", first: "Alfred", last: "Adler"} },
      { from: "Affleck, Ben", to: { full: "Ben Affleck", first: "Ben", last: "Affleck"} },
      { from: "Agena, Keiko", to: { full: "Keiko Agena", first: "Keiko", last: "Agena"} },
      { from: "Agnew, Spiro", to: { full: "Spiro Agnew", first: "Spiro", last: "Agnew"} },
      { from: "Ahbez, Eden", to: { full: "Eden Ahbez", first: "Eden", last: "Ahbez"} },
      { from: "Ahern, Bertie", to: { full: "Bertie Ahern", first: "Bertie", last: "Ahern"} },
      { from: "Ah Koy, James", to: { full: "James Ah Koy", first: "James", last: "Ah Koy"} },
      { from: "Aiken, Clay", to: { full: "Clay Aiken", first: "Clay", last: "Aiken"} },
      { from: "Aiken, Conrad", to: { full: "Conrad Aiken", first: "Conrad", last: "Aiken"} },
      { from: "Alba, Jessica", to: { full: "Jessica Alba", first: "Jessica", last: "Alba"} },
      { from: "Alberti, Leone Battista", to: { full: "Leone Battista Alberti", first: "Leone Battista", last: "Alberti"} },
      { from: "Albom, Mitch", to: { full: "Mitch Albom", first: "Mitch", last: "Albom"} },
      { from: "Alcott, Louisa May", to: { full: "Louisa May Alcott", first: "Louisa May", last: "Alcott"} },
      { from: "Aldiss, Brian", to: { full: "Brian Aldiss", first: "Brian", last: "Aldiss"} },
      { from: "Alexie, Sherman", to: { full: "Sherman Alexie", first: "Sherman", last: "Alexie"} },
      { from: "al-Sadr, Muqtada", to: { full: "Muqtada al-Sadr", first: "Muqtada", last: "al-Sadr"} },
      { from: "al-Sahaf, Muhammed Saeed", to: { full: "Muhammed Saeed al-Sahaf", first: "Muhammed Saeed", last: "al-Sahaf"} },
      { from: "Alfven, Hannes", to: { full: "Hannes Alfven", first: "Hannes", last: "Alfven"} },
      { from: "Aldrin, Buzz", to: { full: "Buzz Aldrin", first: "Buzz", last: "Aldrin"} },
      { from: "Ali, Muhammad", to: { full: "Muhammad Ali", first: "Muhammad", last: "Ali"} },
      { from: "Ali, Tariq", to: { full: "Tariq Ali", first: "Tariq", last: "Ali"} },
      { from: "Allee, W. C.", to: { full: "W C Allee", first: "W C", last: "Allee"} },
      { from: "Allen, Agnes", to: { full: "Agnes Allen", first: "Agnes", last: "Allen"} },
      { from: "Allen, Fred", to: { full: "Fred Allen", first: "Fred", last: "Allen"} },
      { from: "Allen, James", to: { full: "James Allen", first: "James", last: "Allen"} },
      { from: "Allen, Steve", to: { full: "Steve Allen", first: "Steve", last: "Allen"} },
      { from: "Allen, Woody", to: { full: "Woody Allen", first: "Woody", last: "Allen"} },
      { from: "Allais, Alphonse", to: { full: "Alphonse Allais", first: "Alphonse", last: "Allais"} },
      { from: "Allston, Aaron", to: { full: "Aaron Allston", first: "Aaron", last: "Allston"} },
      { from: "Amaro, Rolim", to: { full: "Rolim Amaro", first: "Rolim", last: "Amaro"} },
      { from: "Amiel, Barbara", to: { full: "Barbara Amiel", first: "Barbara", last: "Amiel"} },
      { from: "Amis, Martin", to: { full: "Martin Amis", first: "Martin", last: "Amis"} },
      { from: "Amos, Tori", to: { full: "Tori Amos", first: "Tori", last: "Amos"} },
      { from: "Andersen, Hans Christian", to: { full: "Hans Christian Andersen", first: "Hans Christian", last: "Andersen"} },
      { from: "Anderson, Beth", to: { full: "Beth Anderson", first: "Beth", last: "Anderson"} },
      { from: "Anderson, Sparky", to: { full: "Sparky Anderson", first: "Sparky", last: "Anderson"} },
      { from: "Andrians, Aiven", to: { full: "Aiven Andrians", first: "Aiven", last: "Andrians"} },
      { from: "Andric, Ivo", to: { full: "Ivo Andric", first: "Ivo", last: "Andric"} },
      { from: "Angell, Norman", to: { full: "Norman Angell", first: "Norman", last: "Angell"} },
      { from: "Angelou, Maya", to: { full: "Maya Angelou", first: "Maya", last: "Angelou"} },
      { from: "Anthony, Piers", to: { full: "Piers Anthony", first: "Piers", last: "Anthony"} },
      { from: "Anthony, Susan B.", to: { full: "Susan B Anthony", first: "Susan B", last: "Anthony"} },
      { from: "Antoniou, Laura", to: { full: "Laura Antoniou", first: "Laura", last: "Antoniou"} },
      { from: "Antunes, António Lobo", to: { full: "António Lobo Antunes", first: "António Lobo", last: "Antunes"} },
      { from: "Apple, Fiona", to: { full: "Fiona Apple", first: "Fiona", last: "Apple"} },
      { from: "Aquinas, Thomas", to: { full: "Thomas Aquinas", first: "Thomas", last: "Aquinas"} },
      { from: "Arafat, Yasser", to: { full: "Yasser Arafat", first: "Yasser", last: "Arafat"} },
      { from: "Araya, Tom", to: { full: "Tom Araya", first: "Tom", last: "Araya"} },
      { from: "Arbuthnot, John", to: { full: "John Arbuthnot", first: "John", last: "Arbuthnot"} },
      { from: "Armstrong, Edwin", to: { full: "Edwin Armstrong", first: "Edwin", last: "Armstrong"} },
      { from: "Armstrong, Louis", to: { full: "Louis Armstrong", first: "Louis", last: "Armstrong"} },
      { from: "Armstrong, Neil", to: { full: "Neil Armstrong", first: "Neil", last: "Armstrong"} },
      { from: "Arp, Hans", to: { full: "Hans Arp", first: "Hans", last: "Arp"} },
      { from: "Arslan, Alp", to: { full: "Alp Arslan", first: "Alp", last: "Arslan"} },
      { from: "Ascham, Roger", to: { full: "Roger Ascham", first: "Roger", last: "Ascham"} },
      { from: "Ashe, Arthur", to: { full: "Arthur Ashe", first: "Arthur", last: "Ashe"} },
      { from: "Ashlag, Baruch", to: { full: "Baruch Ashlag", first: "Baruch", last: "Ashlag"} },
      { from: "Ashlag, Yehuda", to: { full: "Yehuda Ashlag", first: "Yehuda", last: "Ashlag"} },
      { from: "Asimov, Isaac", to: { full: "Isaac Asimov", first: "Isaac", last: "Asimov"} },
      { from: "Attali, Jacques", to: { full: "Jacques Attali", first: "Jacques", last: "Attali"} },
      { from: "Atatürk, Mustafa Kemal", to: { full: "Mustafa Kemal Atatürk", first: "Mustafa Kemal", last: "Atatürk"} },
      { from: "Atwood, Margaret", to: { full: "Margaret Atwood", first: "Margaret", last: "Atwood"} },
      { from: "Auden, Wystan Hugh", to: { full: "Wystan Hugh Auden", first: "Wystan Hugh", last: "Auden"} },
      { from: "Audette, Derek R.", to: { full: "Derek R Audette", first: "Derek R", last: "Audette"} },
      { from: "Augustine, Norman Ralph", to: { full: "Norman Ralph Augustine", first: "Norman Ralph", last: "Augustine"} },
      { from: "Austen, Jane", to: { full: "Jane Austen", first: "Jane", last: "Austen"} },
      { from: "Austin, Alfred", to: { full: "Alfred Austin", first: "Alfred", last: "Austin"} },
      { from: "Austin, J. L.", to: { full: "J L Austin", first: "J L", last: "Austin"} },
      { from: "Austin, Stone Cold Steve", to: { full: "Stone Cold Steve Austin", first: "Stone Cold Steve", last: "Austin"} },

      { from: "Baba, Meher", to: { full: "Meher Baba", first: "Meher", last: "Baba"} },
      { from: "Baba, Tupeni", to: { full: "Tupeni Baba", first: "Tupeni", last: "Baba"} },
      { from: "Babbage, Charles", to: { full: "Charles Babbage", first: "Charles", last: "Babbage"} },
      { from: "Babbitt, Milton", to: { full: "Milton Babbitt", first: "Milton", last: "Babbitt"} },
      { from: "Bacevich, Andrew", to: { full: "Andrew Bacevich", first: "Andrew", last: "Bacevich"} },
      { from: "Bach, Richard", to: { full: "Richard Bach", first: "Richard", last: "Bach"} },
      { from: "Bachelard, Gaston", to: { full: "Gaston Bachelard", first: "Gaston", last: "Bachelard"} },
      { from: "Bachelot, Roselyne", to: { full: "Roselyne Bachelot", first: "Roselyne", last: "Bachelot"} },
      { from: "Bacon, Francis", to: { full: "Francis Bacon", first: "Francis", last: "Bacon"} },
      { from: "Baddiel, David", to: { full: "David Baddiel", first: "David", last: "Baddiel"} },
      { from: "Badiou, Alain", to: { full: "Alain Badiou", first: "Alain", last: "Badiou"} },
      { from: "Badnarik, Michael", to: { full: "Michael Badnarik", first: "Michael", last: "Badnarik"} },
      { from: "Baez, Joan", to: { full: "Joan Baez", first: "Joan", last: "Baez"} },
      { from: "Bagehot, Walter", to: { full: "Walter Bagehot", first: "Walter", last: "Bagehot"} },
      { from: "Bailey, Philip James", to: { full: "Philip James Bailey", first: "Philip James", last: "Bailey"} },
      { from: "Baillie, Bruce", to: { full: "Bruce Baillie", first: "Bruce", last: "Baillie"} },
      { from: "Bainimarama, Frank", to: { full: "Frank Bainimarama", first: "Frank", last: "Bainimarama"} },
      { from: "Baker, Jack", to: { full: "Jack Baker", first: "Jack", last: "Baker"} },
      { from: "Baker, Russell", to: { full: "Russell Baker", first: "Russell", last: "Baker"} },
      { from: "Bakhtiari, Marjaney", to: { full: "Marjaney Bakhtiari", first: "Marjaney", last: "Bakhtiari"} },
      { from: "Bakunin, Mikhail", to: { full: "Mikhail Bakunin", first: "Mikhail", last: "Bakunin"} },
      { from: "Ball, Hugo", to: { full: "Hugo Ball", first: "Hugo", last: "Ball"} },
      { from: "Ballmer, Steve", to: { full: "Steve Ballmer", first: "Steve", last: "Ballmer"} },
      { from: "Balzac, Honoré de", to: { full: "Honoré de Balzac", first: "Honoré", last: "de Balzac"} },
      { from: "Bancroft, Anne", to: { full: "Anne Bancroft", first: "Anne", last: "Bancroft"} },
      { from: "Bangs, Lester", to: { full: "Lester Bangs", first: "Lester", last: "Bangs"} },
      { from: "Banhart, Devendra", to: { full: "Devendra Banhart", first: "Devendra", last: "Banhart"} },
      { from: "Banks, Ernie", to: { full: "Ernie Banks", first: "Ernie", last: "Banks"} },
      { from: "Banks, Robert", to: { full: "Robert Banks", first: "Robert", last: "Banks"} },
      { from: "Barbauld, Anna Letitia", to: { full: "Anna Letitia Barbauld", first: "Anna Letitia", last: "Barbauld"} },
      { from: "Barclay, William", to: { full: "William Barclay", first: "William", last: "Barclay"} },
      { from: "Barker, Clive", to: { full: "Clive Barker", first: "Clive", last: "Barker"} },
      { from: "Barkley, Charles", to: { full: "Charles Barkley", first: "Charles", last: "Barkley"} },
      { from: "Barlow, John Perry", to: { full: "John Perry Barlow", first: "John Perry", last: "Barlow"} },
      { from: "Barnes, Jack", to: { full: "Jack Barnes", first: "Jack", last: "Barnes"} },
      { from: "Barnes, Julian", to: { full: "Julian Barnes", first: "Julian", last: "Barnes"} },
      { from: "Barrie, J. M.", to: { full: "J M Barrie", first: "J M", last: "Barrie"} },
      { from: "Barry, Dave", to: { full: "Dave Barry", first: "Dave", last: "Barry"} },
      { from: "Barry, Marion", to: { full: "Marion Barry", first: "Marion", last: "Barry"} },
      { from: "Bartholin, Thomas V.", to: { full: "Thomas V Bartholin", first: "Thomas V", last: "Bartholin"} },
      { from: "Baruch, Bernard", to: { full: "Bernard Baruch", first: "Bernard", last: "Baruch"} },
      { from: "Barwich, Heinz", to: { full: "Heinz Barwich", first: "Heinz", last: "Barwich"} },
      { from: "Bastiat, Frédéric", to: { full: "Frédéric Bastiat", first: "Frédéric", last: "Bastiat"} },
      { from: "Batch, Charlie", to: { full: "Charlie Batch", first: "Charlie", last: "Batch"} },
      { from: "Bathgate, Andy", to: { full: "Andy Bathgate", first: "Andy", last: "Bathgate"} },
      { from: "Baudelaire, Charles", to: { full: "Charles Baudelaire", first: "Charles", last: "Baudelaire"} },
      { from: "Baum, L. Frank", to: { full: "L Frank Baum", first: "L Frank", last: "Baum"} },
      { from: "Bavadra, Timoci", to: { full: "Timoci Bavadra", first: "Timoci", last: "Bavadra"} },
      { from: "Bayly, Thomas Haynes", to: { full: "Thomas Haynes Bayly", first: "Thomas Haynes", last: "Bayly"} },
      { from: "Bazin, André", to: { full: "André Bazin", first: "André", last: "Bazin"} },
      { from: "Bean, Roy", to: { full: "Roy Bean", first: "Roy", last: "Bean"} },
      { from: "Beard, Charles A.", to: { full: "Charles A Beard", first: "Charles A", last: "Beard"} },
      { from: "Beck, Glenn", to: { full: "Glenn Beck", first: "Glenn", last: "Beck"} },
      { from: "Becker, Carl", to: { full: "Carl Becker", first: "Carl", last: "Becker"} },
      { from: "Beckett, Samuel", to: { full: "Samuel Beckett", first: "Samuel", last: "Beckett"} },
      { from: "Beddoes, Mick", to: { full: "Mick Beddoes", first: "Mick", last: "Beddoes"} },
      { from: "Beecher, Henry Ward", to: { full: "Henry Ward Beecher", first: "Henry Ward", last: "Beecher"} },
      { from: "Beethoven, Ludwig van", to: { full: "Ludwig van Beethoven", first: "Ludwig", last: "van Beethoven"} },
      { from: "Begin, Menachem", to: { full: "Menachem Begin", first: "Menachem", last: "Begin"} },
      { from: "Bell, Alexander Graham", to: { full: "Alexander Graham Bell", first: "Alexander Graham", last: "Bell"} },
      { from: "Belloc, Hilaire", to: { full: "Hilaire Belloc", first: "Hilaire", last: "Belloc"} },
      { from: "Bellow, Saul", to: { full: "Saul Bellow", first: "Saul", last: "Bellow"} },
      { from: "Benchley, Robert", to: { full: "Robert Benchley", first: "Robert", last: "Benchley"} },
      { from: "Benenson, Peter", to: { full: "Peter Benenson", first: "Peter", last: "Benenson"} },
      { from: "Ben-Gurion, David", to: { full: "David Ben-Gurion", first: "David", last: "Ben-Gurion"} },
      { from: "Benjamin, Walter", to: { full: "Walter Benjamin", first: "Walter", last: "Benjamin"} },
      { from: "Benn, Tony", to: { full: "Tony Benn", first: "Tony", last: "Benn"} },
      { from: "Bennett, William Andrew Cicil", to: { full: "William Andrew Cicil Bennett", first: "William Andrew Cicil", last: "Bennett"} },
      { from: "Bennington, Chester", to: { full: "Chester Bennington", first: "Chester", last: "Bennington"} },
      { from: "Benson, Leana", to: { full: "Leana Benson", first: "Leana", last: "Benson"} },
      { from: "Bent, Silas", to: { full: "Silas Bent", first: "Silas", last: "Bent"} },
      { from: "Bentsen, Lloyd", to: { full: "Lloyd Bentsen", first: "Lloyd", last: "Bentsen"} },
      { from: "Berard, Edward V.", to: { full: "Edward V Berard", first: "Edward V", last: "Berard"} },
      { from: "Berger, Ric", to: { full: "Ric Berger", first: "Ric", last: "Berger"} },
      { from: "Bergman, George E.", to: { full: "George E Bergman", first: "George E", last: "Bergman"} },
      { from: "Bergman, Ingmar", to: { full: "Ingmar Bergman", first: "Ingmar", last: "Bergman"} },
      { from: "Berio, Luciano", to: { full: "Luciano Berio", first: "Luciano", last: "Berio"} },
      { from: "Bergerac, Cyrano de", to: { full: "Cyrano de Bergerac", first: "Cyrano", last: "de Bergerac"} },
      { from: "Berle, Milton", to: { full: "Milton Berle", first: "Milton", last: "Berle"} },
      { from: "Berlin, Irving", to: { full: "Irving Berlin", first: "Irving", last: "Berlin"} },
      { from: "Berne, Eric", to: { full: "Eric Berne", first: "Eric", last: "Berne"} },
      { from: "Bernhard, Sandra", to: { full: "Sandra Bernhard", first: "Sandra", last: "Bernhard"} },
      { from: "Berra, Yogi", to: { full: "Yogi Berra", first: "Yogi", last: "Berra"} },
      { from: "Berry, Halle", to: { full: "Halle Berry", first: "Halle", last: "Berry"} },
      { from: "Berry, Wendell", to: { full: "Wendell Berry", first: "Wendell", last: "Berry"} },
      { from: "Bethea, Erin", to: { full: "Erin Bethea", first: "Erin", last: "Bethea"} },
      { from: "Bevan, Aneurin", to: { full: "Aneurin Bevan", first: "Aneurin", last: "Bevan"} },
      { from: "Bevel, Ken", to: { full: "Ken Bevel", first: "Ken", last: "Bevel"} },
      { from: "Bibesco, Princess Elizabeth", to: { full: "Princess Elizabeth Bibesco", first: "Princess Elizabeth", last: "Bibesco"} },
      { from: "Biden, Joseph", to: { full: "Joseph Biden", first: "Joseph", last: "Biden"} },
      { from: "Bierce, Ambrose", to: { full: "Ambrose Bierce", first: "Ambrose", last: "Bierce"} },
      { from: "Biko, Steve", to: { full: "Steve Biko", first: "Steve", last: "Biko"} },
      { from: "Billings, Josh", to: { full: "Josh Billings", first: "Josh", last: "Billings"} },
      { from: "Biondo, Frank", to: { full: "Frank Biondo", first: "Frank", last: "Biondo"} },
      { from: "Birrell, Augustine", to: { full: "Augustine Birrell", first: "Augustine", last: "Birrell"} },
      { from: "Blair, Robert", to: { full: "Robert Blair", first: "Robert", last: "Blair"} },
      { from: "Blair, Tony", to: { full: "Tony Blair", first: "Tony", last: "Blair"} },
      { from: "Blake, William", to: { full: "William Blake", first: "William", last: "Blake"} },
      { from: "Blakey, Art", to: { full: "Art Blakey", first: "Art", last: "Blakey"} },
      { from: "Blalock, Jolene", to: { full: "Jolene Blalock", first: "Jolene", last: "Blalock"} },
      { from: "Blanc, Mel", to: { full: "Mel Blanc", first: "Mel", last: "Blanc"} },
      { from: "Blanc, Raymond", to: { full: "Raymond Blanc", first: "Raymond", last: "Blanc"} },
      { from: "Blanchett, Cate", to: { full: "Cate Blanchett", first: "Cate", last: "Blanchett"} },
      { from: "Blix, Hans", to: { full: "Hans Blix", first: "Hans", last: "Blix"} },
      { from: "Blood, Rebecca", to: { full: "Rebecca Blood", first: "Rebecca", last: "Blood"} },
      { from: "Boethius, Ancius", to: { full: "Ancius Boethius", first: "Ancius", last: "Boethius"} },
      { from: "Bogart, Neil", to: { full: "Neil Bogart", first: "Neil", last: "Bogart"} },
      { from: "Bohm, David", to: { full: "David Bohm", first: "David", last: "Bohm"} },
      { from: "Bohr, Niels", to: { full: "Niels Bohr", first: "Niels", last: "Bohr"} },
      { from: "Boileau-Despreaux, Nicholas", to: { full: "Nicholas Boileau-Despreaux", first: "Nicholas", last: "Boileau-Despreaux"} },
      { from: "Bokini, Ratu Ovini", to: { full: "Ratu Ovini Bokini", title: "Ratu", first: "Ovini", last: "Bokini"} },
      { from: "Bolano, Roberto", to: { full: "Roberto Bolano", first: "Roberto", last: "Bolano"} },
      { from: "Bolívar, Simón", to: { full: "Simón Bolívar", first: "Simón", last: "Bolívar"} },
      { from: "Bombeck, Erma", to: { full: "Erma Bombeck", first: "Erma", last: "Bombeck"} },
      { from: "Bonaparte, Napoleon", to: { full: "Napoleon Bonaparte", first: "Napoleon", last: "Bonaparte"} },
      { from: "Bonhoeffer, Dietrich", to: { full: "Dietrich Bonhoeffer", first: "Dietrich", last: "Bonhoeffer"} },
      { from: "Bonner, Elena", to: { full: "Elena Bonner", first: "Elena", last: "Bonner"} },
      { from: "Boone, Louis E.", to: { full: "Louis E Boone", first: "Louis E", last: "Boone"} },
      { from: "Boorstin, Daniel J.", to: { full: "Daniel J Boorstin", first: "Daniel J", last: "Boorstin"} },
      { from: "Booth, William", to: { full: "William Booth", first: "William", last: "Booth"} },
      { from: "Boretz, Benjamin", to: { full: "Benjamin Boretz", first: "Benjamin", last: "Boretz"} },
      { from: "Borges, Jorge Luis", to: { full: "Jorge Luis Borges", first: "Jorge Luis", last: "Borges"} },
      { from: "Borlaug, Norman", to: { full: "Norman Borlaug", first: "Norman", last: "Borlaug"} },
      { from: "Bose, Subhash Chandra", to: { full: "Subhash Chandra Bose", first: "Subhash Chandra", last: "Bose"} },
      { from: "Bossidy, John Collins", to: { full: "John Collins Bossidy", first: "John Collins", last: "Bossidy"} },
      { from: "Boswell, James", to: { full: "James Boswell", first: "James", last: "Boswell"} },
      { from: "Botha, Pik", to: { full: "Pik Botha", first: "Pik", last: "Botha"} },
      { from: "Boutroux, Pierre", to: { full: "Pierre Boutroux", first: "Pierre", last: "Boutroux"} },
      { from: "Bowen, Elizabeth", to: { full: "Elizabeth Bowen", first: "Elizabeth", last: "Bowen"} },
      { from: "Bowerman, Bill", to: { full: "Bill Bowerman", first: "Bill", last: "Bowerman"} },
      { from: "Bowie, David", to: { full: "David Bowie", first: "David", last: "Bowie"} },
      { from: "Bowles, Chester", to: { full: "Chester Bowles", first: "Chester", last: "Bowles"} },
      { from: "Bowles, Paul", to: { full: "Paul Bowles", first: "Paul", last: "Bowles"} },
      { from: "Bowles, Ralston", to: { full: "Ralston Bowles", first: "Ralston", last: "Bowles"} },
      { from: "Box, George E. P.", to: { full: "George E P Box", first: "George E P", last: "Box"} },
      { from: "Bracken, Peg", to: { full: "Peg Bracken", first: "Peg", last: "Bracken"} },
      { from: "Bracken, Thomas", to: { full: "Thomas Bracken", first: "Thomas", last: "Bracken"} },
      { from: "Brackett, Joseph", to: { full: "Joseph Brackett", first: "Joseph", last: "Brackett"} },
      { from: "Bradbury, Ray", to: { full: "Ray Bradbury", first: "Ray", last: "Bradbury"} },
      { from: "Bradley, Omar", to: { full: "Omar Bradley", first: "Omar", last: "Bradley"} },
      { from: "Braine, John", to: { full: "John Braine", first: "John", last: "Braine"} },
      { from: "Brand, Max", to: { full: "Max Brand", first: "Max", last: "Brand"} },
      { from: "Branden, Nathaniel", to: { full: "Nathaniel Branden", first: "Nathaniel", last: "Branden"} },
      { from: "Brando, Marlon", to: { full: "Marlon Brando", first: "Marlon", last: "Brando"} },
      { from: "Braque, Georges", to: { full: "Georges Braque", first: "Georges", last: "Braque"} },
      { from: "Braun, Carol Moseley", to: { full: "Carol Moseley Braun", first: "Carol Moseley", last: "Braun"} },
      { from: "Braun, Wernher von", to: { full: "Wernher von Braun", first: "Wernher", last: "von Braun"} },
      { from: "Bräutigam, Deborah", to: { full: "Deborah Bräutigam", first: "Deborah", last: "Bräutigam"} },
      { from: "Brautigan, Richard", to: { full: "Richard Brautigan", first: "Richard", last: "Brautigan"} },
      { from: "Brazauskas, Algirdas", to: { full: "Algirdas Brazauskas", first: "Algirdas", last: "Brazauskas"} },
      { from: "Brecht, Bertolt", to: { full: "Bertolt Brecht", first: "Bertolt", last: "Brecht"} },
      { from: "Briggs, Joe Bob", to: { full: "Joe Bob Briggs", first: "Joe Bob", last: "Briggs"} },
      { from: "Brilliant, Ashleigh", to: { full: "Ashleigh Brilliant", first: "Ashleigh", last: "Brilliant"} },
      { from: "Brodsky, Joseph", to: { full: "Joseph Brodsky", first: "Joseph", last: "Brodsky"} },
      { from: "Brontë, Emily", to: { full: "Emily Brontë", first: "Emily", last: "Brontë"} },
      { from: "Brooks, Gwendolyn", to: { full: "Gwendolyn Brooks", first: "Gwendolyn", last: "Brooks"} },
      { from: "Brooks, Mel", to: { full: "Mel Brooks", first: "Mel", last: "Brooks"} },
      { from: "Brothers, Dr. Joyce", to: { full: "Joyce Brothers", title: "Dr", first: "Joyce", last: "Brothers"} },
      { from: "Broun, Heywood", to: { full: "Heywood Broun", first: "Heywood", last: "Broun"} },
      { from: "Brown, Alton", to: { full: "Alton Brown", first: "Alton", last: "Brown"} },
      { from: "Brown, Earle", to: { full: "Earle Brown", first: "Earle", last: "Brown"} },
      { from: "Brown, Elizabeth", to: { full: "Elizabeth Brown", first: "Elizabeth", last: "Brown"} },
      { from: "Brown, Julie", to: { full: "Julie Brown", first: "Julie", last: "Brown"} },
      { from: "Brown, Sam", to: { full: "Sam Brown", first: "Sam", last: "Brown"} },
      { from: "Browne, Harry", to: { full: "Harry Browne", first: "Harry", last: "Browne"} },
      { from: "Browne, Sir Thomas", to: { full: "Sir Thomas Browne", title: "Sir", first: "Thomas", last: "Browne"} },
      { from: "Browning, Elizabeth Barrett", to: { full: "Elizabeth Barrett Browning", first: "Elizabeth Barrett", last: "Browning"} },
      { from: "Browning, Robert", to: { full: "Robert Browning", first: "Robert", last: "Browning"} },
      { from: "Broyard, Anatole", to: { full: "Anatole Broyard", first: "Anatole", last: "Broyard"} },
      { from: "Bruce, Lenny", to: { full: "Lenny Bruce", first: "Lenny", last: "Bruce"} },
      { from: "Bruno, Giordano", to: { full: "Giordano Bruno", first: "Giordano", last: "Bruno"} },
      { from: "Brutus, Marcus Junius", to: { full: "Marcus Junius Brutus", first: "Marcus Junius", last: "Brutus"} },
      { from: "Bryan, William Jennings", to: { full: "William Jennings Bryan", first: "William Jennings", last: "Bryan"} },
      { from: "Bryant, William Cullen", to: { full: "William Cullen Bryant", first: "William Cullen", last: "Bryant"} },
      { from: "Bryson, Bill", to: { full: "Bill Bryson", first: "Bill", last: "Bryson"} },
      { from: "Buber, Martin", to: { full: "Martin Buber", first: "Martin", last: "Buber"} },
      { from: "Buchan, John", to: { full: "John Buchan", first: "John", last: "Buchan"} },
      { from: "Buck, Pearl", to: { full: "Pearl Buck", first: "Pearl", last: "Buck"} },
      { from: "Buckles, Frank", to: { full: "Frank Buckles", first: "Frank", last: "Buckles"} },
      { from: "Buddha, Gautama", to: { full: "Gautama Buddha", first: "Gautama", last: "Buddha"} },
      { from: "Buffett, Warren", to: { full: "Warren Buffett", first: "Warren", last: "Buffett"} },
      { from: "Bujold, Lois McMaster", to: { full: "Lois McMaster Bujold", first: "Lois McMaster", last: "Bujold"} },
      { from: "Bullock, Sandra", to: { full: "Sandra Bullock", first: "Sandra", last: "Bullock"} },
      { from: "Bune, Poseci", to: { full: "Poseci Bune", first: "Poseci", last: "Bune"} },
      { from: "Buñuel, Luis", to: { full: "Luis Buñuel", first: "Luis", last: "Buñuel"} },
      { from: "Buonarroti, Michelangelo", to: { full: "Michelangelo Buonarroti", first: "Michelangelo", last: "Buonarroti"} },
      { from: "Burke, Edmund", to: { full: "Edmund Burke", first: "Edmund", last: "Burke"} },
      { from: "Burnett, Carol", to: { full: "Carol Burnett", first: "Carol", last: "Burnett"} },
      { from: "Burnham, Daniel", to: { full: "Daniel Burnham", first: "Daniel", last: "Burnham"} },
      { from: "Burnham, Frederick Russell", to: { full: "Frederick Russell Burnham", first: "Frederick Russell", last: "Burnham"} },
      { from: "Burns, Edward", to: { full: "Edward Burns", first: "Edward", last: "Burns"} },
      { from: "Burns, Robert", to: { full: "Robert Burns", first: "Robert", last: "Burns"} },
      { from: "Burroughs, John", to: { full: "John Burroughs", first: "John", last: "Burroughs"} },
      { from: "Burroughs, William S.", to: { full: "William S Burroughs", first: "William S", last: "Burroughs"} },
      { from: "Burton, Sir Richard Francis", to: { full: "Richard Francis Burton", title: "Sir", first: "Richard Francis", last: "Burton"} },
      { from: "Buscaglia, Leo", to: { full: "Leo Buscaglia", first: "Leo", last: "Buscaglia"} },
      { from: "Bush, George H. W.", to: { full: "George H W Bush", first: "George H W", last: "Bush"} },
      { from: "Bush, George W.", to: { full: "George W Bush", first: "George W", last: "Bush"} },
      { from: "Bush, John Carder", to: { full: "John Carder Bush", first: "John Carder", last: "Bush"} },
      { from: "Bush, Kate", to: { full: "Kate Bush", first: "Kate", last: "Bush"} },
      { from: "Bush, Vannevar", to: { full: "Vannevar Bush", first: "Vannevar", last: "Bush"} },
      { from: "Butler, Amir", to: { full: "Amir Butler", first: "Amir", last: "Butler"} },
      { from: "Butler, Smedley", to: { full: "Smedley Butler", first: "Smedley", last: "Butler"} },
      { from: "Butler Sloss, Dame Elizabeth", to: { full: "Dame Elizabeth Butler Sloss", title: "Dame", first: "Elizabeth", last: "Butler Sloss"} },
      { from: "Buzan, Tony", to: { full: "Tony Buzan", first: "Tony", last: "Buzan"} },
      { from: "Byrd, Richard E.", to: { full: "Richard E Byrd", first: "Richard E", last: "Byrd"} },
      { from: "Byrd, Robert", to: { full: "Robert Byrd", first: "Robert", last: "Byrd"} },
      { from: "Byrne, David", to: { full: "David Byrne", first: "David", last: "Byrne"} },
      { from: "Byrne, Robert", to: { full: "Robert Byrne", first: "Robert", last: "Byrne"} },
      { skip: "The given string implies Lord is his name, it is his title",
        from: "Byron, Lord", to: { full: "Lord Byron", title: "Lord", last: "Byron"} },

      { from: "Cabell, James Branch", to: { full: "James Branch Cabell", first: "James Branch", last: "Cabell"} },
      { from: "Caesar, Irving", to: { full: "Irving Caesar", first: "Irving", last: "Caesar"} },
      { from: "Caesar, Julius", to: { full: "Julius Caesar", first: "Julius", last: "Caesar"} },
      { from: "Cage, John", to: { full: "John Cage", first: "John", last: "Cage"} },
      { from: "Cain, Peter", to: { full: "Peter Cain", first: "Peter", last: "Cain"} },
      { from: "Callaghan, James", to: { full: "James Callaghan", first: "James", last: "Callaghan"} },
      { from: "Calvin, John", to: { full: "John Calvin", first: "John", last: "Calvin"} },
      { from: "Cameron, Julia", to: { full: "Julia Cameron", first: "Julia", last: "Cameron"} },
      { from: "Cameron, Kirk", to: { full: "Kirk Cameron", first: "Kirk", last: "Cameron"} },
      { from: "Campbell, Beatrice Stella; (Mrs. Patrick Campbell)", to: { full: "Beatrice Stella Campbell", first: "Beatrice Stella", nick: "Mrs Patrick Campbell", last: "Campbell"} },
      { from: "Camus, Albert", to: { full: "Albert Camus", first: "Albert", last: "Camus"} },
      { from: "Cannon, James P.", to: { full: "James P Cannon", first: "James P", last: "Cannon"} },
      { from: "Canseco, José", to: { full: "José Canseco", first: "José", last: "Canseco"} },
      { from: "Cantona, Eric", to: { full: "Eric Cantona", first: "Eric", last: "Cantona"} },
      { from: "Cao, Cao", to: { full: "Cao Cao", first: "Cao", last: "Cao"} },
      { from: "Čapek, Karel", to: { full: "Karel Čapek", first: "Karel", last: "Čapek"} },
      { from: "Capote, Truman", to: { full: "Truman Capote", first: "Truman", last: "Capote"} },
      { from: "Capone, Al", to: { full: "Al Capone", first: "Al", last: "Capone"} },
      { from: "Card, Orson Scott", to: { full: "Orson Scott Card", first: "Orson Scott", last: "Card"} },
      { from: "Carducci, Giosue", to: { full: "Giosue Carducci", first: "Giosue", last: "Carducci"} },
      { from: "Carey, Mariah", to: { full: "Mariah Carey", first: "Mariah", last: "Carey"} },
      { from: "Carey, Sandra", to: { full: "Sandra Carey", first: "Sandra", last: "Carey"} },
      { from: "Carlin, George", to: { full: "George Carlin", first: "George", last: "Carlin"} },
      { from: "Carlson, Tucker", to: { full: "Tucker Carlson", first: "Tucker", last: "Carlson"} },
      { from: "Carlyle, Thomas", to: { full: "Thomas Carlyle", first: "Thomas", last: "Carlyle"} },
      { from: "Carnegie, Andrew", to: { full: "Andrew Carnegie", first: "Andrew", last: "Carnegie"} },
      { from: "Carolla, Adam", to: { full: "Adam Carolla", first: "Adam", last: "Carolla"} },
      { from: "Carrel, Alexis", to: { full: "Alexis Carrel", first: "Alexis", last: "Carrel"} },
      { from: "Carrey, Jim", to: { full: "Jim Carrey", first: "Jim", last: "Carrey"} },
      { from: "Carroll, Lewis", to: { full: "Lewis Carroll", first: "Lewis", last: "Carroll"} },
      { from: "Carroll, Tom", to: { full: "Tom Carroll", first: "Tom", last: "Carroll"} },
      { from: "Carson, Rachel", to: { full: "Rachel Carson", first: "Rachel", last: "Carson"} },
      { from: "Carter, Elliott", to: { full: "Elliott Carter", first: "Elliott", last: "Carter"} },
      { from: "Carter, Howard", to: { full: "Howard Carter", first: "Howard", last: "Carter"} },
      { from: "Carter, Jimmy", to: { full: "Jimmy Carter", first: "Jimmy", last: "Carter"} },
      { from: "Carville, James", to: { full: "James Carville", first: "James", last: "Carville"} },
      { from: "Casals, Pablo", to: { full: "Pablo Casals", first: "Pablo", last: "Casals"} },
      { from: "Casanova, Giacomo (Jacques Casanova de Seingal)", to: { full: "Giacomo Casanova", first: "Giacomo", nick:"Jacques Casanova de Seingal", last: "Casanova" } },
      { from: "Cash, Johnny", to: { full: "Johnny Cash", first: "Johnny", last: "Cash"} },
      { from: "Castaneda, Carlos", to: { full: "Carlos Castaneda", first: "Carlos", last: "Castaneda"} },
      { from: "Castro, Fidel", to: { full: "Fidel Castro", first: "Fidel", last: "Castro"} },
      { from: "Cather, Willa", to: { full: "Willa Cather", first: "Willa", last: "Cather"} },
      { from: "Catt, Michael", to: { full: "Michael Catt", first: "Michael", last: "Catt"} },
      { from: "Catullus, Gaius Valerius", to: { full: "Gaius Valerius Catullus", first: "Gaius Valerius", last: "Catullus"} },
      { from: "Caucau, Adi Asenaca", to: { full: "Adi Asenaca Caucau", title: "Adi", first: "Asenaca", last: "Caucau"} },
      { from: "Cavell, Edith", to: { full: "Edith Cavell", first: "Edith", last: "Cavell"} },
      { from: "Cavett, Dick", to: { full: "Dick Cavett", first: "Dick", last: "Cavett"} },
      { from: "Cervantes, Miguel de", to: { full: "Miguel de Cervantes", first: "Miguel", last: "de Cervantes"} },
      { from: "Chambers, Oswald", to: { full: "Oswald Chambers", first: "Oswald", last: "Chambers"} },
      { from: "Chandler, Raymond", to: { full: "Raymond Chandler", first: "Raymond", last: "Chandler"} },
      { from: "Lon Chaney, Sr.", to: { full: "Lon Chaney", first: "Lon", last: "Chaney", suffix: "Sr"} },
      { from: "Channing, William Ellery", to: { full: "William Ellery Channing", first: "William Ellery", last: "Channing"} },
      { from: "Chapin, Harry", to: { full: "Harry Chapin", first: "Harry", last: "Chapin"} },
      { from: "Chapman, Colin", to: { full: "Colin Chapman", first: "Colin", last: "Chapman"} },
      { from: "Chappelle, Dave", to: { full: "Dave Chappelle", first: "Dave", last: "Chappelle"} },
      { skip: "Haven't figured this one yet",
        from: "Charles II, King of England", to: { full: "King of England Charles II", first: "King of England", last: "Charles II"} },
      { skip: "Haven't figured this one yet",
        from: "Charles V, Holy Roman Emperor", to: { full: "Holy Roman Emperor Charles V", first: "Holy Roman Emperor", last: "Charles V"} },
      { from: "Charles, Ray", to: { full: "Ray Charles", first: "Ray", last: "Charles"} },
      { from: "Chateaubriand, François-René de", to: { full: "François-René de Chateaubriand", first: "François-René", last: "de Chateaubriand"} },
      { from: "Chatwin, Bruce", to: { full: "Bruce Chatwin", first: "Bruce", last: "Chatwin"} },
      { from: "Chaucer, Geoffrey", to: { full: "Geoffrey Chaucer", first: "Geoffrey", last: "Chaucer"} },
      { from: "Chaudhry, Mahendra", to: { full: "Mahendra Chaudhry", first: "Mahendra", last: "Chaudhry"} },
      { from: "Chavez, Cesar", to: { full: "Cesar Chavez", first: "Cesar", last: "Chavez"} },
      { from: "Cheever, John", to: { full: "John Cheever", first: "John", last: "Cheever"} },
      { from: "Cherryh, C. J.", to: { full: "C J Cherryh", first: "C J", last: "Cherryh"} },
      { from: "Chesterton, Gilbert Keith", to: { full: "Gilbert Keith Chesterton", first: "Gilbert Keith", last: "Chesterton"} },
      { from: "Chevalier, Maurice", to: { full: "Maurice Chevalier", first: "Maurice", last: "Chevalier"} },
      { from: "Chiariglione, Leonardo", to: { full: "Leonardo Chiariglione", first: "Leonardo", last: "Chiariglione"} },
      { from: "Chicago, Judy", to: { full: "Judy Chicago", first: "Judy", last: "Chicago"} },
      { from: "Child, Julia", to: { full: "Julia Child", first: "Julia", last: "Child"} },
      { from: "Cho, Margaret", to: { full: "Margaret Cho", first: "Margaret", last: "Cho"} },
      { from: "Choate, Rufus", to: { full: "Rufus Choate", first: "Rufus", last: "Choate"} },
      { from: "Christie, Agatha", to: { full: "Agatha Christie", first: "Agatha", last: "Christie"} },
      { from: "Chrysostom, John", to: { full: "John Chrysostom", first: "John", last: "Chrysostom"} },
      { from: "Churchill, Winston", to: { full: "Winston Churchill", first: "Winston", last: "Churchill"} },
      { from: "Ciccone, Madonna", to: { full: "Madonna Ciccone", first: "Madonna", last: "Ciccone"} },
      { from: "Cioran, Emile", to: { full: "Emile Cioran", first: "Emile", last: "Cioran"} },
      { from: "Clancy, Tom", to: { full: "Tom Clancy", first: "Tom", last: "Clancy"} },
      { from: "Clapton, Eric", to: { full: "Eric Clapton", first: "Eric", last: "Clapton"} },
      { from: "Clark, Frank A.", to: { full: "Frank A Clark", first: "Frank A", last: "Clark"} },
      { from: "Clark, Ramsey", to: { full: "Ramsey Clark", first: "Ramsey", last: "Clark"} },
      { from: "Clark, Wesley", to: { full: "Wesley Clark", first: "Wesley", last: "Clark"} },
      { from: "Clarke, Arthur C.", to: { full: "Arthur C Clarke", first: "Arthur C", last: "Clarke"} },
      { from: "Clausewitz, Karl von", to: { full: "Karl von Clausewitz", first: "Karl", last: "von Clausewitz"} },
      { from: "Clay, Andrew Dice", to: { full: "Andrew Dice Clay", first: "Andrew Dice", last: "Clay"} },
      { from: "Clay, Henry", to: { full: "Henry Clay", first: "Henry", last: "Clay"} },
      { from: "Clemenceau, Georges", to: { full: "Georges Clemenceau", first: "Georges", last: "Clemenceau"} },
      { from: "Clinton, Bill", to: { full: "Bill Clinton", first: "Bill", last: "Clinton"} },
      { from: "Clinton, Hillary", to: { full: "Hillary Clinton", first: "Hillary", last: "Clinton"} },
      { from: "Clough, Brian", to: { full: "Brian Clough", first: "Brian", last: "Clough"} },
      { from: "Cobain, Kurt Donald", to: { full: "Kurt Donald Cobain", first: "Kurt Donald", last: "Cobain"} },
      { from: "Cochran, Johnnie", to: { full: "Johnnie Cochran", first: "Johnnie", last: "Cochran"} },
      { from: "Cocteau, Jean", to: { full: "Jean Cocteau", first: "Jean", last: "Cocteau"} },
      { from: "Codrescu, Andrei", to: { full: "Andrei Codrescu", first: "Andrei", last: "Codrescu"} },
      { from: "Cohen, Catman", to: { full: "Catman Cohen", first: "Catman", last: "Cohen"} },
      { from: "Cohen, Leonard", to: { full: "Leonard Cohen", first: "Leonard", last: "Cohen"} },
      { from: "Cohen, Nick", to: { full: "Nick Cohen", first: "Nick", last: "Cohen"} },
      { from: "Cohen, Richard", to: { full: "Richard Cohen", first: "Richard", last: "Cohen"} },
      { from: "Coleridge, Samuel Taylor", to: { full: "Samuel Taylor Coleridge", first: "Samuel Taylor", last: "Coleridge"} },
      { from: "Collett, Camilla", to: { full: "Camilla Collett", first: "Camilla", last: "Collett"} },
      { from: "Collier, Jeremy", to: { full: "Jeremy Collier", first: "Jeremy", last: "Collier"} },
      { from: "Collins, Tim", to: { full: "Tim Collins", first: "Tim", last: "Collins"} },
      { from: "Collison, Chris", to: { full: "Chris Collison", first: "Chris", last: "Collison"} },
      { from: "Colson, Charles", to: { full: "Charles Colson", first: "Charles", last: "Colson"} },
      { from: "Colten, James", to: { full: "James Colten", first: "James", last: "Colten"} },
      { from: "Colton, Charles Caleb", to: { full: "Charles Caleb Colton", first: "Charles Caleb", last: "Colton"} },
      { from: "Coltrane, John", to: { full: "John Coltrane", first: "John", last: "Coltrane"} },
      { from: "Columbus, Christopher", to: { full: "Christopher Columbus", first: "Christopher", last: "Columbus"} },
      { from: "Commager, Henry Steele", to: { full: "Henry Steele Commager", first: "Henry Steele", last: "Commager"} },
      { from: "Congreve, William", to: { full: "William Congreve", first: "William", last: "Congreve"} },
      { from: "Conlon, Fred", to: { full: "Fred Conlon", first: "Fred", last: "Conlon"} },
      { from: "Connolly, Cyril", to: { full: "Cyril Connolly", first: "Cyril", last: "Connolly"} },
      { from: "Conrad, Joseph", to: { full: "Joseph Conrad", first: "Joseph", last: "Conrad"} },
      { from: "Conway, Anne", to: { full: "Anne Conway", first: "Anne", last: "Conway"} },
      { from: "Conway Morris, Simon", to: { full: "Simon Conway Morris", first: "Simon", last: "Conway Morris"} },
      { from: "Cook, Peter", to: { full: "Peter Cook", first: "Peter", last: "Cook"} },
      { from: "Cooley, Mason", to: { full: "Mason Cooley", first: "Mason", last: "Cooley"} },
      { from: "Coolidge, Calvin", to: { full: "Calvin Coolidge", first: "Calvin", last: "Coolidge"} },
      { from: "Cooper, Alice", to: { full: "Alice Cooper", first: "Alice", last: "Cooper"} },
      { from: "Copeland, Stewart", to: { full: "Stewart Copeland", first: "Stewart", last: "Copeland"} },
      { from: "Copernicus, Nicolaus", to: { full: "Nicolaus Copernicus", first: "Nicolaus", last: "Copernicus"} },
      { from: "Copland, Aaron", to: { full: "Aaron Copland", first: "Aaron", last: "Copland"} },
      { from: "Corea, Chick", to: { full: "Chick Corea", first: "Chick", last: "Corea"} },
      { from: "Corea, Vernon", to: { full: "Vernon Corea", first: "Vernon", last: "Corea"} },
      { from: "Corey, Peter", to: { full: "Peter Corey", first: "Peter", last: "Corey"} },
      { from: "Corgan, Billy", to: { full: "Billy Corgan", first: "Billy", last: "Corgan"} },
      { from: "Cortázar, Julio", to: { full: "Julio Cortázar", first: "Julio", last: "Cortázar"} },
      { from: "Cosby, Bill", to: { full: "Bill Cosby", first: "Bill", last: "Cosby"} },
      { from: "Coulter, Ann", to: { full: "Ann Coulter", first: "Ann", last: "Coulter"} },
      { from: "Coupland, Douglas", to: { full: "Douglas Coupland", first: "Douglas", last: "Coupland"} },
      { from: "Courtney, Margaret", to: { full: "Margaret Courtney", first: "Margaret", last: "Courtney"} },
      { from: "Covington, Stephen", to: { full: "Stephen Covington", first: "Stephen", last: "Covington"} },
      { from: "Coward, Noel", to: { full: "Noel Coward", first: "Noel", last: "Coward"} },
      { from: "Cowley, Abraham", to: { full: "Abraham Cowley", first: "Abraham", last: "Cowley"} },
      { from: "Cowper, William", to: { full: "William Cowper", first: "William", last: "Cowper"} },
      { from: "Crace, Jim", to: { full: "Jim Crace", first: "Jim", last: "Crace"} },
      { from: "Craik, Dinah", to: { full: "Dinah Craik", first: "Dinah", last: "Craik"} },
      { from: "Crane, Dr. Frank", to: { full: "Frank Crane", title: "Dr", first: "Frank", last: "Crane"} },
      { from: "Crane, Stephen", to: { full: "Stephen Crane", first: "Stephen", last: "Crane"} },
      { from: "Cray, Seymour", to: { full: "Seymour Cray", first: "Seymour", last: "Cray"} },
      { from: "Crick, Francis", to: { full: "Francis Crick", first: "Francis", last: "Crick"} },
      { from: "Crimmins, Barry", to: { full: "Barry Crimmins", first: "Barry", last: "Crimmins"} },
      { from: "Cringely, Robert X.", to: { full: "Robert X Cringely", first: "Robert X", last: "Cringely"} },
      { from: "Crisp, Quentin", to: { full: "Quentin Crisp", first: "Quentin", last: "Crisp"} },
      { from: "Crockett, Davy", to: { full: "Davy Crockett", first: "Davy", last: "Crockett"} },
      { from: "Cromwell, Oliver", to: { full: "Oliver Cromwell", first: "Oliver", last: "Cromwell"} },
      { from: "Cross, David", to: { full: "David Cross", first: "David", last: "Cross"} },
      { from: "Crowley, Aleister", to: { full: "Aleister Crowley", first: "Aleister", last: "Crowley"} },
      { from: "Crumb, Robert", to: { full: "Robert Crumb", first: "Robert", last: "Crumb"} },
      { from: "Cummings, E. E.", to: { full: "E E Cummings", first: "E E", last: "Cummings"} },
      { from: "Cunningham, Allan", to: { full: "Allan Cunningham", first: "Allan", last: "Cunningham"} },
      { from: "Cunningham, Ward", to: { full: "Ward Cunningham", first: "Ward", last: "Cunningham"} },
      { from: "Curie, Marie", to: { full: "Marie Curie", first: "Marie", last: "Curie"} },

      { from: "Daley, Richard J.", to: { full: "Richard J Daley", first: "Richard J", last: "Daley"} },
      { from: "Dali, Salvador", to: { full: "Salvador Dali", first: "Salvador", last: "Dali"} },
      { from: "Daly, Carson", to: { full: "Carson Daly", first: "Carson", last: "Daly"} },
      { from: "Daly, Daniel", to: { full: "Daniel Daly", first: "Daniel", last: "Daly"} },
      { from: "Damon, Johnny", to: { full: "Johnny Damon", first: "Johnny", last: "Damon"} },
      { from: "Dangerfield, Rodney", to: { full: "Rodney Dangerfield", first: "Rodney", last: "Dangerfield"} },
      { from: "Daniel, Samuel", to: { full: "Samuel Daniel", first: "Samuel", last: "Daniel"} },
      { from: "Daniels, Anthony", to: { full: "Anthony Daniels", first: "Anthony", last: "Daniels"} },
      { from: "Darrow, Clarence", to: { full: "Clarence Darrow", first: "Clarence", last: "Darrow"} },
      { from: "Darwin, Charles", to: { full: "Charles Darwin", first: "Charles", last: "Darwin"} },
      { from: "Dauten, Dale", to: { full: "Dale Dauten", first: "Dale", last: "Dauten"} },
      { from: "Davis, Bette", to: { full: "Bette Davis", first: "Bette", last: "Davis"} },
      { from: "Davis, Miles", to: { full: "Miles Davis", first: "Miles", last: "Davis"} },
      { from: "Davisson, Richard", to: { full: "Richard Davisson", first: "Richard", last: "Davisson"} },
      { from: "Dawkins, Richard", to: { full: "Richard Dawkins", first: "Richard", last: "Dawkins"} },
      { from: "Day, Carl", to: { full: "Carl Day", first: "Carl", last: "Day"} },
      { from: "Dayan, Moshe", to: { full: "Moshe Dayan", first: "Moshe", last: "Dayan"} },
      { from: "Dean, Howard", to: { full: "Howard Dean", first: "Howard", last: "Dean"} },
      { from: "Dean, James", to: { full: "James Dean", first: "James", last: "Dean"} },
      { from: "Dean, John", to: { full: "John Dean", first: "John", last: "Dean"} },
      { from: "de Bono, Edward", to: { full: "Edward de Bono", first: "Edward", last: "de Bono"} },
      { from: "Debs, Eugene V.", to: { full: "Eugene V Debs", first: "Eugene V", last: "Debs"} },
      { from: "Dee, Jack", to: { full: "Jack Dee", first: "Jack", last: "Dee"} },
      { from: "Degas, Edgar", to: { full: "Edgar Degas", first: "Edgar", last: "Degas"} },
      { from: "DeGeneres, Ellen", to: { full: "Ellen DeGeneres", first: "Ellen", last: "DeGeneres"} },
      { from: "Delacroix, Eugène", to: { full: "Eugène Delacroix", first: "Eugène", last: "Delacroix"} },
      { from: "de la Rocha, Zack", to: { full: "Zack de la Rocha", first: "Zack", last: "de la Rocha"} },
      { from: "Delay, Tom", to: { full: "Tom Delay", first: "Tom", last: "Delay"} },
      { from: "Delson, Brad", to: { full: "Brad Delson", first: "Brad", last: "Delson"} },
      { from: "de Mello, Anthony", to: { full: "Anthony de Mello", first: "Anthony", last: "de Mello"} },
      { from: "de Molay, Jacques", to: { full: "Jacques de Molay", first: "Jacques", last: "de Molay"} },
      { from: "Denham, John", to: { full: "John Denham", first: "John", last: "Denham"} },
      { from: "Depew, Chauncey", to: { full: "Chauncey Depew", first: "Chauncey", last: "Depew"} },
      { from: "de Raadt, Theo", to: { full: "Theo de Raadt", first: "Theo", last: "de Raadt"} },
      { from: "Derrida, Jacques", to: { full: "Jacques Derrida", first: "Jacques", last: "Derrida"} },
      { from: "Descartes, René", to: { full: "René Descartes", first: "René", last: "Descartes"} },
      { from: "DeShannon, Jackie", to: { full: "Jackie DeShannon", first: "Jackie", last: "DeShannon"} },
      { from: "Desmond, Paul", to: { full: "Paul Desmond", first: "Paul", last: "Desmond"} },
      { from: "Deutsch, David", to: { full: "David Deutsch", first: "David", last: "Deutsch"} },
      { from: "Devine, Carl", to: { full: "Carl Devine", first: "Carl", last: "Devine"} },
      { from: "Devo, musical group", to: { full: "musical group Devo", first: "musical group", last: "Devo"} },
      { from: "DeWolfe, Ron (born L. Ron Hubbard, Jr.)", to: { full: "Ron DeWolfe", first: "Ron", last: "DeWolfe", nick: "born L Ron Hubbard, Jr"} },
      { from: "Dhavernas, Caroline", to: { full: "Caroline Dhavernas", first: "Caroline", last: "Dhavernas"} },
      { from: "Diana, Princess of Wales", to: { full: "Princess of Wales Diana", first: "Princess of Wales", last: "Diana"} },
      { from: "DiCaprio, Leonardo", to: { full: "Leonardo DiCaprio", first: "Leonardo", last: "DiCaprio"} },
      { skip: "Haven't figured this one yet",
        from: "Dick, Philip Kindred - a.k.a. PKD", to: { full: "Philip Kindred - a.k.a. PKD Dick", first: "Philip Kindred - a.k.a. PKD", last: "Dick"} },
      { from: "Dickens, Charles", to: { full: "Charles Dickens", first: "Charles", last: "Dickens"} },
      { from: "Dickinson, Emily", to: { full: "Emily Dickinson", first: "Emily", last: "Dickinson"} },
      { from: "Dickson, Leonard Eugene", to: { full: "Leonard Eugene Dickson", first: "Leonard Eugene", last: "Dickson"} },
      { from: "Diderot, Denis", to: { full: "Denis Diderot", first: "Denis", last: "Diderot"} },
      { from: "Didion, Joan", to: { full: "Joan Didion", first: "Joan", last: "Didion"} },
      { from: "Dillard, Annie", to: { full: "Annie Dillard", first: "Annie", last: "Dillard"} },
      { from: "Dirac, Paul", to: { full: "Paul Dirac", first: "Paul", last: "Dirac"} },
      { from: "Dirksen, Everett", to: { full: "Everett Dirksen", first: "Everett", last: "Dirksen"} },
      { from: "Disney, Roy O.", to: { full: "Roy O Disney", first: "Roy O", last: "Disney"} },
      { from: "Disney, Walt", to: { full: "Walt Disney", first: "Walt", last: "Disney"} },
      { from: "Disraeli, Benjamin", to: { full: "Benjamin Disraeli", first: "Benjamin", last: "Disraeli"} },
      { from: "Dijkstra, Edsger", to: { full: "Edsger Dijkstra", first: "Edsger", last: "Dijkstra"} },
      { from: "Djilas, Milovan", to: { full: "Milovan Djilas", first: "Milovan", last: "Djilas"} },
      { from: "Dobson, James", to: { full: "James Dobson", first: "James", last: "Dobson"} },
      { from: "Dogg, Snoop", to: { full: "Snoop Dogg", first: "Snoop", last: "Dogg"} },
      { from: "Doherty, Peter", to: { full: "Peter Doherty", first: "Peter", last: "Doherty"} },
      { from: "Dolphy, Eric", to: { full: "Eric Dolphy", first: "Eric", last: "Dolphy"} },
      { from: "Domeyko, Ignacy", to: { full: "Ignacy Domeyko", first: "Ignacy", last: "Domeyko"} },
      { from: "Dominus, Mark-Jason", to: { full: "Mark-Jason Dominus", first: "Mark-Jason", last: "Dominus"} },
      { from: "Donaldson, Stephen R.", to: { full: "Stephen R Donaldson", first: "Stephen R", last: "Donaldson"} },
      { from: "Donne, John", to: { full: "John Donne", first: "John", last: "Donne"} },
      { from: "Dornfest, Rael", to: { full: "Rael Dornfest", first: "Rael", last: "Dornfest"} },
      { from: "Dostoevsky, Fyodor", to: { full: "Fyodor Dostoevsky", first: "Fyodor", last: "Dostoevsky"} },
      { from: "Douglas, Donald", to: { full: "Donald Douglas", first: "Donald", last: "Douglas"} },
      { from: "Douglas, Kirk", to: { full: "Kirk Douglas", first: "Kirk", last: "Douglas"} },
      { from: "Douglas, Tommy", to: { full: "Tommy Douglas", first: "Tommy", last: "Douglas"} },
      { from: "Douglass, David", to: { full: "David Douglass", first: "David", last: "Douglass"} },
      { from: "Douglass, Frederick", to: { full: "Frederick Douglass", first: "Frederick", last: "Douglass"} },
      { from: "Doyle, Arthur Conan", to: { full: "Arthur Conan Doyle", first: "Arthur Conan", last: "Doyle"} },
      { from: "Drake, Nick", to: { full: "Nick Drake", first: "Nick", last: "Drake"} },
      { from: "Dreiser, Theodore", to: { full: "Theodore Dreiser", first: "Theodore", last: "Dreiser"} },
      { from: "Drucker, Peter F.", to: { full: "Peter F Drucker", first: "Peter F", last: "Drucker"} },
      { from: "Duff, Hilary", to: { full: "Hilary Duff", first: "Hilary", last: "Duff"} },
      { from: "Dumas, Alexandre", to: { full: "Alexandre Dumas", first: "Alexandre", last: "Dumas"} },
      { from: "Dunst, Kirsten", to: { full: "Kirsten Dunst", first: "Kirsten", last: "Dunst"} },
      { from: "Durante, Jimmy", to: { full: "Jimmy Durante", first: "Jimmy", last: "Durante"} },
      { from: "Durbin, Richard", to: { full: "Richard Durbin", first: "Richard", last: "Durbin"} },
      { from: "Durrell, Gerald", to: { full: "Gerald Durrell", first: "Gerald", last: "Durrell"} },
      { from: "Dutton, Denis", to: { full: "Denis Dutton", first: "Denis", last: "Dutton"} },
      { from: "Dyer, Wayne", to: { full: "Wayne Dyer", first: "Wayne", last: "Dyer"} },
      { from: "Dyke, Henry van", to: { full: "Henry van Dyke", first: "Henry", last: "van Dyke"} },
      { from: "Dylan, Bob", to: { full: "Bob Dylan", first: "Bob", last: "Dylan"} },
      { from: "Dyson, Freeman", to: { full: "Freeman Dyson", first: "Freeman", last: "Dyson"} },

      { from: "Early, Jubal Anderson", to: { full: "Jubal Anderson Early", first: "Jubal Anderson", last: "Early"} },
      { from: "Eastwood, Clint", to: { full: "Clint Eastwood", first: "Clint", last: "Eastwood"} },
      { from: "Ebadi, Shirin", to: { full: "Shirin Ebadi", first: "Shirin", last: "Ebadi"} },
      { from: "Eban, Abba", to: { full: "Abba Eban", first: "Abba", last: "Eban"} },
      { from: "Ebert, Roger", to: { full: "Roger Ebert", first: "Roger", last: "Ebert"} },
      { from: "Ecclestone, Bernie", to: { full: "Bernie Ecclestone", first: "Bernie", last: "Ecclestone"} },
      { from: "Echols, Damien", to: { full: "Damien Echols", first: "Damien", last: "Echols"} },
      { from: "Eckhart, Meister", to: { full: "Meister Eckhart", first: "Meister", last: "Eckhart"} },
      { from: "Eddington, Arthur Stanley", to: { full: "Arthur Stanley Eddington", first: "Arthur Stanley", last: "Eddington"} },
      { from: "Edison, Thomas Alva", to: { full: "Thomas Alva Edison", first: "Thomas Alva", last: "Edison"} },
      { skip: "Haven't figured this one yet",
        from: "Edward VII, King of England", to: { full: "King of England Edward VII", first: "King of England", last: "Edward VII"} },
      { from: "Edwards, Edwin W.", to: { full: "Edwin W Edwards", first: "Edwin W", last: "Edwards"} },
      { from: "Edwards, John", to: { full: "John Edwards", first: "John", last: "Edwards"} },
      { from: "Eggers, Dave", to: { full: "Dave Eggers", first: "Dave", last: "Eggers"} },
      { from: "Ehrlich, Paul R.", to: { full: "Paul R Ehrlich", first: "Paul R", last: "Ehrlich"} },
      { from: "Einstein, Albert", to: { full: "Albert Einstein", first: "Albert", last: "Einstein"} },
      { from: "Eisenhower, Dwight D.", to: { full: "Dwight D Eisenhower", first: "Dwight D", last: "Eisenhower"} },
      { from: "Eisenstein, Ferdinand", to: { full: "Ferdinand Eisenstein", first: "Ferdinand", last: "Eisenstein"} },
      { from: "ElBaradei, Mohamed", to: { full: "Mohamed ElBaradei", first: "Mohamed", last: "ElBaradei"} },
      { from: "Eldredge, Niles", to: { full: "Niles Eldredge", first: "Niles", last: "Eldredge"} },
      { from: "Eliot, George", to: { full: "George Eliot", first: "George", last: "Eliot"} },
      { from: "Eliot, Thomas Stearns", to: { full: "Thomas Stearns Eliot", first: "Thomas Stearns", last: "Eliot"} },
      { skip: "Haven't figured this one yet",
        from: "Elizabeth, the Queen Mother", to: { full: "the Queen Mother Elizabeth", first: "the Queen Mother", last: "Elizabeth"} },
      { skip: "Duke will be treated as a title, not a name",
        from: "Ellington, Duke", to: { full: "Duke Ellington", first: "Duke", last: "Ellington"} },
      { from: "Elliot, Cass", to: { full: "Cass Elliot", first: "Cass", last: "Elliot"} },
      { from: "Elliot, Jim", to: { full: "Jim Elliot", first: "Jim", last: "Elliot"} },
      { from: "Ellison, Harlan", to: { full: "Harlan Ellison", first: "Harlan", last: "Ellison"} },
      { from: "Eluard, Paul", to: { full: "Paul Eluard", first: "Paul", last: "Eluard"} },
      { from: "Emerson, Ralph Waldo", to: { full: "Ralph Waldo Emerson", first: "Ralph Waldo", last: "Emerson"} },
      { from: "Engelke, Anke", to: { full: "Anke Engelke", first: "Anke", last: "Engelke"} },
      { from: "Erdös, Paul", to: { full: "Paul Erdös", first: "Paul", last: "Erdös"} },
      { from: "Erikson, Steven", to: { full: "Steven Erikson", first: "Steven", last: "Erikson"} },
      { from: "Escher, M. C.", to: { full: "M C Escher", first: "M C", last: "Escher"} },
      { from: "Esposito, Phil", to: { full: "Phil Esposito", first: "Phil", last: "Esposito"} },
      { from: "Estefan, Gloria", to: { full: "Gloria Estefan", first: "Gloria", last: "Estefan"} },
      { from: "Everett, Carl", to: { full: "Carl Everett", first: "Carl", last: "Everett"} },
      { from: "Ezrin, Bob", to: { full: "Bob Ezrin", first: "Bob", last: "Ezrin"} },

      { from: "Fakes, Dennis", to: { full: "Dennis Fakes", first: "Dennis", last: "Fakes"} },
      { from: "Farage, Nigel", to: { full: "Nigel Farage", first: "Nigel", last: "Farage"} },
      { from: "Farjeon, Eleanor", to: { full: "Eleanor Farjeon", first: "Eleanor", last: "Farjeon"} },
      { from: "Farmer, Frances", to: { full: "Frances Farmer", first: "Frances", last: "Farmer"} },
      { from: "Noli, Fan", to: { full: "Fan Noli", first: "Fan", last: "Noli"} },
      { from: "Fatiaki, Daniel", to: { full: "Daniel Fatiaki", first: "Daniel", last: "Fatiaki"} },
      { from: "Faulkner, William", to: { full: "William Faulkner", first: "William", last: "Faulkner"} },
      { from: "Favre, Brett", to: { full: "Brett Favre", first: "Brett", last: "Favre"} },
      { from: "Fawkes, Guy", to: { full: "Guy Fawkes", first: "Guy", last: "Fawkes"} },
      { from: "Federer, Roger", to: { full: "Roger Federer", first: "Roger", last: "Federer"} },
      { from: "Feibig, Jim", to: { full: "Jim Feibig", first: "Jim", last: "Feibig"} },
      { from: "Feingold, Russ", to: { full: "Russ Feingold", first: "Russ", last: "Feingold"} },
      { from: "Feldman, Morton", to: { full: "Morton Feldman", first: "Morton", last: "Feldman"} },
      { from: "Fellini, Federico", to: { full: "Federico Fellini", first: "Federico", last: "Fellini"} },
      { from: "Ferguson, Adam", to: { full: "Adam Ferguson", first: "Adam", last: "Ferguson"} },
      { from: "Ferguson, Miriam", to: { full: "Miriam Ferguson", first: "Miriam", last: "Ferguson"} },
      { from: "Fermi, Enrico", to: { full: "Enrico Fermi", first: "Enrico", last: "Fermi"} },
      { from: "Ferrell, Will", to: { full: "Will Ferrell", first: "Will", last: "Ferrell"} },
      { from: "Ferron, Marcelle", to: { full: "Marcelle Ferron", first: "Marcelle", last: "Ferron"} },
      { from: "Fétis, Joseph", to: { full: "Joseph Fétis", first: "Joseph", last: "Fétis"} },
      { from: "Fey, Tina", to: { full: "Tina Fey", first: "Tina", last: "Fey"} },
      { from: "Feynman, Richard", to: { full: "Richard Feynman", first: "Richard", last: "Feynman"} },
      { from: "Fielding, Henry", to: { full: "Henry Fielding", first: "Henry", last: "Fielding"} },
      { from: "Fields, W. C.", to: { full: "W C Fields", first: "W C", last: "Fields"} },
      { from: "Finney, Albert", to: { full: "Albert Finney", first: "Albert", last: "Finney"} },
      { from: "Firestone, Shulamith", to: { full: "Shulamith Firestone", first: "Shulamith", last: "Firestone"} },
      { from: "Fischer, Bobby", to: { full: "Bobby Fischer", first: "Bobby", last: "Fischer"} },
      { from: "Fischer, Joschka", to: { full: "Joschka Fischer", first: "Joschka", last: "Fischer"} },
      { from: "Fish, Michael", to: { full: "Michael Fish", first: "Michael", last: "Fish"} },
      { from: "Fishback, Margaret", to: { full: "Margaret Fishback", first: "Margaret", last: "Fishback"} },
      { from: "Fisher, Carrie", to: { full: "Carrie Fisher", first: "Carrie", last: "Fisher"} },
      { from: "Fiske, Irving", to: { full: "Irving Fiske", first: "Irving", last: "Fiske"} },
      { from: "Fiszer, Franciszek", to: { full: "Franciszek Fiszer", first: "Franciszek", last: "Fiszer"} },
      { from: "Fitzgerald, F. Scott", to: { full: "F Scott Fitzgerald", first: "F Scott", last: "Fitzgerald"} },
      { from: "Fitzgerald, Patrick", to: { full: "Patrick Fitzgerald", first: "Patrick", last: "Fitzgerald"} },
      { from: "Flaubert, Gustave", to: { full: "Gustave Flaubert", first: "Gustave", last: "Flaubert"} },
      { from: "Flynt, Larry", to: { full: "Larry Flynt", first: "Larry", last: "Flynt"} },
      { from: "Foch, Ferdinand", to: { full: "Ferdinand Foch", first: "Ferdinand", last: "Foch"} },
      { from: "Foley, Mick", to: { full: "Mick Foley", first: "Mick", last: "Foley"} },
      { from: "Fonteyn, Margot", to: { full: "Margot Fonteyn", first: "Margot", last: "Fonteyn"} },
      { from: "Forbes, Malcolm", to: { full: "Malcolm Forbes", first: "Malcolm", last: "Forbes"} },
      { from: "Ford, Gerald", to: { full: "Gerald Ford", first: "Gerald", last: "Ford"} },
      { from: "Ford, Harrison", to: { full: "Harrison Ford", first: "Harrison", last: "Ford"} },
      { from: "Ford, Henry", to: { full: "Henry Ford", first: "Henry", last: "Ford"} },
      { from: "Forster, E. M.", to: { full: "E M Forster", first: "E M", last: "Forster"} },
      { from: "Forsyth, Bruce", to: { full: "Bruce Forsyth", first: "Bruce", last: "Forsyth"} },
      { from: "Fort, Charles", to: { full: "Charles Fort", first: "Charles", last: "Fort"} },
      { from: "Fosdick, Harry Emerson", to: { full: "Harry Emerson Fosdick", first: "Harry Emerson", last: "Fosdick"} },
      { from: "Foster, Sir Robert Sidney", to: { full: "Robert Sidney Foster", title: "Sir", first: "Robert Sidney", last: "Foster"} },
      { from: "Fowler, Gene", to: { full: "Gene Fowler", first: "Gene", last: "Fowler"} },
      { from: "Fox, George", to: { full: "George Fox", first: "George", last: "Fox"} },
      { from: "Fox, Virgil", to: { full: "Virgil Fox", first: "Virgil", last: "Fox"} },
      { from: "Foxworthy, Jeff", to: { full: "Jeff Foxworthy", first: "Jeff", last: "Foxworthy"} },
      { from: "France, Anatole", to: { full: "Anatole France", first: "Anatole", last: "France"} },
      { from: "Francona, Terry", to: { full: "Terry Francona", first: "Terry", last: "Francona"} },
      { from: "Franck, Richard", to: { full: "Richard Franck", first: "Richard", last: "Franck"} },
      { from: "Frank, Anne", to: { full: "Anne Frank", first: "Anne", last: "Frank"} },
      { from: "Franklin, Benjamin", to: { full: "Benjamin Franklin", first: "Benjamin", last: "Franklin"} },
      { from: "Franks, Tommy", to: { full: "Tommy Franks", first: "Tommy", last: "Franks"} },
      { from: "Franti, Michael", to: { full: "Michael Franti", first: "Michael", last: "Franti"} },
      { from: "Franzen, Jonathan", to: { full: "Jonathan Franzen", first: "Jonathan", last: "Franzen"} },
      { from: "Freud, Sigmund", to: { full: "Sigmund Freud", first: "Sigmund", last: "Freud"} },
      { from: "Freund, Peter", to: { full: "Peter Freund", first: "Peter", last: "Freund"} },
      { from: "Friedman, Kinky", to: { full: "Kinky Friedman", first: "Kinky", last: "Friedman"} },
      { from: "Friedman, Milton", to: { full: "Milton Friedman", first: "Milton", last: "Friedman"} },
      { from: "Friedman, Nat", to: { full: "Nat Friedman", first: "Nat", last: "Friedman"} },
      { from: "Friel, Todd", to: { full: "Todd Friel", first: "Todd", last: "Friel"} },
      { from: "Frist, Bill", to: { full: "Bill Frist", first: "Bill", last: "Frist"} },
      { from: "Fromm, Erich", to: { full: "Erich Fromm", first: "Erich", last: "Fromm"} },
      { from: "Frost, Robert", to: { full: "Robert Frost", first: "Robert", last: "Frost"} },
      { from: "Frostrup, Mariella", to: { full: "Mariella Frostrup", first: "Mariella", last: "Frostrup"} },
      { from: "Fulbright, J. William", to: { full: "J William Fulbright", first: "J William", last: "Fulbright"} },
      { from: "Fulghum, Robert", to: { full: "Robert Fulghum", first: "Robert", last: "Fulghum"} },
      { from: "Fuller, Buckminster", to: { full: "Buckminster Fuller", first: "Buckminster", last: "Fuller"} },
      { from: "Fuller, Margaret", to: { full: "Margaret Fuller", first: "Margaret", last: "Fuller"} },

      { from: "Gabor, Zsa Zsa", to: { full: "Zsa Zsa Gabor", first: "Zsa Zsa", last: "Gabor"} },
      { from: "Gabriel, Peter", to: { full: "Peter Gabriel", first: "Peter", last: "Gabriel"} },
      { from: "Gagarin, Yuri", to: { full: "Yuri Gagarin", first: "Yuri", last: "Gagarin"} },
      { from: "Gaiman, Neil", to: { full: "Neil Gaiman", first: "Neil", last: "Gaiman"} },
      { from: "Galbraith, John Kenneth", to: { full: "John Kenneth Galbraith", first: "John Kenneth", last: "Galbraith"} },
      { from: "Galilei, Galileo", to: { full: "Galileo Galilei", first: "Galileo", last: "Galilei"} },
      { from: "Gallagher, Fred", to: { full: "Fred Gallagher", first: "Fred", last: "Gallagher"} },
      { from: "Gallo, Vincent Actor", to: { full: "Vincent Actor Gallo", first: "Vincent Actor", last: "Gallo"} },
      { from: "Galloway, George", to: { full: "George Galloway", first: "George", last: "Galloway"} },
      { from: "Gallup, George", to: { full: "George Gallup", first: "George", last: "Gallup"} },
      { from: "Galtieri, Leopoldo", to: { full: "Leopoldo Galtieri", first: "Leopoldo", last: "Galtieri"} },
      { from: "Gandhi, Indira", to: { full: "Indira Gandhi", first: "Indira", last: "Gandhi"} },
      { from: "Gandhi, Mahatma", to: { full: "Mahatma Gandhi", first: "Mahatma", last: "Gandhi"} },
      { from: "Gangchuan, Cao", to: { full: "Cao Gangchuan", first: "Cao", last: "Gangchuan"} },
      { from: "Ganilau, Adi Ateca", to: { full: "Adi Ateca Ganilau", title: "Adi", first: "Ateca", last: "Ganilau"} },
      { from: "Ganilau, Ratu Epeli", to: { full: "Ratu Epeli Ganilau", title: "Ratu", first: "Epeli", last: "Ganilau"} },
      { from: "Ganilau, Ratu Sir Penaia", to: { full: "Ratu Sir Penaia Ganilau", title: "Ratu Sir", first: "Penaia", last: "Ganilau"} },
      { from: "Gardel, Carlos", to: { full: "Carlos Gardel", first: "Carlos", last: "Gardel"} },
      { from: "Garfield, James A.", to: { full: "James A Garfield", first: "James A", last: "Garfield"} },
      { from: "Garland, Judy", to: { full: "Judy Garland", first: "Judy", last: "Garland"} },
      { from: "Garner, Helen", to: { full: "Helen Garner", first: "Helen", last: "Garner"} },
      { from: "Garrison, William Lloyd", to: { full: "William Lloyd Garrison", first: "William Lloyd", last: "Garrison"} },
      { from: "Gary, Romain", to: { full: "Romain Gary", first: "Romain", last: "Gary"} },
      { from: "Gassée, Jean-Louis", to: { full: "Jean-Louis Gassée", first: "Jean-Louis", last: "Gassée"} },
      { from: "Gates, Bill", to: { full: "Bill Gates", first: "Bill", last: "Gates"} },
      { from: "Gaudi, Antonio", to: { full: "Antonio Gaudi", first: "Antonio", last: "Gaudi"} },
      { from: "Gauguin, Paul", to: { full: "Paul Gauguin", first: "Paul", last: "Gauguin"} },
      { from: "Gaulle, Charles de", to: { full: "Charles de Gaulle", first: "Charles", last: "de Gaulle"} },
      { from: "Gaultier, Jules de", to: { full: "Jules de Gaultier", first: "Jules", last: "de Gaultier"} },
      { from: "Gauss, Carl Friedrich", to: { full: "Carl Friedrich Gauss", first: "Carl Friedrich", last: "Gauss"} },
      { from: "Gay, John", to: { full: "John Gay", first: "John", last: "Gay"} },
      { from: "Gaye, Marvin", to: { full: "Marvin Gaye", first: "Marvin", last: "Gaye"} },
      { from: "Geagea, Samir", to: { full: "Samir Geagea", first: "Samir", last: "Geagea"} },
      { from: "Gemayel, Solange", to: { full: "Solange Gemayel", first: "Solange", last: "Gemayel"} },
      { from: "Genet, Jean", to: { full: "Jean Genet", first: "Jean", last: "Genet"} },
      { skip: "Haven't figured this one yet",
        from: "George III, King of England", to: { full: "King of England George III", first: "King of England", last: "George III"} },
      { skip: "Haven't figured this one yet",
        from: "George V, King of England", to: { full: "King of England George V", first: "King of England", last: "George V"} },
      { from: "Gephardt, Dick", to: { full: "Dick Gephardt", first: "Dick", last: "Gephardt"} },
      { from: "Gerety, Frances", to: { full: "Frances Gerety", first: "Frances", last: "Gerety"} },
      { from: "Gergen, David", to: { full: "David Gergen", first: "David", last: "Gergen"} },
      { from: "Giacometti, Alberto", to: { full: "Alberto Giacometti", first: "Alberto", last: "Giacometti"} },
      { from: "Gibbon, Edward", to: { full: "Edward Gibbon", first: "Edward", last: "Gibbon"} },
      { from: "Gibran, Khalil", to: { full: "Khalil Gibran", first: "Khalil", last: "Gibran"} },
      { from: "Gibson, William Ford", to: { full: "William Ford Gibson", first: "William Ford", last: "Gibson"} },
      { from: "Gide, André", to: { full: "André Gide", first: "André", last: "Gide"} },
      { from: "Gilbert, W. S.", to: { full: "W S Gilbert", first: "W S", last: "Gilbert"} },
      { from: "Gilder, George", to: { full: "George Gilder", first: "George", last: "Gilder"} },
      { from: "Gill, Eric", to: { full: "Eric Gill", first: "Eric", last: "Gill"} },
      { from: "Gilmore, John", to: { full: "John Gilmore", first: "John", last: "Gilmore"} },
      { from: "Ginott, Haim", to: { full: "Haim Ginott", first: "Haim", last: "Ginott"} },
      { from: "Giraudoux, Jean", to: { full: "Jean Giraudoux", first: "Jean", last: "Giraudoux"} },
      { from: "Giuliani, Rudy", to: { full: "Rudy Giuliani", first: "Rudy", last: "Giuliani"} },
      { from: "Gladstone, William Ewart", to: { full: "William Ewart Gladstone", first: "William Ewart", last: "Gladstone"} },
      { from: "Godard, Jean-Luc", to: { full: "Jean-Luc Godard", first: "Jean-Luc", last: "Godard"} },
      { from: "Godwin, Earl of Wessex", to: { full: "Earl of Wessex Godwin", first: "Earl of Wessex", last: "Godwin"} },
      { from: "Godwin, Mike", to: { full: "Mike Godwin", first: "Mike", last: "Godwin"} },
      { from: "Goering, Hermann", to: { full: "Hermann Goering", first: "Hermann", last: "Goering"} },
      { from: "Goethe, Johann Wolfgang von", to: { full: "Johann Wolfgang von Goethe", first: "Johann Wolfgang", last: "von Goethe"} },
      { from: "Gogh, Vincent Willem Van", to: { full: "Vincent Willem Van Gogh", first: "Vincent Willem", last: "Van Gogh"} },
      { from: "Gogol, Nikolai Vasilievich", to: { full: "Nikolai Vasilievich Gogol", first: "Nikolai Vasilievich", last: "Gogol"} },
      { from: "Goldberg, Jonah", to: { full: "Jonah Goldberg", first: "Jonah", last: "Goldberg"} },
      { from: "Golding, William", to: { full: "William Golding", first: "William", last: "Golding"} },
      { from: "Goldman, Emma", to: { full: "Emma Goldman", first: "Emma", last: "Goldman"} },
      { from: "Goldsmith, Oliver", to: { full: "Oliver Goldsmith", first: "Oliver", last: "Goldsmith"} },
      { from: "Goldsworthy, Andy", to: { full: "Andy Goldsworthy", first: "Andy", last: "Goldsworthy"} },
      { from: "Goldwater, Barry", to: { full: "Barry Goldwater", first: "Barry", last: "Goldwater"} },
      { from: "Goldwyn, Samuel", to: { full: "Samuel Goldwyn", first: "Samuel", last: "Goldwyn"} },
      { from: "Goodman, Ellen", to: { full: "Ellen Goodman", first: "Ellen", last: "Goodman"} },
      { from: "Gorky, Maxim", to: { full: "Maxim Gorky", first: "Maxim", last: "Gorky"} },
      { from: "Göring, Hermann", to: { full: "Hermann Göring", first: "Hermann", last: "Göring"} },
      { from: "Gothard, Bill", to: { full: "Bill Gothard", first: "Bill", last: "Gothard"} },
      { from: "Gould, Stephen Jay", to: { full: "Stephen Jay Gould", first: "Stephen Jay", last: "Gould"} },
      { from: "Goya, Francisco", to: { full: "Francisco Goya", first: "Francisco", last: "Goya"} },
      { from: "Gracián, Baltasar", to: { full: "Baltasar Gracián", first: "Baltasar", last: "Gracián"} },
      { from: "Graham, Lindsey", to: { full: "Lindsey Graham", first: "Lindsey", last: "Graham"} },
      { from: "Graham, Paul", to: { full: "Paul Graham", first: "Paul", last: "Graham"} },
      { from: "Gramsci, Antonio", to: { full: "Antonio Gramsci", first: "Antonio", last: "Gramsci"} },
      { from: "Grant, Ulysses S.", to: { full: "Ulysses S Grant", first: "Ulysses S", last: "Grant"} },
      { from: "Grass, Günter", to: { full: "Günter Grass", first: "Günter", last: "Grass"} },
      { from: "Gray, Thomas", to: { full: "Thomas Gray", first: "Thomas", last: "Gray"} },
      { from: "Greeley, Horace", to: { full: "Horace Greeley", first: "Horace", last: "Greeley"} },
      { from: "Green, Matthew", to: { full: "Matthew Green", first: "Matthew", last: "Green"} },
      { from: "Greene, Graham", to: { full: "Graham Greene", first: "Graham", last: "Greene"} },
      { from: "Greer, Germaine", to: { full: "Germaine Greer", first: "Germaine", last: "Greer"} },
      { from: "Grellet, Stephen", to: { full: "Stephen Grellet", first: "Stephen", last: "Grellet"} },
      { from: "Grey, Zane", to: { full: "Zane Grey", first: "Zane", last: "Grey"} },
      { from: "Griswold, Alfred Whitney", to: { full: "Alfred Whitney Griswold", first: "Alfred Whitney", last: "Griswold"} },
      { from: "Griswold, Erwin", to: { full: "Erwin Griswold", first: "Erwin", last: "Griswold"} },
      { from: "Groban, Josh", to: { full: "Josh Groban", first: "Josh", last: "Groban"} },
      { from: "Groening, Matt", to: { full: "Matt Groening", first: "Matt", last: "Groening"} },
      { from: "Grove, Andy", to: { full: "Andy Grove", first: "Andy", last: "Grove"} },
      { from: "Grudin, Robert", to: { full: "Robert Grudin", first: "Robert", last: "Grudin"} },
      { from: "Guber, Peter", to: { full: "Peter Guber", first: "Peter", last: "Guber"} },
      { from: "Guderian, Heinz", to: { full: "Heinz Guderian", first: "Heinz", last: "Guderian"} },
      { from: "Guevara, Ernesto 'Che'", to: { full: "Ernesto 'Che' Guevara", first: "Ernesto", nick: "Che", last: "Guevara"} },
      { from: "Guitry, Sacha", to: { full: "Sacha Guitry", first: "Sacha", last: "Guitry"} },
      { from: "Gundmundsdottir, Bjork", to: { full: "Bjork Gundmundsdottir", first: "Bjork", last: "Gundmundsdottir"} },
      { from: "Gurdjieff, G. I.", to: { full: "G I Gurdjieff", first: "G I", last: "Gurdjieff"} },
      { from: "Gygax, Gary", to: { full: "Gary Gygax", first: "Gary", last: "Gygax"} },
      { from: "Gyllenhaal, Jake", to: { full: "Jake Gyllenhaal", first: "Jake", last: "Gyllenhaal"} },

      { from: "Hába, Alois", to: { full: "Alois Hába", first: "Alois", last: "Hába"} },
      { from: "Hague, Frank", to: { full: "Frank Hague", first: "Frank", last: "Hague"} },
      { from: "Haig, Alexander", to: { full: "Alexander Haig", first: "Alexander", last: "Haig"} },
      { from: "Hain, Peter", to: { full: "Peter Hain", first: "Peter", last: "Hain"} },
      { from: "Halas, George", to: { full: "George Halas", first: "George", last: "Halas"} },
      { from: "Haldeman, Joe", to: { full: "Joe Haldeman", first: "Joe", last: "Haldeman"} },
      { from: "Haley, Alex", to: { full: "Alex Haley", first: "Alex", last: "Haley"} },
      { from: "Halliburton, Richard", to: { full: "Richard Halliburton", first: "Richard", last: "Halliburton"} },
      { from: "Halme, Tony", to: { full: "Tony Halme", first: "Tony", last: "Halme"} },
      { from: "Halsey, William \"Bull\"", to: { full: "William Halsey", first: "William", nick: "Bull", last: "Halsey"} },
      { from: "Hamilton, Alexander", to: { full: "Alexander Hamilton", first: "Alexander", last: "Hamilton"} },
      { from: "Hamilton, Gail", to: { full: "Gail Hamilton", first: "Gail", last: "Hamilton"} },
      { from: "Hamilton, Laurell K.", to: { full: "Laurell K Hamilton", first: "Laurell K", last: "Hamilton"} },
      { from: "Hammarskjöld, Dag", to: { full: "Dag Hammarskjöld", first: "Dag", last: "Hammarskjöld"} },
      { from: "Handy, Charles", to: { full: "Charles Handy", first: "Charles", last: "Handy"} },
      { from: "Handy, W. C.", to: { full: "W C Handy", first: "W C", last: "Handy"} },
      { from: "Hannity, Sean", to: { full: "Sean Hannity", first: "Sean", last: "Hannity"} },
      { skip: "Haven't figured this one yet",
        from: "Harold II Godwinson, King of England", to: { full: "King of England Harold II Godwinson", first: "King of England", last: "Harold II Godwinson"} },
      { from: "Harper, Stephen", to: { full: "Stephen Harper", first: "Stephen", last: "Harper"} },
      { from: "Harris, Sam", to: { full: "Sam Harris", first: "Sam", last: "Harris"} },
      { from: "Harris, William Torrey", to: { full: "William Torrey Harris", first: "William Torrey", last: "Harris"} },
      { from: "Harrison, George", to: { full: "George Harrison", first: "George", last: "Harrison"} },
      { from: "Hart, Lorenz", to: { full: "Lorenz Hart", first: "Lorenz", last: "Hart"} },
      { from: "Hart, Owen", to: { full: "Owen Hart", first: "Owen", last: "Hart"} },
      { from: "Harvey, Paul", to: { full: "Paul Harvey", first: "Paul", last: "Harvey"} },
      { from: "Hašek, Jaroslav", to: { full: "Jaroslav Hašek", first: "Jaroslav", last: "Hašek"} },
      { from: "Hathaway, Anne", to: { full: "Anne Hathaway", first: "Anne", last: "Hathaway"} },
      { from: "Hathaway, Sybil", to: { full: "Sybil Hathaway", first: "Sybil", last: "Hathaway"} },
      { from: "Hattersley, Roy", to: { full: "Roy Hattersley", first: "Roy", last: "Hattersley"} },
      { from: "Havel, Václav", to: { full: "Václav Havel", first: "Václav", last: "Havel"} },
      { from: "Havok, Davey", to: { full: "Davey Havok", first: "Davey", last: "Havok"} },
      { from: "Hawking, Stephen", to: { full: "Stephen Hawking", first: "Stephen", last: "Hawking"} },
      { from: "Hawthorne, Nathaniel", to: { full: "Nathaniel Hawthorne", first: "Nathaniel", last: "Hawthorne"} },
      { from: "Hayden, Teresa Nielson", to: { full: "Teresa Nielson Hayden", first: "Teresa Nielson", last: "Hayden"} },
      { from: "Hayek, Friedrich", to: { full: "Friedrich Hayek", first: "Friedrich", last: "Hayek"} },
      { from: "Hayes, Helen", to: { full: "Helen Hayes", first: "Helen", last: "Hayes"} },
      { from: "Hazlitt, William", to: { full: "William Hazlitt", first: "William", last: "Hazlitt"} },
      { from: "Hedberg, Mitch", to: { full: "Mitch Hedberg", first: "Mitch", last: "Hedberg"} },
      { from: "Hedges, Chris", to: { full: "Chris Hedges", first: "Chris", last: "Hedges"} },
      { from: "Hegel, Georg Friedrich Wilhelm", to: { full: "Georg Friedrich Wilhelm Hegel", first: "Georg Friedrich Wilhelm", last: "Hegel"} },
      { from: "Heifetz, Jascha", to: { full: "Jascha Heifetz", first: "Jascha", last: "Heifetz"} },
      { from: "Heilbrun, Carolyn", to: { full: "Carolyn Heilbrun", first: "Carolyn", last: "Heilbrun"} },
      { from: "Hein, Piet", to: { full: "Piet Hein", first: "Piet", last: "Hein"} },
      { from: "Heindel, Max", to: { full: "Max Heindel", first: "Max", last: "Heindel"} },
      { from: "Heinlein, Robert A.", to: { full: "Robert A Heinlein", first: "Robert A", last: "Heinlein"} },
      { from: "Heine, Heinrich", to: { full: "Heinrich Heine", first: "Heinrich", last: "Heine"} },
      { from: "Heisenberg, Werner", to: { full: "Werner Heisenberg", first: "Werner", last: "Heisenberg"} },
      { from: "Held, John", to: { full: "John Held", first: "John", last: "Held"} },
      { from: "Heller, Joseph", to: { full: "Joseph Heller", first: "Joseph", last: "Heller"} },
      { from: "Hellman, Lillian", to: { full: "Lillian Hellman", first: "Lillian", last: "Hellman"} },
      { from: "Hemingway, Ernest", to: { full: "Ernest Hemingway", first: "Ernest", last: "Hemingway"} },
      { from: "Henderson, Rickey", to: { full: "Rickey Henderson", first: "Rickey", last: "Henderson"} },
      { from: "Hendrie, Phil", to: { full: "Phil Hendrie", first: "Phil", last: "Hendrie"} },
      { from: "Hendrix, Jimi", to: { full: "Jimi Hendrix", first: "Jimi", last: "Hendrix"} },
      { from: "Hennessey, Ammon", to: { full: "Ammon Hennessey", first: "Ammon", last: "Hennessey"} },
      { from: "Henry, Matthew", to: { full: "Matthew Henry", first: "Matthew", last: "Henry"} },
      { from: "Henry, O.", to: { full: "O Henry", first: "O", last: "Henry"} },
      { from: "Henry, Patrick", to: { full: "Patrick Henry", first: "Patrick", last: "Henry"} },
      { from: "Hepburn, Audrey", to: { full: "Audrey Hepburn", first: "Audrey", last: "Hepburn"} },
      { from: "Hepburn, Katherine", to: { full: "Katherine Hepburn", first: "Katherine", last: "Hepburn"} },
      { from: "Herbert, George", to: { full: "George Herbert", first: "George", last: "Herbert"} },
      { from: "Herbert, Zbigniew", to: { full: "Zbigniew Herbert", first: "Zbigniew", last: "Herbert"} },
      { from: "Hernández, Julián", to: { full: "Julián Hernández", first: "Julián", last: "Hernández"} },
      { from: "Herschel, John", to: { full: "John Herschel", first: "John", last: "Herschel"} },
      { from: "Herzler, Roger D", to: { full: "Roger D Herzler", first: "Roger D", last: "Herzler"} },
      { from: "Herzog, Werner", to: { full: "Werner Herzog", first: "Werner", last: "Herzog"} },
      { from: "Heschel, Abraham Joshua", to: { full: "Abraham Joshua Heschel", first: "Abraham Joshua", last: "Heschel"} },
      { from: "Hess, Karl", to: { full: "Karl Hess", first: "Karl", last: "Hess"} },
      { from: "Hesse, Hermann", to: { full: "Hermann Hesse", first: "Hermann", last: "Hesse"} },
      { from: "Hewitt, Hugh", to: { full: "Hugh Hewitt", first: "Hugh", last: "Hewitt"} },
      { from: "Heywood, John", to: { full: "John Heywood", first: "John", last: "Heywood"} },
      { from: "Hibiki, Dan", to: { full: "Dan Hibiki", first: "Dan", last: "Hibiki"} },
      { from: "Hickenbottom, Michael", to: { full: "Michael Hickenbottom", first: "Michael", last: "Hickenbottom"} },
      { from: "Hicks, Bill", to: { full: "Bill Hicks", first: "Bill", last: "Hicks"} },
      { from: "Hicks, Dan", to: { full: "Dan Hicks", first: "Dan", last: "Hicks"} },
      { from: "Hightower, Jim", to: { full: "Jim Hightower", first: "Jim", last: "Hightower"} },
      { from: "Hikmet, Nazim", to: { full: "Nazim Hikmet", first: "Nazim", last: "Hikmet"} },
      { from: "Hill, Joe", to: { full: "Joe Hill", first: "Joe", last: "Hill"} },
      { from: "Hill, Napoleon", to: { full: "Napoleon Hill", first: "Napoleon", last: "Hill"} },
      { from: "Hillary, Edmund", to: { full: "Edmund Hillary", first: "Edmund", last: "Hillary"} },
      { from: "Hirsch, Mary", to: { full: "Mary Hirsch", first: "Mary", last: "Hirsch"} },
      { from: "Hitchens, Christopher", to: { full: "Christopher Hitchens", first: "Christopher", last: "Hitchens"} },
      { from: "Hitchcock, Alfred", to: { full: "Alfred Hitchcock", first: "Alfred", last: "Hitchcock"} },
      { from: "Hitler, Adolf", to: { full: "Adolf Hitler", first: "Adolf", last: "Hitler"} },
      { from: "Hobbes, Thomas", to: { full: "Thomas Hobbes", first: "Thomas", last: "Hobbes"} },
      { from: "Hoff, Benjamin", to: { full: "Benjamin Hoff", first: "Benjamin", last: "Hoff"} },
      { from: "Hoffer, Eric", to: { full: "Eric Hoffer", first: "Eric", last: "Hoffer"} },
      { from: "Hoffman, Abbie", to: { full: "Abbie Hoffman", first: "Abbie", last: "Hoffman"} },
      { from: "Hoffman, Jessica", to: { full: "Jessica Hoffman", first: "Jessica", last: "Hoffman"} },
      { from: "Hofstadter, Douglas", to: { full: "Douglas Hofstadter", first: "Douglas", last: "Hofstadter"} },
      { from: "Hofstadter, Richard", to: { full: "Richard Hofstadter", first: "Richard", last: "Hofstadter"} },
      { from: "Holderlin, Friedrich", to: { full: "Friedrich Holderlin", first: "Friedrich", last: "Holderlin"} },
      { from: "Holmes, Oliver Wendell, Jr.", to: { full: "Oliver Wendell Holmes Jr", first: "Oliver Wendell", last: "Holmes", suffix: "Jr"} },
      { from: "Holmes, Oliver Wendell, Sr.", to: { full: "Oliver Wendell Holmes Sr", first: "Oliver Wendell", last: "Holmes", suffix: "Sr"} },
      { from: "Holt, Anatol", to: { full: "Anatol Holt", first: "Anatol", last: "Holt"} },
      { from: "Holt, John", to: { full: "John Holt", first: "John", last: "Holt"} },
      { from: "Honda, Soichiro", to: { full: "Soichiro Honda", first: "Soichiro", last: "Honda"} },
      { from: "Hoover, Herbert", to: { full: "Herbert Hoover", first: "Herbert", last: "Hoover"} },
      { from: "Hope, Bob", to: { full: "Bob Hope", first: "Bob", last: "Hope"} },
      { from: "Hopkins, Gerard Manley", to: { full: "Gerard Manley Hopkins", first: "Gerard Manley", last: "Hopkins"} },
      { from: "Hopper, Edward", to: { full: "Edward Hopper", first: "Edward", last: "Hopper"} },
      { from: "Hopper, Grace", to: { full: "Grace Hopper", first: "Grace", last: "Hopper"} },
      { from: "Horning, Jim", to: { full: "Jim Horning", first: "Jim", last: "Horning"} },
      { from: "Houdini, Harry", to: { full: "Harry Houdini", first: "Harry", last: "Houdini"} },
      { from: "House, Jinnah", to: { full: "Jinnah House", first: "Jinnah", last: "House"} },
      { from: "Housman, A. E.", to: { full: "A E Housman", first: "A E", last: "Housman"} },
      { from: "Howe, Julia Ward", to: { full: "Julia Ward Howe", first: "Julia Ward", last: "Howe"} },
      { from: "Howell, James", to: { full: "James Howell", first: "James", last: "Howell"} },
      { from: "Hoyle, Fred", to: { full: "Fred Hoyle", first: "Fred", last: "Hoyle"} },
      { from: "Hubbard, Elbert", to: { full: "Elbert Hubbard", first: "Elbert", last: "Hubbard"} },
      { from: "Hubbard, L. Ron", to: { full: "L Ron Hubbard", first: "L Ron", last: "Hubbard"} },
      { from: "Huckabee, Mike", to: { full: "Mike Huckabee", first: "Mike", last: "Huckabee"} },
      { from: "Huelskamp, Tim", to: { full: "Tim Huelskamp", first: "Tim", last: "Huelskamp"} },
      { from: "Huffington, Arianna", to: { full: "Arianna Huffington", first: "Arianna", last: "Huffington"} },
      { from: "Hughes, Charles Evans", to: { full: "Charles Evans Hughes", first: "Charles Evans", last: "Hughes"} },
      { from: "Hugo, Victor", to: { full: "Victor Hugo", first: "Victor", last: "Hugo"} },
      { from: "Hull, Bobby", to: { full: "Bobby Hull", first: "Bobby", last: "Hull"} },
      { from: "Hull, Cordell", to: { full: "Cordell Hull", first: "Cordell", last: "Hull"} },
      { from: "Humboldt, Alexander von", to: { full: "Alexander von Humboldt", first: "Alexander", last: "von Humboldt"} },
      { from: "Humboldt, Wilhelm von", to: { full: "Wilhelm von Humboldt", first: "Wilhelm", last: "von Humboldt"} },
      { from: "Hume, David", to: { full: "David Hume", first: "David", last: "Hume"} },
      { from: "Hundertwasser, Friedensreich", to: { full: "Friedensreich Hundertwasser", first: "Friedensreich", last: "Hundertwasser"} },
      { from: "Hung, William", to: { full: "William Hung", first: "William", last: "Hung"} },
      { from: "Hunt, J. McV.", to: { full: "J McV Hunt", first: "J McV", last: "Hunt"} },
      { from: "Hurston, Zora Neale", to: { full: "Zora Neale Hurston", first: "Zora Neale", last: "Hurston"} },
      { from: "Hussein, Saddam", to: { full: "Saddam Hussein", first: "Saddam", last: "Hussein"} },
      { from: "Hutcheson, Francis", to: { full: "Francis Hutcheson", first: "Francis", last: "Hutcheson"} },
      { from: "Hutchinson, Thomas", to: { full: "Thomas Hutchinson", first: "Thomas", last: "Hutchinson"} },
      { from: "Hutton, James", to: { full: "James Hutton", first: "James", last: "Hutton"} },
      { from: "Huxley, Aldous", to: { full: "Aldous Huxley", first: "Aldous", last: "Huxley"} },
      { from: "Huxley, Julian", to: { full: "Julian Huxley", first: "Julian", last: "Huxley"} },
      { from: "Huxley, Thomas Henry", to: { full: "Thomas Henry Huxley", first: "Thomas Henry", last: "Huxley"} },
      { from: "Huygens, Christian", to: { full: "Christian Huygens", first: "Christian", last: "Huygens"} },
      { from: "Hyles, Jack", to: { full: "Jack Hyles", first: "Jack", last: "Hyles"} },
      { from: "Hyson, Matt", to: { full: "Matt Hyson", first: "Matt", last: "Hyson"} },

      { from: "Iacocca, Lee", to: { full: "Lee Iacocca", first: "Lee", last: "Iacocca"} },
      { from: "Ibsen, Henrik", to: { full: "Henrik Ibsen", first: "Henrik", last: "Ibsen"} },
      { from: "ibn Abi Talib, Ali", to: { full: "Ali ibn Abi Talib", first: "Ali", last: "ibn Abi Talib"} },
      { from: "ibn Abī Ṭālib, Alī", to: { full: "Alī ibn Abī Ṭālib", first: "Alī", last: "ibn Abī Ṭālib"} },
      { from: "Icke, David", to: { full: "David Icke", first: "David", last: "Icke"} },
      { from: "Idle, Eric", to: { full: "Eric Idle", first: "Eric", last: "Idle"} },
      { from: "Iloilo, Ratu Josefa", to: { full: "Ratu Josefa Iloilo", title: "Ratu", first: "Josefa", last: "Iloilo"} },
      { from: "Inge, William Ralph", to: { full: "William Ralph Inge", first: "William Ralph", last: "Inge"} },
      { from: "Ingelow, Jean", to: { full: "Jean Ingelow", first: "Jean", last: "Ingelow"} },
      { from: "Ingersoll, Robert G.", to: { full: "Robert G Ingersoll", first: "Robert G", last: "Ingersoll"} },
      { from: "Ionesco, Eugene", to: { full: "Eugene Ionesco", first: "Eugene", last: "Ionesco"} },
      { from: "Ip, Regina", to: { full: "Regina Ip", first: "Regina", last: "Ip"} },
      { from: "Irvine, Eddie", to: { full: "Eddie Irvine", first: "Eddie", last: "Irvine"} },
      { from: "Ishihara, Shintaro", to: { full: "Shintaro Ishihara", first: "Shintaro", last: "Ishihara"} },
      { from: "Itoi, Shigesato", to: { full: "Shigesato Itoi", first: "Shigesato", last: "Itoi"} },
      { from: "Izzard, Eddie", to: { full: "Eddie Izzard", first: "Eddie", last: "Izzard"} },

      { from: "Jäätteenmäki, Anneli", to: { full: "Anneli Jäätteenmäki", first: "Anneli", last: "Jäätteenmäki"} },
      { from: "Jackson, Andrew", to: { full: "Andrew Jackson", first: "Andrew", last: "Jackson"} },
      { from: "Jackson, Janet", to: { full: "Janet Jackson", first: "Janet", last: "Jackson"} },
      { from: "Jackson, Jesse", to: { full: "Jesse Jackson", first: "Jesse", last: "Jackson"} },
      { from: "Jackson, Michael", to: { full: "Michael Jackson", first: "Michael", last: "Jackson"} },
      { from: "Jackson, Robert H.", to: { full: "Robert H Jackson", first: "Robert H", last: "Jackson"} },
      { from: "Jaffe, Bob", to: { full: "Bob Jaffe", first: "Bob", last: "Jaffe"} },
      { from: "James, Alice", to: { full: "Alice James", first: "Alice", last: "James"} },
      { from: "James, C. L. R.", to: { full: "C L R James", first: "C L R", last: "James"} },
      { from: "James, Donald", to: { full: "Donald James", first: "Donald", last: "James"} },
      { from: "James, Henry", to: { full: "Henry James", first: "Henry", last: "James"} },
      { from: "James, Kevin", to: { full: "Kevin James", first: "Kevin", last: "James"} },
      { from: "James, William", to: { full: "William James", first: "William", last: "James"} },
      { from: "Janáček, Leoš", to: { full: "Leoš Janáček", first: "Leoš", last: "Janáček"} },
      { from: "Jarrell, Randall", to: { full: "Randall Jarrell", first: "Randall", last: "Jarrell"} },
      { from: "Jarrett, Jeff", to: { full: "Jeff Jarrett", first: "Jeff", last: "Jarrett"} },
      { skip: "Too many commas!",
        from: "Jay, Glenn, Miner", to: { full: "Miner Jay, Glenn", first: "Miner", last: "Jay, Glenn"} },
      { from: "Jarry, Alfred", to: { full: "Alfred Jarry", first: "Alfred", last: "Jarry"} },
      { from: "Jeffers, Robinson", to: { full: "Robinson Jeffers", first: "Robinson", last: "Jeffers"} },
      { from: "Jefferson, Thomas", to: { full: "Thomas Jefferson", first: "Thomas", last: "Jefferson"} },
      { from: "Jelinek, Fred", to: { full: "Fred Jelinek", first: "Fred", last: "Jelinek"} },
      { from: "Jenner, Henry", to: { full: "Henry Jenner", first: "Henry", last: "Jenner"} },
      { from: "Jennings, Peter", to: { full: "Peter Jennings", first: "Peter", last: "Jennings"} },
      { from: "Jensen, Derrick", to: { full: "Derrick Jensen", first: "Derrick", last: "Jensen"} },
      { from: "Jensen, Hayley", to: { full: "Hayley Jensen", first: "Hayley", last: "Jensen"} },
      { from: "Jeter, Derek", to: { full: "Derek Jeter", first: "Derek", last: "Jeter"} },
      { from: "Jillette, Penn", to: { full: "Penn Jillette", first: "Penn", last: "Jillette"} },
      { from: "Jobs, Steve", to: { full: "Steve Jobs", first: "Steve", last: "Jobs"} },
      { from: "Johns, Michael", to: { full: "Michael Johns", first: "Michael", last: "Johns"} },
      { from: "Johnson, Boris", to: { full: "Boris Johnson", first: "Boris", last: "Johnson"} },
      { from: "Johnson, Lyndon", to: { full: "Lyndon Johnson", first: "Lyndon", last: "Johnson"} },
      { from: "Johnson, Philip", to: { full: "Philip Johnson", first: "Philip", last: "Johnson"} },
      { from: "Johnson, Samuel", to: { full: "Samuel Johnson", first: "Samuel", last: "Johnson"} },
      { from: "Johnson, Susan (Australian)", to: { full: "Susan (Australian) Johnson", first: "Susan", nick: "Australian", last: "Johnson"} },
      { from: "Johnson, Zach", to: { full: "Zach Johnson", first: "Zach", last: "Johnson"} },
      { from: "Jolie, Angelina", to: { full: "Angelina Jolie", first: "Angelina", last: "Jolie"} },
      { from: "Jones, John Paul", to: { full: "John Paul Jones", first: "John Paul", last: "Jones"} },
      { from: "Jones, Norah", to: { full: "Norah Jones", first: "Norah", last: "Jones"} },
      { from: "Jones, Orlando", to: { full: "Orlando Jones", first: "Orlando", last: "Jones"} },
      { from: "Jong, Erica", to: { full: "Erica Jong", first: "Erica", last: "Jong"} },
      { from: "Jonson, Ben", to: { full: "Ben Jonson", first: "Ben", last: "Jonson"} },
      { from: "Joplin, Janis", to: { full: "Janis Joplin", first: "Janis", last: "Joplin"} },
      { from: "Jordan, Sandra", to: { full: "Sandra Jordan", first: "Sandra", last: "Jordan"} },
      { from: "Joseph, Chief", to: { full: "Chief Joseph", first: "Chief", last: "Joseph"} },
      { from: "Joshi, Kedar", to: { full: "Kedar Joshi", first: "Kedar", last: "Joshi"} },
      { from: "Joubert, Joseph", to: { full: "Joseph Joubert", first: "Joseph", last: "Joubert"} },
      { from: "Joyce, James", to: { full: "James Joyce", first: "James", last: "Joyce"} },
      { from: "Juárez, Benito", to: { full: "Benito Juárez", first: "Benito", last: "Juárez"} },
      { from: "Judd, Ashley", to: { full: "Ashley Judd", first: "Ashley", last: "Judd"} },
      { from: "Jueneman, Frederic", to: { full: "Frederic Jueneman", first: "Frederic", last: "Jueneman"} },
      { from: "Jackson, Michael", to: { full: "Michael Jackson", first: "Michael", last: "Jackson"} },
      { from: "Jung, Carl", to: { full: "Carl Jung", first: "Carl", last: "Jung"} },
      { from: "Junge, Traudl", to: { full: "Traudl Junge", first: "Traudl", last: "Junge"} },
      { from: "Juyi, Bai", to: { full: "Bai Juyi", first: "Bai", last: "Juyi"} },

      { from: "Kaczynski, Lech", to: { full: "Lech Kaczynski", first: "Lech", last: "Kaczynski"} },
      { from: "Kael, Pauline", to: { full: "Pauline Kael", first: "Pauline", last: "Kael"} },
      { from: "Kafka, Franz", to: { full: "Franz Kafka", first: "Franz", last: "Kafka"} },
      { from: "Kahlo, Frida", to: { full: "Frida Kahlo", first: "Frida", last: "Kahlo"} },
      { from: "Kak, Subhash", to: { full: "Subhash Kak", first: "Subhash", last: "Kak"} },
      { from: "Kalam, APJ Abdul", to: { full: "APJ Abdul Kalam", first: "APJ Abdul", last: "Kalam"} },
      { from: "Kant, Immanuel", to: { full: "Immanuel Kant", first: "Immanuel", last: "Kant"} },
      { from: "Kapell, William", to: { full: "William Kapell", first: "William", last: "Kapell"} },
      { from: "Kapuściński, Ryszard", to: { full: "Ryszard Kapuściński", first: "Ryszard", last: "Kapuściński"} },
      { from: "Karenga, Ron", to: { full: "Ron Karenga", first: "Ron", last: "Karenga"} },
      { from: "Karzai, Hamid", to: { full: "Hamid Karzai", first: "Hamid", last: "Karzai"} },
      { from: "Kasparov, Garry", to: { full: "Garry Kasparov", first: "Garry", last: "Kasparov"} },
      { from: "Katz, Jonathan", to: { full: "Jonathan Katz", first: "Jonathan", last: "Katz"} },
      { from: "Kawabata, Yasunari", to: { full: "Yasunari Kawabata", first: "Yasunari", last: "Kawabata"} },
      { from: "Kawohl, Kurt", to: { full: "Kurt Kawohl", first: "Kurt", last: "Kawohl"} },
      { from: "Kay, Alan", to: { full: "Alan Kay", first: "Alan", last: "Kay"} },
      { from: "Kay, Ken", to: { full: "Ken Kay", first: "Ken", last: "Kay"} },
      { from: "Kazantzakis, Nikos", to: { full: "Nikos Kazantzakis", first: "Nikos", last: "Kazantzakis"} },
      { from: "Keats, John", to: { full: "John Keats", first: "John", last: "Keats"} },
      { from: "Keating, Paul", to: { full: "Paul Keating", first: "Paul", last: "Keating"} },
      { from: "Keaton, Buster", to: { full: "Buster Keaton", first: "Buster", last: "Keaton"} },
      { from: "Keel, John", to: { full: "John Keel", first: "John", last: "Keel"} },
      { from: "Keeping, Charles", to: { full: "Charles Keeping", first: "Charles", last: "Keeping"} },
      { from: "Keillor, Garrison", to: { full: "Garrison Keillor", first: "Garrison", last: "Keillor"} },
      { from: "Keller, Helen", to: { full: "Helen Keller", first: "Helen", last: "Keller"} },
      { from: "Kellner, Friedrich", to: { full: "Friedrich Kellner", first: "Friedrich", last: "Kellner"} },
      { from: "Kelly, Walt", to: { full: "Walt Kelly", first: "Walt", last: "Kelly"} },
      { from: "Kempton, Murray", to: { full: "Murray Kempton", first: "Murray", last: "Kempton"} },
      { from: "Kelvin, Lord", to: { full: "Lord Kelvin", title: "Lord", last: "Kelvin"} },
      { from: "Kendrick, Alex", to: { full: "Alex Kendrick", first: "Alex", last: "Kendrick"} },
      { from: "Kennan, George F.", to: { full: "George F Kennan", first: "George F", last: "Kennan"} },
      { from: "Kennedy, Anthony", to: { full: "Anthony Kennedy", first: "Anthony", last: "Kennedy"} },
      { from: "Kennedy, Edward", to: { full: "Edward Kennedy", first: "Edward", last: "Kennedy"} },
      { from: "Kennedy, John F.", to: { full: "John F Kennedy", first: "John F", last: "Kennedy"} },
      { from: "Kennedy, Robert", to: { full: "Robert Kennedy", first: "Robert", last: "Kennedy"} },
      { from: "Kennedy, Robert F.", to: { full: "Robert F Kennedy", first: "Robert F", last: "Kennedy"} },
      { from: "Kennedy, Robert Francis Jr.", to: { full: "Robert Francis Kennedy Jr", first: "Robert Francis", last: "Kennedy", suffix: "Jr"} },
      { from: "Kepa, Ro Teimumu", to: { full: "Ro Teimumu Kepa", title: "Ro", first: "Teimumu", last: "Kepa"} },
      { from: "Kerouac, Jack", to: { full: "Jack Kerouac", first: "Jack", last: "Kerouac"} },
      { from: "Kerry, John", to: { full: "John Kerry", first: "John", last: "Kerry"} },
      { from: "Kerry, Teresa Heinz", to: { full: "Teresa Heinz Kerry", first: "Teresa Heinz", last: "Kerry"} },
      { from: "Kesey, Ken", to: { full: "Ken Kesey", first: "Ken", last: "Kesey"} },
      { from: "Keyes, Alan", to: { full: "Alan Keyes", first: "Alan", last: "Keyes"} },
      { from: "Keynes, John Maynard", to: { full: "John Maynard Keynes", first: "John Maynard", last: "Keynes"} },
      { from: "Khan, Genghis", to: { full: "Genghis Khan", first: "Genghis", last: "Khan"} },
      { from: "Khan, Hafiz", to: { full: "Hafiz Khan", first: "Hafiz", last: "Khan"} },
      { from: "Khan, Nusrat Fateh Ali", to: { full: "Nusrat Fateh Ali Khan", first: "Nusrat Fateh Ali", last: "Khan"} },
      { from: "Khan, Shahrukh", to: { full: "Shahrukh Khan", first: "Shahrukh", last: "Khan"} },
      { from: "Khayyam, Omar", to: { full: "Omar Khayyam", first: "Omar", last: "Khayyam"} },
      { from: "Khomeini, Ruhollah", to: { full: "Ruhollah Khomeini", first: "Ruhollah", last: "Khomeini"} },
      { from: "Khrushchev, Nikita", to: { full: "Nikita Khrushchev", first: "Nikita", last: "Khrushchev"} },
      { from: "Kierkegaard, Søren Aabye", to: { full: "Søren Aabye Kierkegaard", first: "Søren Aabye", last: "Kierkegaard"} },
      { from: "Kilmer, Joyce", to: { full: "Joyce Kilmer", first: "Joyce", last: "Kilmer"} },
      { from: "Kilmister, Lemmy", to: { full: "Lemmy Kilmister", first: "Lemmy", last: "Kilmister"} },
      { from: "Kilroy-Silk, Robert", to: { full: "Robert Kilroy-Silk", first: "Robert", last: "Kilroy-Silk"} },
      { from: "King, Carole", to: { full: "Carole King", first: "Carole", last: "King"} },
      { from: "King, Coretta Scott", to: { full: "Coretta Scott King", first: "Coretta Scott", last: "King"} },
      { from: "King, Martin Luther", to: { full: "Martin Luther King", first: "Martin Luther", last: "King"} },
      { from: "King, Stephen", to: { full: "Stephen King", first: "Stephen", last: "King"} },
      { from: "King, William", to: { full: "William King", first: "William", last: "King"} },
      { from: "Kingsley, Charles", to: { full: "Charles Kingsley", first: "Charles", last: "Kingsley"} },
      { from: "Kingsolver, Barbara", to: { full: "Barbara Kingsolver", first: "Barbara", last: "Kingsolver"} },
      { from: "Kinsey, Alfred", to: { full: "Alfred Kinsey", first: "Alfred", last: "Kinsey"} },
      { from: "Kinski, Klaus", to: { full: "Klaus Kinski", first: "Klaus", last: "Kinski"} },
      { from: "Kipling, Rudyard", to: { full: "Rudyard Kipling", first: "Rudyard", last: "Kipling"} },
      { from: "Kissinger, Henry", to: { full: "Henry Kissinger", first: "Henry", last: "Kissinger"} },
      { from: "Khalilzad, Zalmay", to: { full: "Zalmay Khalilzad", first: "Zalmay", last: "Khalilzad"} },
      { from: "Kline, Kevin", to: { full: "Kevin Kline", first: "Kevin", last: "Kline"} },
      { from: "Klopstock, Friedrich Gottlieb", to: { full: "Friedrich Gottlieb Klopstock", first: "Friedrich Gottlieb", last: "Klopstock"} },
      { from: "Knapman, Roger", to: { full: "Roger Knapman", first: "Roger", last: "Knapman"} },
      { from: "Knebel, Fletcher", to: { full: "Fletcher Knebel", first: "Fletcher", last: "Knebel"} },
      { from: "Knightley, Keira", to: { full: "Keira Knightley", first: "Keira", last: "Knightley"} },
      { from: "Knuth, Donald", to: { full: "Donald Knuth", first: "Donald", last: "Knuth"} },
      { from: "Koestler, Arthur", to: { full: "Arthur Koestler", first: "Arthur", last: "Koestler"} },
      { from: "Koons, Jeff", to: { full: "Jeff Koons", first: "Jeff", last: "Koons"} },
      { from: "Koontz, Dean R.", to: { full: "Dean R Koontz", first: "Dean R", last: "Koontz"} },
      { from: "Koop, C. Everett", to: { full: "C Everett Koop", first: "C Everett", last: "Koop"} },
      { from: "Kornheiser, Tony", to: { full: "Tony Kornheiser", first: "Tony", last: "Kornheiser"} },
      { from: "Kotok, Alan", to: { full: "Alan Kotok", first: "Alan", last: "Kotok"} },
      { from: "Kovacs, Ernie", to: { full: "Ernie Kovacs", first: "Ernie", last: "Kovacs"} },
      { from: "Koya, Sidiq", to: { full: "Sidiq Koya", first: "Sidiq", last: "Koya"} },
      { from: "Kraus, Karl", to: { full: "Karl Kraus", first: "Karl", last: "Kraus"} },
      { from: "Krieger, Lou", to: { full: "Lou Krieger", first: "Lou", last: "Krieger"} },
      { from: "Krieger, Robbie", to: { full: "Robbie Krieger", first: "Robbie", last: "Krieger"} },
      { from: "Kripke, Saul", to: { full: "Saul Kripke", first: "Saul", last: "Kripke"} },
      { from: "Krishnamurti, Jiddu", to: { full: "Jiddu Krishnamurti", first: "Jiddu", last: "Krishnamurti"} },
      { from: "Krishnamurthy, Kalki (R. Krishnamurthy)", to: { full: "Kalki (R Krishnamurthy) Krishnamurthy", first: "Kalki", nick: "R Krishnamurthy", last: "Krishnamurthy"} },
      { from: "Kronrod, Alexander", to: { full: "Alexander Kronrod", first: "Alexander", last: "Kronrod"} },
      { from: "Kruk, John", to: { full: "John Kruk", first: "John", last: "Kruk"} },
      { from: "Kruger, Barbara", to: { full: "Barbara Kruger", first: "Barbara", last: "Kruger"} },
      { from: "Kruth, Ernst", to: { full: "Ernst Kruth", first: "Ernst", last: "Kruth"} },
      { from: "Kübler-Ross, Elisabeth", to: { full: "Elisabeth Kübler-Ross", first: "Elisabeth", last: "Kübler-Ross"} },
      { from: "Kudlow, Lawrence", to: { full: "Lawrence Kudlow", first: "Lawrence", last: "Kudlow"} },
      { from: "Kundera, Milan", to: { full: "Milan Kundera", first: "Milan", last: "Kundera"} },
      { from: "Kulongoski, Ted", to: { full: "Ted Kulongoski", first: "Ted", last: "Kulongoski"} },
      { from: "Kuriyama, Chiaki", to: { full: "Chiaki Kuriyama", first: "Chiaki", last: "Kuriyama"} },
      { from: "Kurosawa, Akira", to: { full: "Akira Kurosawa", first: "Akira", last: "Kurosawa"} },
      { from: "Kurti, Nicholas", to: { full: "Nicholas Kurti", first: "Nicholas", last: "Kurti"} },
      { from: "Kurtz, Katherine", to: { full: "Katherine Kurtz", first: "Katherine", last: "Kurtz"} },
      { from: "Kurtz, Scott R.", to: { full: "Scott R Kurtz", first: "Scott R", last: "Kurtz"} },
      { from: "Kusturica, Emir", to: { full: "Emir Kusturica", first: "Emir", last: "Kusturica"} },

      { from: "La Bruyère, Jean de", to: { full: "Jean de La Bruyère", first: "Jean", last: "de La Bruyère"} },
      { from: "LaHaye, Tim", to: { full: "Tim LaHaye", first: "Tim", last: "LaHaye"} },
      { from: "Laitman, Michael", to: { full: "Michael Laitman", first: "Michael", last: "Laitman"} },
      { from: "Lalabalavu, Ratu Naiqama", to: { full: "Ratu Naiqama Lalabalavu", title: "Ratu", first: "Naiqama", last: "Lalabalavu"} },
      { from: "Lamb, Charles", to: { full: "Charles Lamb", first: "Charles", last: "Lamb"} },
      { from: "Landers, Ann", to: { full: "Ann Landers", first: "Ann", last: "Landers"} },
      { from: "Landor, Walter Savage", to: { full: "Walter Savage Landor", first: "Walter Savage", last: "Landor"} },
      { from: "Lane, Nathan", to: { full: "Nathan Lane", first: "Nathan", last: "Lane"} },
      { from: "Lang, Will Jr.", to: { full: "Will Lang Jr", first: "Will", last: "Lang", suffix: "Jr"} },
      { from: "Lanne, Jack La", to: { full: "Jack La Lanne", first: "Jack", last: "La Lanne"} },
      { from: "Laplace, Pierre-Simon", to: { full: "Pierre-Simon Laplace", first: "Pierre-Simon", last: "Laplace"} },
      { from: "Lardner, Ring", to: { full: "Ring Lardner", first: "Ring", last: "Lardner"} },
      { from: "La Rochefoucauld, François de", to: { full: "François de La Rochefoucauld", first: "François", last: "de La Rochefoucauld"} },
      { from: "Lasorda, Tommy", to: { full: "Tommy Lasorda", first: "Tommy", last: "Lasorda"} },
      { from: "Lastman, Mel", to: { full: "Mel Lastman", first: "Mel", last: "Lastman"} },
      { from: "Lau, Charley", to: { full: "Charley Lau", first: "Charley", last: "Lau"} },
      { from: "Laurel, Stan", to: { full: "Stan Laurel", first: "Stan", last: "Laurel"} },
      { from: "Laurer, Joanie", to: { full: "Joanie Laurer", first: "Joanie", last: "Laurer"} },
      { from: "Laurinkus, Mečys", to: { full: "Mečys Laurinkus", first: "Mečys", last: "Laurinkus"} },
      { from: "Lavigne, Avril", to: { full: "Avril Lavigne", first: "Avril", last: "Lavigne"} },
      { from: "Lawler, Jerry", to: { full: "Jerry Lawler", first: "Jerry", last: "Lawler"} },
      { from: "Lawrence, Thomas Edward", to: { full: "Thomas Edward Lawrence", first: "Thomas Edward", last: "Lawrence"} },
      { from: "Leacock, Stephen", to: { full: "Stephen Leacock", first: "Stephen", last: "Leacock"} },
      { from: "Lear, Edward", to: { full: "Edward Lear", first: "Edward", last: "Lear"} },
      { from: "Leary, Timothy", to: { full: "Timothy Leary", first: "Timothy", last: "Leary"} },
      { from: "LeBlanc, Romeo", to: { full: "Romeo LeBlanc", first: "Romeo", last: "LeBlanc"} },
      { from: "Lebowitz, Fran", to: { full: "Fran Lebowitz", first: "Fran", last: "Lebowitz"} },
      { from: "Lec, Stanislaw Jerzy", to: { full: "Stanislaw Jerzy Lec", first: "Stanislaw Jerzy", last: "Lec"} },
      { from: "Lee, Ang", to: { full: "Ang Lee", first: "Ang", last: "Lee"} },
      { from: "Lee, Bruce", to: { full: "Bruce Lee", first: "Bruce", last: "Lee"} },
      { from: "Lee, Stan", to: { full: "Stan Lee", first: "Stan", last: "Lee"} },
      { from: "Lehman, John", to: { full: "John Lehman", first: "John", last: "Lehman"} },
      { from: "Leiber, Fritz", to: { full: "Fritz Leiber", first: "Fritz", last: "Leiber"} },
      { from: "Lem, Stanislaw", to: { full: "Stanislaw Lem", first: "Stanislaw", last: "Lem"} },
      { from: "LeMay, Curtis", to: { full: "Curtis LeMay", first: "Curtis", last: "LeMay"} },
      { from: "Lenin, Vladimir", to: { full: "Vladimir Lenin", first: "Vladimir", last: "Lenin"} },
      { from: "Lennon, John", to: { full: "John Lennon", first: "John", last: "Lennon"} },
      { from: "Leno, Jay", to: { full: "Jay Leno", first: "Jay", last: "Leno"} },
      { from: "Leonard, Elmore", to: { full: "Elmore Leonard", first: "Elmore", last: "Leonard"} },
      { from: "Lernoux, Penny", to: { full: "Penny Lernoux", first: "Penny", last: "Lernoux"} },
      { from: "Lessig, Lawrence", to: { full: "Lawrence Lessig", first: "Lawrence", last: "Lessig"} },
      { from: "Lessing, Doris", to: { full: "Doris Lessing", first: "Doris", last: "Lessing"} },
      { from: "Letterman, David", to: { full: "David Letterman", first: "David", last: "Letterman"} },
      { from: "Leung, Graeme", to: { full: "Graeme Leung", first: "Graeme", last: "Leung"} },
      { from: "Levertov, Denise", to: { full: "Denise Levertov", first: "Denise", last: "Levertov"} },
      { from: "Leverson, Ada", to: { full: "Ada Leverson", first: "Ada", last: "Leverson"} },
      { from: "Lévi-Strauss, Claude", to: { full: "Claude Lévi-Strauss", first: "Claude", last: "Lévi-Strauss"} },
      { from: "Lewis, C. S.", to: { full: "C S Lewis", first: "C S", last: "Lewis"} },
      { from: "Lewis, Jenny", to: { full: "Jenny Lewis", first: "Jenny", last: "Lewis"} },
      { from: "Lewis, Sinclair", to: { full: "Sinclair Lewis", first: "Sinclair", last: "Lewis"} },
      { from: "Lichtenberg, Georg Christoph", to: { full: "Georg Christoph Lichtenberg", first: "Georg Christoph", last: "Lichtenberg"} },
      { from: "Liddy, G. Gordon", to: { full: "G Gordon Liddy", first: "G Gordon", last: "Liddy"} },
      { from: "Liebling, A. J.", to: { full: "A J Liebling", first: "A J", last: "Liebling"} },
      { from: "Limbaugh, Rush", to: { full: "Rush Limbaugh", first: "Rush", last: "Limbaugh"} },
      { from: "Lincoln, Abraham", to: { full: "Abraham Lincoln", first: "Abraham", last: "Lincoln"} },
      { from: "Livermore, Jesse Lauriston", to: { full: "Jesse Lauriston Livermore", first: "Jesse Lauriston", last: "Livermore"} },
      { from: "Lloyd, Seth", to: { full: "Seth Lloyd", first: "Seth", last: "Lloyd"} },
      { from: "Locke, John", to: { full: "John Locke", first: "John", last: "Locke"} },
      { from: "Lohan, Lindsay", to: { full: "Lindsay Lohan", first: "Lindsay", last: "Lohan"} },
      { from: "London, Jack", to: { full: "Jack London", first: "Jack", last: "London"} },
      { from: "Long, Earl", to: { full: "Earl Long", first: "Earl", last: "Long"} },
      { from: "Long, Huey P.", to: { full: "Huey P Long", first: "Huey P", last: "Long"} },
      { from: "Longfellow, Henry Wadsworth", to: { full: "Henry Wadsworth Longfellow", first: "Henry Wadsworth", last: "Longfellow"} },
      { from: "Loo, Tristan J.", to: { full: "Tristan J Loo", first: "Tristan J", last: "Loo"} },
      { from: "Looney, General William", to: { full: "William Looney", title: "General", first: "William", last: "Looney"} },
      { from: "Lott, Trent", to: { full: "Trent Lott", first: "Trent", last: "Lott"} },
      { skip: "Haven't figured this one yet",
        from: "Louis VII, King of France", to: { full: "King of France Louis VII", first: "King of France", last: "Louis VII"} },
      { from: "Louis, Joe", to: { full: "Joe Louis", first: "Joe", last: "Louis"} },
      { from: "Love, Courtney", to: { full: "Courtney Love", first: "Courtney", last: "Love"} },
      { from: "Lovecraft, H. P.", to: { full: "H P Lovecraft", first: "H P", last: "Lovecraft"} },
      { from: "Lovelace, Richard", to: { full: "Richard Lovelace", first: "Richard", last: "Lovelace"} },
      { from: "Lovins, Amory", to: { full: "Amory Lovins", first: "Amory", last: "Lovins"} },
      { from: "Lowell, Christopher", to: { full: "Christopher Lowell", first: "Christopher", last: "Lowell"} },
      { from: "Lubbock, John", to: { full: "John Lubbock", first: "John", last: "Lubbock"} },
      { from: "Lucas, George", to: { full: "George Lucas", first: "George", last: "Lucas"} },
      { from: "Ludwig, Arnold M.", to: { full: "Arnold M Ludwig", first: "Arnold M", last: "Ludwig"} },
      { from: "Luther, Martin", to: { full: "Martin Luther", first: "Martin", last: "Luther"} },
      { from: "Luxemburg, Rosa", to: { full: "Rosa Luxemburg", first: "Rosa", last: "Luxemburg"} },
      { from: "Lynch, Peter", to: { full: "Peter Lynch", first: "Peter", last: "Lynch"} },
      { from: "Lyons, Steve", to: { full: "Steve Lyons", first: "Steve", last: "Lyons"} },

      { from: "Maathai, Wangari", to: { full: "Wangari Maathai", first: "Wangari", last: "Maathai"} },
      { from: "MacArthur, Douglas", to: { full: "Douglas MacArthur", first: "Douglas", last: "MacArthur"} },
      { from: "Macaulay, Thomas Babington", to: { full: "Thomas Babington Macaulay", first: "Thomas Babington", last: "Macaulay"} },
      { from: "Macdonald, George", to: { full: "George Macdonald", first: "George", last: "Macdonald"} },
      { from: "MacGregor, Robert Roy", to: { full: "Robert Roy MacGregor", first: "Robert Roy", last: "MacGregor"} },
      { from: "Machado, Antonio", to: { full: "Antonio Machado", first: "Antonio", last: "Machado"} },
      { from: "Machiavelli, Niccolo", to: { full: "Niccolo Machiavelli", first: "Niccolo", last: "Machiavelli"} },
      { from: "Madonna see Ciccone, Madonna", to: { full: "Madonna Madonna see Ciccone", first: "Madonna", last: "Madonna see Ciccone"} },
      { from: "Madraiwiwi, Ratu Joni", to: { full: "Ratu Joni Madraiwiwi", title: "Ratu", first: "Joni", last: "Madraiwiwi"} },
      { from: "Magee, Bryan", to: { full: "Bryan Magee", first: "Bryan", last: "Magee"} },
      { from: "Maher, Bill", to: { full: "Bill Maher", first: "Bill", last: "Maher"} },
      { from: "Malda, Rob \"CmdrTaco\"", to: { full: "Rob Malda", first: "Rob", nick: "CmdrTaco", last: "Malda"} },
      { from: "Mallet, David (or David Malloch)", to: { full: "David Mallet", first: "David", last: "Mallet", nick: "or David Malloch"} },
      { from: "Malley, Matt", to: { full: "Matt Malley", first: "Matt", last: "Malley"} },
      { from: "Malory, Thomas", to: { full: "Thomas Malory", first: "Thomas", last: "Malory"} },
      { from: "Malraux, André", to: { full: "André Malraux", first: "André", last: "Malraux"} },
      { from: "Malthus, Thomas", to: { full: "Thomas Malthus", first: "Thomas", last: "Malthus"} },
      { from: "Manchester, William", to: { full: "William Manchester", first: "William", last: "Manchester"} },
      { from: "Mandela, Nelson", to: { full: "Nelson Mandela", first: "Nelson", last: "Mandela"} },
      { from: "Mann, Horace", to: { full: "Horace Mann", first: "Horace", last: "Mann"} },
      { from: "Mann, Thomas", to: { full: "Thomas Mann", first: "Thomas", last: "Mann"} },
      { from: "Mannheim, Karl", to: { full: "Karl Mannheim", first: "Karl", last: "Mannheim"} },
      { from: "Mansfield, Katherine", to: { full: "Katherine Mansfield", first: "Katherine", last: "Mansfield"} },
      { from: "Manson, Charles", to: { full: "Charles Manson", first: "Charles", last: "Manson"} },
      { from: "Manson, Marilyn", to: { full: "Marilyn Manson", first: "Marilyn", last: "Manson"} },
      { from: "Mara, Ratu Sir Kamisese", to: { full: "Ratu Sir Kamisese Mara", title: "Ratu Sir", first: "Kamisese", last: "Mara"} },
      { from: "Marconi, Guglielmo", to: { full: "Guglielmo Marconi", first: "Guglielmo", last: "Marconi"} },
      { from: "Marcos, Ferdinand Edralin", to: { full: "Ferdinand Edralin Marcos", first: "Ferdinand Edralin", last: "Marcos"} },
      { from: "Margera, Brandon \"Bam\"", to: { full: "Brandon (Bam) Margera", first: "Brandon", nick: "Bam", last: "Margera"} },
      { from: "Marley, Bob", to: { full: "Bob Marley", first: "Bob", last: "Marley"} },
      { from: "Marlowe, Christopher", to: { full: "Christopher Marlowe", first: "Christopher", last: "Marlowe"} },
      { from: "Maroulis, Constantine", to: { full: "Constantine Maroulis", first: "Constantine", last: "Maroulis"} },
      { from: "Marquis, Don", to: { full: "Don Marquis", first: "Don", last: "Marquis"} },
      { from: "Marshall, George", to: { full: "George Marshall", first: "George", last: "Marshall"} },
      { from: "Marshall, Joshua Micah", to: { full: "Joshua Micah Marshall", first: "Joshua Micah", last: "Marshall"} },
      { from: "Marshall, Thomas R.", to: { full: "Thomas R Marshall", first: "Thomas R", last: "Marshall"} },
      { from: "Martell, Yann", to: { full: "Yann Martell", first: "Yann", last: "Martell"} },
      { from: "Martí, José", to: { full: "José Martí", first: "José", last: "Martí"} },
      { from: "Martin, Demetri", to: { full: "Demetri Martin", first: "Demetri", last: "Martin"} },
      { from: "Martin, John", to: { full: "John Martin", first: "John", last: "Martin"} },
      { from: "Martin, Judith \"Miss Manners\"", to: { full: "Judith (Miss Manners) Martin", first: "Judith", nick: "Miss Manners", last: "Martin"} },
      { from: "Martin, Paul", to: { full: "Paul Martin", first: "Paul", last: "Martin"} },
      { from: "Martin, Steve", to: { full: "Steve Martin", first: "Steve", last: "Martin"} },
      { from: "Marvell, Andrew", to: { full: "Andrew Marvell", first: "Andrew", last: "Marvell"} },
      { from: "Marx, Groucho", to: { full: "Groucho Marx", first: "Groucho", last: "Marx"} },
      { from: "Marx, Karl", to: { full: "Karl Marx", first: "Karl", last: "Marx"} },
      { from: "Maslow, Abraham", to: { full: "Abraham Maslow", first: "Abraham", last: "Maslow"} },
      { from: "Mataca, Petero", to: { full: "Petero Mataca", first: "Petero", last: "Mataca"} },
      { from: "Matarazzo, Francesco", to: { full: "Francesco Matarazzo", first: "Francesco", last: "Matarazzo"} },
      { from: "Matisse, Henri", to: { full: "Henri Matisse", first: "Henri", last: "Matisse"} },
      { from: "Matthews, Dave", to: { full: "Dave Matthews", first: "Dave", last: "Matthews"} },
      { from: "Maugham, William Somerset", to: { full: "William Somerset Maugham", first: "William Somerset", last: "Maugham"} },
      { from: "Maupassant, Guy de", to: { full: "Guy de Maupassant", first: "Guy", last: "de Maupassant"} },
      { from: "May, Rollo", to: { full: "Rollo May", first: "Rollo", last: "May"} },
      { from: "Mayfield, Curtis", to: { full: "Curtis Mayfield", first: "Curtis", last: "Mayfield"} },
      { from: "Mayweather, Floyd, Jr.", to: { full: "Floyd Mayweather Jr", first: "Floyd", last: "Mayweather", suffix: "Jr"} },
      { from: "McAuliffe, Anthony", to: { full: "Anthony McAuliffe", first: "Anthony", last: "McAuliffe"} },
      { from: "McCain, John", to: { full: "John McCain", first: "John", last: "McCain"} },
      { from: "McCarthy, Eugene", to: { full: "Eugene McCarthy", first: "Eugene", last: "McCarthy"} },
      { from: "McCarthy, Joseph", to: { full: "Joseph McCarthy", first: "Joseph", last: "McCarthy"} },
      { from: "McCarthy, Mary", to: { full: "Mary McCarthy", first: "Mary", last: "McCarthy"} },
      { from: "McCartney, Paul", to: { full: "Paul McCartney", first: "Paul", last: "McCartney"} },
      { from: "McClary, Susan", to: { full: "Susan McClary", first: "Susan", last: "McClary"} },
      { from: "McClung, Nellie", to: { full: "Nellie McClung", first: "Nellie", last: "McClung"} },
      { from: "McFee, William", to: { full: "William McFee", first: "William", last: "McFee"} },
      { from: "McGill, Bryant", to: { full: "Bryant McGill", first: "Bryant", last: "McGill"} },
      { from: "McGoohan, Patrick", to: { full: "Patrick McGoohan", first: "Patrick", last: "McGoohan"} },
      { from: "McGuire, Al", to: { full: "Al McGuire", first: "Al", last: "McGuire"} },
      { from: "McKay, Charles", to: { full: "Charles McKay", first: "Charles", last: "McKay"} },
      { from: "McKennitt, Loreena", to: { full: "Loreena McKennitt", first: "Loreena", last: "McKennitt"} },
      { from: "McLuhan, Marshall", to: { full: "Marshall McLuhan", first: "Marshall", last: "McLuhan"} },
      { from: "McMahon, Vince", to: { full: "Vince McMahon", first: "Vince", last: "McMahon"} },
      { from: "McNair, Steve", to: { full: "Steve McNair", first: "Steve", last: "McNair"} },
      { from: "McNamara, Robert", to: { full: "Robert McNamara", first: "Robert", last: "McNamara"} },
      { from: "McQuaig, Linda", to: { full: "Linda McQuaig", first: "Linda", last: "McQuaig"} },
      { from: "Mead, Margaret", to: { full: "Margaret Mead", first: "Margaret", last: "Mead"} },
      { from: "Mecham, Evan", to: { full: "Evan Mecham", first: "Evan", last: "Mecham"} },
      { from: "Medved, Michael", to: { full: "Michael Medved", first: "Michael", last: "Medved"} },
      { from: "Meir, Golda", to: { full: "Golda Meir", first: "Golda", last: "Meir"} },
      { from: "Melua, Katie", to: { full: "Katie Melua", first: "Katie", last: "Melua"} },
      { from: "Melville, Herman", to: { full: "Herman Melville", first: "Herman", last: "Melville"} },
      { from: "Men, Alexander", to: { full: "Alexander Men", first: "Alexander", last: "Men"} },
      { from: "Mencken, H. L.", to: { full: "H L Mencken", first: "H L", last: "Mencken"} },
      { from: "Merchant, Natalie", to: { full: "Natalie Merchant", first: "Natalie", last: "Merchant"} },
      { from: "Mercury, Freddie", to: { full: "Freddie Mercury", first: "Freddie", last: "Mercury"} },
      { from: "Mero, Rena", to: { full: "Rena Mero", first: "Rena", last: "Mero"} },
      { from: "Merrick, Joseph", to: { full: "Joseph Merrick", first: "Joseph", last: "Merrick"} },
      { from: "Michener, James", to: { full: "James Michener", first: "James", last: "Michener"} },
      { from: "Midler, Bette", to: { full: "Bette Midler", first: "Bette", last: "Midler"} },
      { from: "Mies van der Rohe, Ludwig", to: { full: "Ludwig Mies van der Rohe", first: "Ludwig", last: "Mies van der Rohe"} },
      { from: "Milano, Alyssa", to: { full: "Alyssa Milano", first: "Alyssa", last: "Milano"} },
      { from: "Mill, John Stuart", to: { full: "John Stuart Mill", first: "John Stuart", last: "Mill"} },
      { from: "Miller, Alex", to: { full: "Alex Miller", first: "Alex", last: "Miller"} },
      { from: "Miller, Arthur", to: { full: "Arthur Miller", first: "Arthur", last: "Miller"} },
      { from: "Miller, Bode", to: { full: "Bode Miller", first: "Bode", last: "Miller"} },
      { from: "Miller, Henry", to: { full: "Henry Miller", first: "Henry", last: "Miller"} },
      { from: "Miller, Ron", to: { full: "Ron Miller", first: "Ron", last: "Miller"} },
      { skip: "Jr will be parsed as a nick",
        from: "Miller, Walter M. (Jr.)", to: { full: "Walter M Miller", first: "Walter M", last: "Miller", suffix: "Jr"} },
      { from: "Milligan, Spike", to: { full: "Spike Milligan", first: "Spike", last: "Milligan"} },
      { from: "Mills, C. Wright", to: { full: "C Wright Mills", first: "C Wright", last: "Mills"} },
      { from: "Milne, A.A.", to: { full: "A A Milne", first: "A A", last: "Milne"} },
      { from: "Milosz, Ceslaw", to: { full: "Ceslaw Milosz", first: "Ceslaw", last: "Milosz"} },
      { from: "Milton, John", to: { full: "John Milton", first: "John", last: "Milton"} },
      { from: "Minow, Newton N.", to: { full: "Newton N Minow", first: "Newton N", last: "Minow"} },
      { from: "Mises, Ludwig von", to: { full: "Ludwig von Mises", first: "Ludwig", last: "von Mises"} },
      { from: "Mitchell, John", to: { full: "John Mitchell", first: "John", last: "Mitchell"} },
      { from: "Mitchell, Joni", to: { full: "Joni Mitchell", first: "Joni", last: "Mitchell"} },
      { from: "Miyamoto, Shigeru", to: { full: "Shigeru Miyamoto", first: "Shigeru", last: "Miyamoto"} },
      { from: "Moawad, Nayla", to: { full: "Nayla Moawad", first: "Nayla", last: "Moawad"} },
      { from: "Moawad, René", to: { full: "René Moawad", first: "René", last: "Moawad"} },
      { from: "Momoedonu, Tevita", to: { full: "Tevita Momoedonu", first: "Tevita", last: "Momoedonu"} },
      { from: "Monheit, Jane", to: { full: "Jane Monheit", first: "Jane", last: "Monheit"} },
      { from: "Monroe, Marilyn", to: { full: "Marilyn Monroe", first: "Marilyn", last: "Monroe"} },
      { from: "Montaigne, Michel de", to: { full: "Michel de Montaigne", first: "Michel", last: "de Montaigne"} },
      { from: "Montesquieu, Charles de", to: { full: "Charles de Montesquieu", first: "Charles", last: "de Montesquieu"} },
      { from: "Moore, Alan", to: { full: "Alan Moore", first: "Alan", last: "Moore"} },
      { from: "Moore, Dudley", to: { full: "Dudley Moore", first: "Dudley", last: "Moore"} },
      { from: "Moore, Michael", to: { full: "Michael Moore", first: "Michael", last: "Moore"} },
      { from: "Moore, Tim", to: { full: "Tim Moore", first: "Tim", last: "Moore"} },
      { from: "Morales, Evo", to: { full: "Evo Morales", first: "Evo", last: "Morales"} },
      { from: "Moran, Dylan", to: { full: "Dylan Moran", first: "Dylan", last: "Moran"} },
      { from: "More, Hannah", to: { full: "Hannah More", first: "Hannah", last: "More"} },
      { from: "More, St. Thomas", to: { full: "St Thomas More", first: "St Thomas", last: "More"} },
      { from: "Morgenstern, Christian", to: { full: "Christian Morgenstern", first: "Christian", last: "Morgenstern"} },
      { from: "Morley, Christopher", to: { full: "Christopher Morley", first: "Christopher", last: "Morley"} },
      { from: "Morris, Errol", to: { full: "Errol Morris", first: "Errol", last: "Morris"} },
      { from: "Morris, Mixmaster", to: { full: "Mixmaster Morris", first: "Mixmaster", last: "Morris"} },
      { from: "Morrison, Jim", to: { full: "Jim Morrison", first: "Jim", last: "Morrison"} },
      { from: "Morrison, Robert", to: { full: "Robert Morrison", first: "Robert", last: "Morrison"} },
      { from: "Mortimer, John", to: { full: "John Mortimer", first: "John", last: "Mortimer"} },
      { from: "Mountbatten, Louis", to: { full: "Louis Mountbatten", first: "Louis", last: "Mountbatten"} },
      { from: "Mozart, Wolfgang Amadeus", to: { full: "Wolfgang Amadeus Mozart", first: "Wolfgang Amadeus", last: "Mozart"} },
      { from: "Mugabe, Robert", to: { full: "Robert Mugabe", first: "Robert", last: "Mugabe"} },
      { from: "Muhammad, Holy Prophet", to: { full: "Holy Prophet Muhammad", first: "Holy Prophet", last: "Muhammad"} },
      { from: "Muir, John", to: { full: "John Muir", first: "John", last: "Muir"} },
      { from: "Mullally, Megan", to: { full: "Megan Mullally", first: "Megan", last: "Mullally"} },
      { skip: "Haven't figured this one yet",
        from: "Mulock, Dinah Maria; also Dinah Maria Craik", to: { full: "Dinah Maria; also Dinah Maria Craik Mulock", first: "Dinah Maria; also Dinah Maria Craik", last: "Mulock"} },
      { from: "Mumford, Lewis", to: { full: "Lewis Mumford", first: "Lewis", last: "Mumford"} },
      { from: "Mumpfield, Susie", to: { full: "Susie Mumpfield", first: "Susie", last: "Mumpfield"} },
      { from: "Munch, Edvard", to: { full: "Edvard Munch", first: "Edvard", last: "Munch"} },
      { from: "Munro, Alice", to: { full: "Alice Munro", first: "Alice", last: "Munro"} },
      { from: "Murrow, Edward R.", to: { full: "Edward R Murrow", first: "Edward R", last: "Murrow"} },
      { from: "Mussolini, Benito", to: { full: "Benito Mussolini", first: "Benito", last: "Mussolini"} },
      { from: "Mustaine, Dave", to: { full: "Dave Mustaine", first: "Dave", last: "Mustaine"} },
      { from: "Myatt, David", to: { full: "David Myatt", first: "David", last: "Myatt"} },

      { from: "Nabokov, Vladimir", to: { full: "Vladimir Nabokov", first: "Vladimir", last: "Nabokov"} },
      { skip: "Haven't figured this one yet",
        from: "Nachman, Rabbi, of Bratzlav", to: { full: "of Bratzlav Nachman, Rabbi", first: "of Bratzlav", last: "Nachman, Rabbi"} },
      { from: "Nader, Ralph", to: { full: "Ralph Nader", first: "Ralph", last: "Nader"} },
      { from: "Nagel, Thomas", to: { full: "Thomas Nagel", first: "Thomas", last: "Nagel"} },
      { from: "Cole, Nat \"King\"", to: { full: "Nat Cole", first: "Nat", nick: "King", last: "Cole"} },
      { from: "Naidu, Richard", to: { full: "Richard Naidu", first: "Richard", last: "Naidu"} },
      { from: "Nailatikau, Adi Koila", to: { full: "Adi Koila Nailatikau", title: "Adi", first: "Koila", last: "Nailatikau"} },
      { from: "Nailatikau, Ratu Epeli Qaraninamu", to: { full: "Ratu Epeli Qaraninamu Nailatikau", title: "Ratu", first: "Epeli Qaraninamu", last: "Nailatikau"} },
      { from: "Najimy, Kathy", to: { full: "Kathy Najimy", first: "Kathy", last: "Najimy"} },
      { from: "Nash, John Forbes", to: { full: "John Forbes Nash", first: "John Forbes", last: "Nash"} },
      { from: "Nash, Thomas", to: { full: "Thomas Nash", first: "Thomas", last: "Nash"} },
      { from: "Navakasuasua, Maciu", to: { full: "Maciu Navakasuasua", first: "Maciu", last: "Navakasuasua"} },
      { from: "Negroponte, Nicholas", to: { full: "Nicholas Negroponte", first: "Nicholas", last: "Negroponte"} },
      { from: "Nelson, Hailey Anne", to: { full: "Hailey Anne Nelson", first: "Hailey Anne", last: "Nelson"} },
      { from: "Nelson, Horatio", to: { full: "Horatio Nelson", first: "Horatio", last: "Nelson"} },
      { from: "Neruda, Pablo", to: { full: "Pablo Neruda", first: "Pablo", last: "Neruda"} },
      { from: "Newhart, Bob", to: { full: "Bob Newhart", first: "Bob", last: "Newhart"} },
      { from: "Newton, Isaac", to: { full: "Isaac Newton", first: "Isaac", last: "Newton"} },
      { from: "Newton, John", to: { full: "John Newton", first: "John", last: "Newton"} },
      { from: "Nicks, Stevie", to: { full: "Stevie Nicks", first: "Stevie", last: "Nicks"} },
      { from: "Nicoll, James", to: { full: "James Nicoll", first: "James", last: "Nicoll"} },
      { from: "Niebuhr, Reinhold", to: { full: "Reinhold Niebuhr", first: "Reinhold", last: "Niebuhr"} },
      { from: "Niemöller, Martin", to: { full: "Martin Niemöller", first: "Martin", last: "Niemöller"} },
      { from: "Nietzsche, Friedrich", to: { full: "Friedrich Nietzsche", first: "Friedrich", last: "Nietzsche"} },
      { from: "Nightingale, Florence", to: { full: "Florence Nightingale", first: "Florence", last: "Nightingale"} },
      { from: "Nijinsky, Vaslav", to: { full: "Vaslav Nijinsky", first: "Vaslav", last: "Nijinsky"} },
      { skip: "Not only misspelled, Nin get treated as a compound",
        from: "Nin, Anaïs Nin", to: { full: "Anaïs Nin Nin", first: "Anaïs", last: "Nin Nin"} },
      { from: "Ninio, Jacques", to: { full: "Jacques Ninio", first: "Jacques", last: "Ninio"} },
      { from: "Niranjan, Sangeeta", to: { full: "Sangeeta Niranjan", first: "Sangeeta", last: "Niranjan"} },
      { from: "Niven, Larry", to: { full: "Larry Niven", first: "Larry", last: "Niven"} },
      { from: "Nixon, Richard", to: { full: "Richard Nixon", first: "Richard", last: "Nixon"} },
      { from: "Noam, Eli", to: { full: "Eli Noam", first: "Eli", last: "Noam"} },
      { from: "Norton, Joshua Abraham", to: { full: "Joshua Abraham Norton", first: "Joshua Abraham", last: "Norton"} },
      { skip: "Haven't figured this one yet",
        from: "Nostradamus (Michel de Notredame, or Michel de Nostredame)", to: { full: "or Michel de Nostredame) Nostradamus (Michel de Notredame", first: "or Michel de Nostredame)", last: "Nostradamus (Michel de Notredame"} },
      { from: "Nugent, Ted", to: { full: "Ted Nugent", first: "Ted", last: "Nugent"} },
      { skip: "Duke will treated as a title, not a name",
        from: "Nukem, Duke", to: { full: "Duke Nukem", title: "Duke", last: "Nukem"} },
      { from: "Null, Gary", to: { full: "Gary Null", first: "Gary", last: "Null"} },
      { from: "Nunally, Patrick", to: { full: "Patrick Nunally", first: "Patrick", last: "Nunally"} },
      { from: "Nuwas, Abu", to: { full: "Abu Nuwas", first: "Abu", last: "Nuwas"} },

      { from: "Obama, Barack", to: { full: "Barack Obama", first: "Barack", last: "Obama"} },
      { from: "Oberst, Conor", to: { full: "Conor Oberst", first: "Conor", last: "Oberst"} },
      { from: "O'Brien, Conan", to: { full: "Conan O'Brien", first: "Conan", last: "O'Brien"} },
      { from: "Ochs, Phil", to: { full: "Phil Ochs", first: "Phil", last: "Ochs"} },
      { from: "O'Donnell, Rosie", to: { full: "Rosie O'Donnell", first: "Rosie", last: "O'Donnell"} },
      { from: "Ogi, Adolf", to: { full: "Adolf Ogi", first: "Adolf", last: "Ogi"} },
      { from: "Ogilvy, David", to: { full: "David Ogilvy", first: "David", last: "Ogilvy"} },
      { from: "O'Keeffe, Georgia", to: { full: "Georgia O'Keeffe", first: "Georgia", last: "O'Keeffe"} },
      { from: "Oliver, Jamie", to: { full: "Jamie Oliver", first: "Jamie", last: "Oliver"} },
      { from: "Oliver, Robert T.", to: { full: "Robert T Oliver", first: "Robert T", last: "Oliver"} },
      { from: "Olson, Ken", to: { full: "Ken Olson", first: "Ken", last: "Olson"} },
      { skip: "Haven't figured this one yet",
        from: "Olsen, Mary-Kate and Ashley", to: { full: "Mary-Kate and Ashley Olsen", first: "Mary-Kate and Ashley", last: "Olsen"} },
      { from: "Onassis, Jacqueline Kennedy", to: { full: "Jacqueline Kennedy Onassis", first: "Jacqueline Kennedy", last: "Onassis"} },
      { from: "Ondrick, William F.", to: { full: "William F Ondrick", first: "William F", last: "Ondrick"} },
      { from: "Oppenheimer, J. Robert", to: { full: "J Robert Oppenheimer", first: "J Robert", last: "Oppenheimer"} },
      { from: "O'Reilly, Bill", to: { full: "Bill O'Reilly", first: "Bill", last: "O'Reilly"} },
      { from: "O'Rourke, P. J.", to: { full: "P J O'Rourke", first: "P J", last: "O'Rourke"} },
      { from: "Ortiz, David", to: { full: "David Ortiz", first: "David", last: "Ortiz"} },
      { from: "Orwell, George", to: { full: "George Orwell", first: "George", last: "Orwell"} },
      { from: "Osbourne, Ozzy", to: { full: "Ozzy Osbourne", first: "Ozzy", last: "Osbourne"} },
      { from: "O’Shaughnessy, Arthur", to: { full: "Arthur O'Shaughnessy", first: "Arthur", last: "O'Shaughnessy"} },
      { from: "Ouspensky, P. D.", to: { full: "P D Ouspensky", first: "P D", last: "Ouspensky"} },
      { from: "Overbury, Thomas", to: { full: "Thomas Overbury", first: "Thomas", last: "Overbury"} },
      { from: "Owens, Jesse", to: { full: "Jesse Owens", first: "Jesse", last: "Owens"} },
      { from: "Owsen, Dan", to: { full: "Dan Owsen", first: "Dan", last: "Owsen"} },

      { from: "Page, Larry", to: { full: "Larry Page", first: "Larry", last: "Page"} },
      { from: "Paige, Satchel", to: { full: "Satchel Paige", first: "Satchel", last: "Paige"} },
      { from: "Paine, Thomas", to: { full: "Thomas Paine", first: "Thomas", last: "Paine"} },
      { from: "Palahniuk, Chuck", to: { full: "Chuck Palahniuk", first: "Chuck", last: "Palahniuk"} },
      { from: "Palgrave, Francis Turner", to: { full: "Francis Turner Palgrave", first: "Francis Turner", last: "Palgrave"} },
      { from: "Palin, Michael", to: { full: "Michael Palin", first: "Michael", last: "Palin"} },
      { from: "Palme, Olof", to: { full: "Olof Palme", first: "Olof", last: "Palme"} },
      { from: "Parker, Dorothy", to: { full: "Dorothy Parker", first: "Dorothy", last: "Parker"} },
      { from: "Parton, Dolly", to: { full: "Dolly Parton", first: "Dolly", last: "Parton"} },
      { from: "Pascal, Blaise", to: { full: "Blaise Pascal", first: "Blaise", last: "Pascal"} },
      { from: "Pasteur, Louis", to: { full: "Louis Pasteur", first: "Louis", last: "Pasteur"} },
      { from: "Pater, Walter", to: { full: "Walter Pater", first: "Walter", last: "Pater"} },
      { from: "Paterson, Isabel", to: { full: "Isabel Paterson", first: "Isabel", last: "Paterson"} },
      { from: "Patrick, Saint", to: { full: "Saint Patrick", first: "Saint", last: "Patrick"} },
      { from: "Patton, George S.", to: { full: "George S Patton", first: "George S", last: "Patton"} },
      { from: "Paul, Ron", to: { full: "Ron Paul", first: "Ron", last: "Paul"} },
      { from: "Pauli, Wolfgang", to: { full: "Wolfgang Pauli", first: "Wolfgang", last: "Pauli"} },
      { from: "Pauling, Linus", to: { full: "Linus Pauling", first: "Linus", last: "Pauling"} },
      { from: "Payack, Paul JJ", to: { full: "Paul JJ Payack", first: "Paul JJ", last: "Payack"} },
      { from: "Payne, Max", to: { full: "Max Payne", first: "Max", last: "Payne"} },
      { from: "Peel, John", to: { full: "John Peel", first: "John", last: "Peel"} },
      { from: "Peguy, Charles", to: { full: "Charles Peguy", first: "Charles", last: "Peguy"} },
      { from: "Peirce, Charles Sanders", to: { full: "Charles Sanders Peirce", first: "Charles Sanders", last: "Peirce"} },
      { from: "Penn, William", to: { full: "William Penn", first: "William", last: "Penn"} },
      { from: "Percy, Walker", to: { full: "Walker Percy", first: "Walker", last: "Percy"} },
      { from: "Peres, Shimon", to: { full: "Shimon Peres", first: "Shimon", last: "Peres"} },
      { from: "Perger, Andreas Paolo", to: { full: "Andreas Paolo Perger", first: "Andreas Paolo", last: "Perger"} },
      { from: "Perle, Richard", to: { full: "Richard Perle", first: "Richard", last: "Perle"} },
      { from: "Perlis, Alan", to: { full: "Alan Perlis", first: "Alan", last: "Perlis"} },
      { from: "Perry, Michael D.", to: { full: "Michael D Perry", first: "Michael D", last: "Perry"} },
      { from: "Perry, Oliver Hazard", to: { full: "Oliver Hazard Perry", first: "Oliver Hazard", last: "Perry"} },
      { from: "Pessoa, Fernando", to: { full: "Fernando Pessoa", first: "Fernando", last: "Pessoa"} },
      { from: "Peter, Dr. Laurence J.", to: { full: "Laurence J Peter", title: "Dr", first: "Laurence J", last: "Peter"} },
      { from: "Petronius, Gaius", to: { full: "Gaius Petronius", first: "Gaius", last: "Petronius"} },
      { from: "Petty, Tom", to: { full: "Tom Petty", first: "Tom", last: "Petty"} },
      { from: "Phelps, Michael", to: { full: "Michael Phelps", first: "Michael", last: "Phelps"} },
      { skip: "Haven't figured this one yet",
        from: "Philip, Duke of Edinburgh", to: { full: "Duke of Edinburgh Philip", first: "Duke of Edinburgh", last: "Philip"} },
      { from: "Philips, Emo", to: { full: "Emo Philips", first: "Emo", last: "Philips"} },
      { from: "Piaget, Jean", to: { full: "Jean Piaget", first: "Jean", last: "Piaget"} },
      { from: "Picasso, Pablo", to: { full: "Pablo Picasso", first: "Pablo", last: "Picasso"} },
      { from: "Pieper, Josef", to: { full: "Josef Pieper", first: "Josef", last: "Pieper"} },
      { from: "Pinker, Steven", to: { full: "Steven Pinker", first: "Steven", last: "Pinker"} },
      { from: "Piper, Roddy", to: { full: "Roddy Piper", first: "Roddy", last: "Piper"} },
      { from: "Piraten, Fritiof Nilsson", to: { full: "Fritiof Nilsson Piraten", first: "Fritiof Nilsson", last: "Piraten"} },
      { from: "Pirsig, Robert M.", to: { full: "Robert M Pirsig", first: "Robert M", last: "Pirsig"} },
      { from: "Plath, Sylvia", to: { full: "Sylvia Plath", first: "Sylvia", last: "Plath"} },
      { from: "Plimpton, Martha", to: { full: "Martha Plimpton", first: "Martha", last: "Plimpton"} },
      { from: "Poe, Edgar Allan", to: { full: "Edgar Allan Poe", first: "Edgar Allan", last: "Poe"} },
      { from: "Poincaré, Henri", to: { full: "Henri Poincaré", first: "Henri", last: "Poincaré"} },
      { from: "Polański, Roman", to: { full: "Roman Polański", first: "Roman", last: "Polański"} },
      { from: "Ponsonby, Arthur", to: { full: "Arthur Ponsonby", first: "Arthur", last: "Ponsonby"} },
      { from: "Pope, Alexander", to: { full: "Alexander Pope", first: "Alexander", last: "Pope"} },
      { from: "Popper, Karl", to: { full: "Karl Popper", first: "Karl", last: "Popper"} },
      { from: "Porson, Richard", to: { full: "Richard Porson", first: "Richard", last: "Porson"} },
      { from: "Postel, Jon", to: { full: "Jon Postel", first: "Jon", last: "Postel"} },
      { from: "Powell, Colin", to: { full: "Colin Powell", first: "Colin", last: "Powell"} },
      { from: "Pratchett, Terry", to: { full: "Terry Pratchett", first: "Terry", last: "Pratchett"} },
      { from: "Premchand, Munshi", to: { full: "Munshi Premchand", first: "Munshi", last: "Premchand"} },
      { from: "Presley, Elvis", to: { full: "Elvis Presley", first: "Elvis", last: "Presley"} },
      { from: "Priestley, Joseph", to: { full: "Joseph Priestley", first: "Joseph", last: "Priestley"} },
      { from: "Proudhon, P. J.", to: { full: "P J Proudhon", first: "P J", last: "Proudhon"} },
      { from: "Puget, Jade", to: { full: "Jade Puget", first: "Jade", last: "Puget"} },
      { from: "Punja, Hari", to: { full: "Hari Punja", first: "Hari", last: "Punja"} },
      { from: "Purcell, Steve", to: { full: "Steve Purcell", first: "Steve", last: "Purcell"} },
      { from: "Putin, Vladimir", to: { full: "Vladimir Putin", first: "Vladimir", last: "Putin"} },
      { from: "Pynchon, Thomas", to: { full: "Thomas Pynchon", first: "Thomas", last: "Pynchon"} },

      { from: "Qarase, Laisenia", to: { full: "Laisenia Qarase", first: "Laisenia", last: "Qarase"} },
      { from: "Quale, Anthony", to: { full: "Anthony Quale", first: "Anthony", last: "Quale"} },
      { from: "Quarles, Francis", to: { full: "Francis Quarles", first: "Francis", last: "Quarles"} },
      { from: "Quayle, Dan", to: { full: "Dan Quayle", first: "Dan", last: "Quayle"} },
      { skip: "Haven't figured this one yet",
        from: "Marie, Queen of Romania", to: { full: "Queen of Romania Marie", first: "Queen of Romania", last: "Marie"} },
      { from: "Quine, Willard van Orman", to: { full: "Willard van Orman Quine", first: "Willard van Orman", last: "Quine"} },
      { from: "Quintilian, Marcus Fabius", to: { full: "Marcus Fabius Quintilian", first: "Marcus Fabius", last: "Quintilian"} },
      { from: "Quisenberry, Dan", to: { full: "Dan Quisenberry", first: "Dan", last: "Quisenberry"} },

      { from: "Raajan, Amitrajit", to: { full: "Amitrajit Raajan", first: "Amitrajit", last: "Raajan"} },
      { from: "Rabelais, François", to: { full: "François Rabelais", first: "François", last: "Rabelais"} },
      { from: "Rabin, Yitzhak", to: { full: "Yitzhak Rabin", first: "Yitzhak", last: "Rabin"} },
      { from: "Rabuka, Sitiveni", to: { full: "Sitiveni Rabuka", first: "Sitiveni", last: "Rabuka"} },
      { from: "Radner, Gilda", to: { full: "Gilda Radner", first: "Gilda", last: "Radner"} },
      { from: "Rae, Pramod", to: { full: "Pramod Rae", first: "Pramod", last: "Rae"} },
      { from: "Raleigh, Sir Walter", to: { full: "Walter Raleigh", title: "Sir", first: "Walter", last: "Raleigh"} },
      { from: "Ramirez, Manny", to: { full: "Manny Ramirez", first: "Manny", last: "Ramirez"} },
      { from: "Rand, Ayn", to: { full: "Ayn Rand", first: "Ayn", last: "Rand"} },
      { from: "Ranke, Leopold von", to: { full: "Leopold von Ranke", first: "Leopold", last: "von Ranke"} },
      { from: "Ransome, Arthur", to: { full: "Arthur Ransome", first: "Arthur", last: "Ransome"} },
      { from: "Rascoe, Burton", to: { full: "Burton Rascoe", first: "Burton", last: "Rascoe"} },
      { from: "Raskin, Jef", to: { full: "Jef Raskin", first: "Jef", last: "Raskin"} },
      { from: "Ravuvu, Asesela", to: { full: "Asesela Ravuvu", first: "Asesela", last: "Ravuvu"} },
      { from: "Ray, Gene", to: { full: "Gene Ray", first: "Gene", last: "Ray"} },
      { from: "Ray, James Arthur", to: { full: "James Arthur Ray", first: "James Arthur", last: "Ray"} },
      { from: "Reagan, Nancy", to: { full: "Nancy Reagan", first: "Nancy", last: "Reagan"} },
      { from: "Reagan, Ronald", to: { full: "Ronald Reagan", first: "Ronald", last: "Reagan"} },
      { from: "Reagan, Ron", to: { full: "Ron Reagan", first: "Ron", last: "Reagan"} },
      { from: "Rees, Nigel", to: { full: "Nigel Rees", first: "Nigel", last: "Rees"} },
      { from: "Reeve, Christopher", to: { full: "Christopher Reeve", first: "Christopher", last: "Reeve"} },
      { from: "Rehnquist, William", to: { full: "William Rehnquist", first: "William", last: "Rehnquist"} },
      { from: "Reich, Wilhelm", to: { full: "Wilhelm Reich", first: "Wilhelm", last: "Reich"} },
      { from: "Reid, Harry", to: { full: "Harry Reid", first: "Harry", last: "Reid"} },
      { from: "Reisman, George", to: { full: "George Reisman", first: "George", last: "Reisman"} },
      { from: "Rexroth, Kenneth", to: { full: "Kenneth Rexroth", first: "Kenneth", last: "Rexroth"} },
      { from: "Rice, Condoleezza", to: { full: "Condoleezza Rice", first: "Condoleezza", last: "Rice"} },
      { from: "Richards, Keith", to: { full: "Keith Richards", first: "Keith", last: "Richards"} },
      { from: "Richelieu, Cardinal", to: { full: "Cardinal Richelieu", first: "Cardinal", last: "Richelieu"} },
      { from: "Rickover, Hyman G.", to: { full: "Hyman G Rickover", first: "Hyman G", last: "Rickover"} },
      { from: "Riley, Tim", to: { full: "Tim Riley", first: "Tim", last: "Riley"} },
      { from: "Rilke, Rainer Maria", to: { full: "Rainer Maria Rilke", first: "Rainer Maria", last: "Rilke"} },
      { from: "Rimbaud, Arthur", to: { full: "Arthur Rimbaud", first: "Arthur", last: "Rimbaud"} },
      { from: "Ripa, Kelly", to: { full: "Kelly Ripa", first: "Kelly", last: "Ripa"} },
      { from: "Ritter, Scott", to: { full: "Scott Ritter", first: "Scott", last: "Ritter"} },
      { from: "Rivers, Joan", to: { full: "Joan Rivers", first: "Joan", last: "Rivers"} },
      { from: "Robbins, Anthony", to: { full: "Anthony Robbins", first: "Anthony", last: "Robbins"} },
      { from: "Robespierre, Maximilien", to: { full: "Maximilien Robespierre", first: "Maximilien", last: "Robespierre"} },
      { from: "Robinson, Jackie", to: { full: "Jackie Robinson", first: "Jackie", last: "Robinson"} },
      { from: "Robinson, Kim Stanley", to: { full: "Kim Stanley Robinson", first: "Kim Stanley", last: "Robinson"} },
      { from: "Robinson, Spider", to: { full: "Spider Robinson", first: "Spider", last: "Robinson"} },
      { from: "Rockefeller, John D.", to: { full: "John D Rockefeller", first: "John D", last: "Rockefeller"} },
      { from: "Rockne, Knute", to: { full: "Knute Rockne", first: "Knute", last: "Rockne"} },
      { from: "Rodriguez, Alex", to: { full: "Alex Rodriguez", first: "Alex", last: "Rodriguez"} },
      { from: "Rogers, Fred", to: { full: "Fred Rogers", first: "Fred", last: "Rogers"} },
      { from: "Rogers, Will", to: { full: "Will Rogers", first: "Will", last: "Rogers"} },
      { from: "Romano, Ray", to: { full: "Ray Romano", first: "Ray", last: "Romano"} },
      { from: "Rommel, Erwin", to: { full: "Erwin Rommel", first: "Erwin", last: "Rommel"} },
      { from: "Roosevelt, Eleanor", to: { full: "Eleanor Roosevelt", first: "Eleanor", last: "Roosevelt"} },
      { from: "Roosevelt, Franklin Delano", to: { full: "Franklin Delano Roosevelt", first: "Franklin Delano", last: "Roosevelt"} },
      { from: "Roosevelt, Theodore", to: { full: "Theodore Roosevelt", first: "Theodore", last: "Roosevelt"} },
      { from: "Rosing, Wayne", to: { full: "Wayne Rosing", first: "Wayne", last: "Rosing"} },
      { from: "Roth, Geneen", to: { full: "Geneen Roth", first: "Geneen", last: "Roth"} },
      { from: "Roth, Philip", to: { full: "Philip Roth", first: "Philip", last: "Roth"} },
      { from: "Rothbard, Murray", to: { full: "Murray Rothbard", first: "Murray", last: "Rothbard"} },
      { skip: "Technically this isn't a name, so do what?",
        from: "Rothschild, Baron", to: { full: "Baron Rothschild", title: "Baron", last: "Rothschild"} },
      { from: "Roux, Joseph", to: { full: "Joseph Roux", first: "Joseph", last: "Roux"} },
      { from: "Rousseau, Jean-Jacques", to: { full: "Jean-Jacques Rousseau", first: "Jean-Jacques", last: "Rousseau"} },
      { from: "Rovabokola, Ratu Viliame", to: { full: "Ratu Viliame Rovabokola", title: "Ratu", first: "Viliame", last: "Rovabokola"} },
      { from: "Roy, Arundhati", to: { full: "Arundhati Roy", first: "Arundhati", last: "Roy"} },
      { from: "Rudner, Rita", to: { full: "Rita Rudner", first: "Rita", last: "Rudner"} },
      { from: "Ruiz, Don Miguel", to: { full: "Don Miguel Ruiz", first: "Don Miguel", last: "Ruiz"} },
      { from: "Rukeyser, Louis", to: { full: "Louis Rukeyser", first: "Louis", last: "Rukeyser"} },
      { from: "Rumbold, Richard", to: { full: "Richard Rumbold", first: "Richard", last: "Rumbold"} },
      { from: "Rumi, Jalal al-Din Muhammad", to: { full: "Jalal al-Din Muhammad Rumi", first: "Jalal al-Din Muhammad", last: "Rumi"} },
      { from: "Rumsfeld, Donald", to: { full: "Donald Rumsfeld", first: "Donald", last: "Rumsfeld"} },
      { from: "Runnels, Dustin", to: { full: "Dustin Runnels", first: "Dustin", last: "Runnels"} },
      { from: "Rushton, Willie", to: { full: "Willie Rushton", first: "Willie", last: "Rushton"} },
      { from: "Ruskin, John", to: { full: "John Ruskin", first: "John", last: "Ruskin"} },
      { from: "Russell, Bertrand", to: { full: "Bertrand Russell", first: "Bertrand", last: "Russell"} },
      { from: "Russell, Nipsey", to: { full: "Nipsey Russell", first: "Nipsey", last: "Russell"} },
      { from: "Russell, Rosaland", to: { full: "Rosaland Russell", first: "Rosaland", last: "Russell"} },
      { from: "Ruth, Babe", to: { full: "Babe Ruth", first: "Babe", last: "Ruth"} },
      { from: "Rutherford, Ernest", to: { full: "Ernest Rutherford", first: "Ernest", last: "Rutherford"} },

      { from: "Sábato, Ernesto", to: { full: "Ernesto Sábato", first: "Ernesto", last: "Sábato"} },
      { from: "Sade, Donatien de", to: { full: "Donatien de Sade", first: "Donatien", last: "de Sade"} },
      { from: "Sagan, Carl", to: { full: "Carl Sagan", first: "Carl", last: "Sagan"} },
      { from: "Saint-Exupéry, Antoine de", to: { full: "Antoine de Saint-Exupéry", first: "Antoine", last: "de Saint-Exupéry"} },
      { from: "Saint-Just, Louis de", to: { full: "Louis de Saint-Just", first: "Louis", last: "de Saint-Just"} },
      { from: "Salk, Jonas", to: { full: "Jonas Salk", first: "Jonas", last: "Salk"} },
      { from: "Salinger, J. D.", to: { full: "J D Salinger", first: "J D", last: "Salinger"} },
      { from: "Sanger, Margaret", to: { full: "Margaret Sanger", first: "Margaret", last: "Sanger"} },
      { from: "San Martín, José de", to: { full: "José de San Martín", first: "José", last: "de San Martín"} },
      { from: "Santayana, George", to: { full: "George Santayana", first: "George", last: "Santayana"} },
      { from: "Saroyan, William", to: { full: "William Saroyan", first: "William", last: "Saroyan"} },
      { from: "Sartre, Jean-Paul", to: { full: "Jean-Paul Sartre", first: "Jean-Paul", last: "Sartre"} },
      { from: "Sarven, Allen", to: { full: "Allen Sarven", first: "Allen", last: "Sarven"} },
      { from: "Satriani, Joe", to: { full: "Joe Satriani", first: "Joe", last: "Satriani"} },
      { from: "Sawyer, Diane", to: { full: "Diane Sawyer", first: "Diane", last: "Sawyer"} },
      { from: "Saul, John Ralston", to: { full: "John Ralston Saul", first: "John Ralston", last: "Saul"} },
      { from: "Schaar, John", to: { full: "John Schaar", first: "John", last: "Schaar"} },
      { from: "Schama, Simon", to: { full: "Simon Schama", first: "Simon", last: "Schama"} },
      { from: "Schiller, Friedrich von", to: { full: "Friedrich von Schiller", first: "Friedrich", last: "von Schiller"} },
      { from: "Schlüter, Poul", to: { full: "Poul Schlüter", first: "Poul", last: "Schlüter"} },
      { from: "Schneier, Bruce", to: { full: "Bruce Schneier", first: "Bruce", last: "Schneier"} },
      { from: "Schopenhauer, Arthur", to: { full: "Arthur Schopenhauer", first: "Arthur", last: "Schopenhauer"} },
      { from: "Schröder, Gerhard", to: { full: "Gerhard Schröder", first: "Gerhard", last: "Schröder"} },
      { from: "Schulberg, Budd", to: { full: "Budd Schulberg", first: "Budd", last: "Schulberg"} },
      { from: "Schultz, Charles M.", to: { full: "Charles M Schultz", first: "Charles M", last: "Schultz"} },
      { from: "Schweitzer, Albert", to: { full: "Albert Schweitzer", first: "Albert", last: "Schweitzer"} },
      { from: "Seabrook, Jeremy", to: { full: "Jeremy Seabrook", first: "Jeremy", last: "Seabrook"} },
      { from: "Seagal, Steven", to: { full: "Steven Seagal", first: "Steven", last: "Seagal"} },
      { from: "Sedaris, David", to: { full: "David Sedaris", first: "David", last: "Sedaris"} },
      { from: "Sedgwick, John", to: { full: "John Sedgwick", first: "John", last: "Sedgwick"} },
      { from: "Seigle, Lucy", to: { full: "Lucy Seigle", first: "Lucy", last: "Seigle"} },
      { from: "Seldes, George", to: { full: "George Seldes", first: "George", last: "Seldes"} },
      { from: "Sellers, Peter", to: { full: "Peter Sellers", first: "Peter", last: "Sellers"} },
      { from: "Serling, Rod", to: { full: "Rod Serling", first: "Rod", last: "Serling"} },
      { from: "Serrano, Miguel", to: { full: "Miguel Serrano", first: "Miguel", last: "Serrano"} },
      { from: "Seuss, Dr.", to: { full: "Dr. Seuss", title: "Dr", last: "Seuss"} },
      { from: "Shahak, Israel", to: { full: "Israel Shahak", first: "Israel", last: "Shahak"} },
      { from: "Shakespeare, William", to: { full: "William Shakespeare", first: "William", last: "Shakespeare"} },
      { from: "Shakur, Tupac", to: { full: "Tupac Shakur", first: "Tupac", last: "Shakur"} },
      { from: "Shankar, Ravi (Art of Living founder, not the sitar maestro)", to: { full: "Ravi Shankar", first: "Ravi", last: "Shankar", nick: "Art of Living founder, not the sitar maestro"} },
      { from: "Sharpton, Al", to: { full: "Al Sharpton", first: "Al", last: "Sharpton"} },
      { from: "Shaw, George Bernard", to: { full: "George Bernard Shaw", first: "George Bernard", last: "Shaw"} },
      { from: "Shawcross, Hartley", to: { full: "Hartley Shawcross", first: "Hartley", last: "Shawcross"} },
      { from: "Sheck, Barry", to: { full: "Barry Sheck", first: "Barry", last: "Sheck"} },
      { from: "Shedd, John", to: { full: "John Shedd", first: "John", last: "Shedd"} },
      { from: "Shelley, Mary Wollstonecraft", to: { full: "Mary Wollstonecraft Shelley", first: "Mary Wollstonecraft", last: "Shelley"} },
      { from: "Shelley, Percy Bysshe", to: { full: "Percy Bysshe Shelley", first: "Percy Bysshe", last: "Shelley"} },
      { from: "Sheridan, Richard Brinsley", to: { full: "Richard Brinsley Sheridan", first: "Richard Brinsley", last: "Sheridan"} },
      { from: "Sherman, William Tecumseh", to: { full: "William Tecumseh Sherman", first: "William Tecumseh", last: "Sherman"} },
      { from: "Shevardnadze, Eduard", to: { full: "Eduard Shevardnadze", first: "Eduard", last: "Shevardnadze"} },
      { from: "Shinoda, Mike", to: { full: "Mike Shinoda", first: "Mike", last: "Shinoda"} },
      { from: "Shirley, James", to: { full: "James Shirley", first: "James", last: "Shirley"} },
      { from: "Schopenhauer, Arthur", to: { full: "Arthur Schopenhauer", first: "Arthur", last: "Schopenhauer"} },
      { from: "Shrivastava, Mataji Nirmala", to: { full: "Mataji Nirmala Shrivastava", first: "Mataji Nirmala", last: "Shrivastava"} },
      { from: "Siegel, Jerry", to: { full: "Jerry Siegel", first: "Jerry", last: "Siegel"} },
      { from: "Simak, Clifford D.", to: { full: "Clifford D Simak", first: "Clifford D", last: "Simak"} },
      { from: "Simon, Paul", to: { full: "Paul Simon", first: "Paul", last: "Simon"} },
      { from: "Simpson, Jack", to: { full: "Jack Simpson", first: "Jack", last: "Simpson"} },
      { from: "Simpson, Jessica", to: { full: "Jessica Simpson", first: "Jessica", last: "Simpson"} },
      { from: "Sinclair, Upton", to: { full: "Upton Sinclair", first: "Upton", last: "Sinclair"} },
      { from: "Singer, Isaac Bashevis", to: { full: "Isaac Bashevis Singer", first: "Isaac Bashevis", last: "Singer"} },
      { from: "Sidhu, Navjot Singh", to: { full: "Navjot Singh Sidhu", first: "Navjot Singh", last: "Sidhu"} },
      { from: "Singh, Raman Pratap", to: { full: "Raman Pratap Singh", first: "Raman Pratap", last: "Singh"} },
      { from: "Singh, Sir Vijay", to: { full: "Sir Vijay Singh", title: "Sir", first: "Vijay", last: "Singh"} },
      { from: "Sitwell, Edith", to: { full: "Edith Sitwell", first: "Edith", last: "Sitwell"} },
      { from: "Slick, Grace", to: { full: "Grace Slick", first: "Grace", last: "Slick"} },
      { from: "Smirnoff, Yakov", to: { full: "Yakov Smirnoff", first: "Yakov", last: "Smirnoff"} },
      { from: "Smith, Adam", to: { full: "Adam Smith", first: "Adam", last: "Smith"} },
      { from: "Smith, Anna Nicole", to: { full: "Anna Nicole Smith", first: "Anna Nicole", last: "Smith"} },
      { from: "Smith, Elliott", to: { full: "Elliott Smith", first: "Elliott", last: "Smith"} },
      { from: "Smith, Gordon", to: { full: "Gordon Smith", first: "Gordon", last: "Smith"} },
      { from: "Smith, Joseph", to: { full: "Joseph Smith", first: "Joseph", last: "Smith"} },
      { from: "Smith, Kevin", to: { full: "Kevin Smith", first: "Kevin", last: "Smith"} },
      { from: "Smith, Logan Pearsall", to: { full: "Logan Pearsall Smith", first: "Logan Pearsall", last: "Smith"} },
      { from: "Smith, Margaret Chase", to: { full: "Margaret Chase Smith", first: "Margaret Chase", last: "Smith"} },
      { from: "Smith, Sydney", to: { full: "Sydney Smith", first: "Sydney", last: "Smith"} },
      { from: "Smollett, Tobias", to: { full: "Tobias Smollett", first: "Tobias", last: "Smollett"} },
      { from: "Smuts, Jan Christiaan", to: { full: "Jan Christiaan Smuts", first: "Jan Christiaan", last: "Smuts"} },
      { from: "Snepscheut, Jan L. A. van de", to: { full: "Jan L A van de Snepscheut", first: "Jan L A", last: "van de Snepscheut"} },
      { from: "Snow, Carrie", to: { full: "Carrie Snow", first: "Carrie", last: "Snow"} },
      { from: "Sobran, Joseph", to: { full: "Joseph Sobran", first: "Joseph", last: "Sobran"} },
      { from: "Solzhenitsyn, Alexander", to: { full: "Alexander Solzhenitsyn", first: "Alexander", last: "Solzhenitsyn"} },
      { from: "Sontag, Susan", to: { full: "Susan Sontag", first: "Susan", last: "Sontag"} },
      { from: "Sorkin, Aaron", to: { full: "Aaron Sorkin", first: "Aaron", last: "Sorkin"} },
      { from: "Soros, George", to: { full: "George Soros", first: "George", last: "Soros"} },
      { from: "Southerne, Thomas", to: { full: "Thomas Southerne", first: "Thomas", last: "Southerne"} },
      { from: "Sowell, Thomas", to: { full: "Thomas Sowell", first: "Thomas", last: "Sowell"} },
      { from: "Sparber, Max", to: { full: "Max Sparber", first: "Max", last: "Sparber"} },
      { from: "Spears, Britney", to: { full: "Britney Spears", first: "Britney", last: "Spears"} },
      { from: "Speijk, Jan van", to: { full: "Jan van Speijk", first: "Jan", last: "van Speijk"} },
      { from: "Spence, Gerry", to: { full: "Gerry Spence", first: "Gerry", last: "Spence"} },
      { from: "Spencer, Herbert", to: { full: "Herbert Spencer", first: "Herbert", last: "Spencer"} },
      { from: "Spielberg, Steven", to: { full: "Steven Spielberg", first: "Steven", last: "Spielberg"} },
      { from: "Spinoza, Baruch", to: { full: "Baruch Spinoza", first: "Baruch", last: "Spinoza"} },
      { from: "Spock, Benjamin", to: { full: "Benjamin Spock", first: "Benjamin", last: "Spock"} },
      { from: "Spolsky, Joel", to: { full: "Joel Spolsky", first: "Joel", last: "Spolsky"} },
      { from: "Springsteen, Bruce", to: { full: "Bruce Springsteen", first: "Bruce", last: "Springsteen"} },
      { from: "Spurgeon, Charles Haddon", to: { full: "Charles Haddon Spurgeon", first: "Charles Haddon", last: "Spurgeon"} },
      { from: "Stalin, Joseph", to: { full: "Joseph Stalin", first: "Joseph", last: "Stalin"} },
      { from: "Stallman, Richard M", to: { full: "Richard M Stallman", first: "Richard M", last: "Stallman"} },
      { from: "Stanley, Henry Morton", to: { full: "Henry Morton Stanley", first: "Henry Morton", last: "Stanley"} },
      { from: "Stanton, Elizabeth Cady", to: { full: "Elizabeth Cady Stanton", first: "Elizabeth Cady", last: "Stanton"} },
      { from: "Starr, Ringo", to: { full: "Ringo Starr", first: "Ringo", last: "Starr"} },
      { from: "Starrett, Vincent", to: { full: "Vincent Starrett", first: "Vincent", last: "Starrett"} },
      { from: "Stein, Gertrude", to: { full: "Gertrude Stein", first: "Gertrude", last: "Stein"} },
      { from: "Stein, Herbert", to: { full: "Herbert Stein", first: "Herbert", last: "Stein"} },
      { from: "Steinbeck, John", to: { full: "John Steinbeck", first: "John", last: "Steinbeck"} },
      { from: "Steinem, Gloria", to: { full: "Gloria Steinem", first: "Gloria", last: "Steinem"} },
      { from: "Stephenson, Neal", to: { full: "Neal Stephenson", first: "Neal", last: "Stephenson"} },
      { from: "Sterling, Bruce", to: { full: "Bruce Sterling", first: "Bruce", last: "Sterling"} },
      { from: "Stevens, Wallace", to: { full: "Wallace Stevens", first: "Wallace", last: "Stevens"} },
      { from: "Stevenson, Adlai", to: { full: "Adlai Stevenson", first: "Adlai", last: "Stevenson"} },
      { from: "Stevenson, Robert Louis", to: { full: "Robert Louis Stevenson", first: "Robert Louis", last: "Stevenson"} },
      { from: "Stewart, James (Jimmy)", to: { full: "James (Jimmy) Stewart", first: "James", nick: "Jimmy", last: "Stewart"} },
      { from: "Stewart, Jon", to: { full: "Jon Stewart", first: "Jon", last: "Stewart"} },
      { from: "Stein, Ben", to: { full: "Ben Stein", first: "Ben", last: "Stein"} },
      { from: "Stimson, Henry L.", to: { full: "Henry L Stimson", first: "Henry L", last: "Stimson"} },
      { from: "Stokowski, Leopold", to: { full: "Leopold Stokowski", first: "Leopold", last: "Stokowski"} },
      { from: "Stone, I. F.", to: { full: "I F Stone", first: "I F", last: "Stone"} },
      { from: "Stone, Lucy", to: { full: "Lucy Stone", first: "Lucy", last: "Stone"} },
      { from: "Stone, W. Clement", to: { full: "W Clement Stone", first: "W Clement", last: "Stone"} },
      { from: "Stoner Jr., James R.", to: { full: "James R Stoner Jr", first: "James R", last: "Stoner", suffix: "Jr"} },
      { from: "Stoppard, Tom", to: { full: "Tom Stoppard", first: "Tom", last: "Stoppard"} },
      { from: "Stout, Rex", to: { full: "Rex Stout", first: "Rex", last: "Stout"} },
      { from: "Stowe, Madeleine", to: { full: "Madeleine Stowe", first: "Madeleine", last: "Stowe"} },
      { from: "Stratford, Lord (Tony Banks)", to: { full: "Lord (Tony Banks) Stratford", title: "Lord", last: "Stratford", nick: "Tony Banks"} },
      { from: "Strauss, Richard", to: { full: "Richard Strauss", first: "Richard", last: "Strauss"} },
      { from: "Stravinsky, Igor", to: { full: "Igor Stravinsky", first: "Igor", last: "Stravinsky"} },
      { from: "Stroustrup, Bjarne", to: { full: "Bjarne Stroustrup", first: "Bjarne", last: "Stroustrup"} },
      { from: "Sturgeon, Theodore", to: { full: "Theodore Sturgeon", first: "Theodore", last: "Sturgeon"} },
      { from: "Sukuna, Ratu Sir Lala", to: { full: "Ratu Sir Lala Sukuna", title: "Ratu Sir", first: "Lala", last: "Sukuna"} },
      { from: "Sulla, Lucius Cornelius", to: { full: "Lucius Cornelius Sulla", first: "Lucius Cornelius", last: "Sulla"} },
      { from: "Šustauskas, Vytautas", to: { full: "Vytautas Šustauskas", first: "Vytautas", last: "Šustauskas"} },
      { from: "Sutherland, Kiefer", to: { full: "Kiefer Sutherland", first: "Kiefer", last: "Sutherland"} },
      { from: "Suvorov, Alexander Vasilyevich", to: { full: "Alexander Vasilyevich Suvorov", first: "Alexander Vasilyevich", last: "Suvorov"} },
      { from: "Suzuka, Shunryu", to: { full: "Shunryu Suzuka", first: "Shunryu", last: "Suzuka"} },
      { from: "Swedenborg, Emanuel", to: { full: "Emanuel Swedenborg", first: "Emanuel", last: "Swedenborg"} },
      { from: "Sweetnam, Skye", to: { full: "Skye Sweetnam", first: "Skye", last: "Sweetnam"} },
      { from: "Swift, Jonathan", to: { full: "Jonathan Swift", first: "Jonathan", last: "Swift"} },
      { from: "Swinburne, Charles Algernon", to: { full: "Charles Algernon Swinburne", first: "Charles Algernon", last: "Swinburne"} },
      { from: "Swindoll, Charles", to: { full: "Charles Swindoll", first: "Charles", last: "Swindoll"} },
      { from: "Syrus, Publilius", to: { full: "Publilius Syrus", first: "Publilius", last: "Syrus"} },
      { from: "Szilard, Leo", to: { full: "Leo Szilard", first: "Leo", last: "Szilard"} },

      { from: "Tagore, Rabindranath", to: { full: "Rabindranath Tagore", first: "Rabindranath", last: "Tagore"} },
      { from: "Taleb, Nassim Nicholas", to: { full: "Nassim Nicholas Taleb", first: "Nassim Nicholas", last: "Taleb"} },
      { from: "Tannen, Deborah", to: { full: "Deborah Tannen", first: "Deborah", last: "Tannen"} },
      { from: "Tate, Sharon", to: { full: "Sharon Tate", first: "Sharon", last: "Tate"} },
      { from: "Tavola, Kaliopate", to: { full: "Kaliopate Tavola", first: "Kaliopate", last: "Tavola"} },
      { from: "Tchaikovsky, Pyotr Ilyich", to: { full: "Pyotr Ilyich Tchaikovsky", first: "Pyotr Ilyich", last: "Tchaikovsky"} },
      { from: "Teilhard de Chardin, Pierre", to: { full: "Pierre Teilhard de Chardin", first: "Pierre", last: "Teilhard de Chardin"} },
      { skip: "Lord will be treated as a nick",
        from: "Tennyson, Alfred (Lord)", to: { full: "Alfred (Lord) Tennyson", first: "Alfred", last: "Tennyson", nick: "Lord"} },
      { from: "Tesla, Nikola", to: { full: "Nikola Tesla", first: "Nikola", last: "Tesla"} },
      { from: "Thackeray, William Makepeace", to: { full: "William Makepeace Thackeray", first: "William Makepeace", last: "Thackeray"} },
      { from: "Thant, U", to: { full: "U Thant", first: "U", last: "Thant"} },
      { from: "Thatcher, Margaret", to: { full: "Margaret Thatcher", first: "Margaret", last: "Thatcher"} },
      { from: "Theron, Charlize", to: { full: "Charlize Theron", first: "Charlize", last: "Theron"} },
      { from: "Thompson, Dorothy", to: { full: "Dorothy Thompson", first: "Dorothy", last: "Thompson"} },
      { from: "Thompson, Hunter S.", to: { full: "Hunter S Thompson", first: "Hunter S", last: "Thompson"} },
      { skip: "Haven't figured this one yet",
        from: "Thomson, William - a.k.a. Lord Kelvin", to: { full: "William - a.k.a. Lord Kelvin Thomson", first: "William - a.k.a. Lord Kelvin", last: "Thomson"} },
      { from: "Thoreau, Henry David", to: { full: "Henry David Thoreau", first: "Henry David", last: "Thoreau"} },
      { from: "Throttle, Ben", to: { full: "Ben Throttle", first: "Ben", last: "Throttle"} },
      { from: "Thurber, James", to: { full: "James Thurber", first: "James", last: "Thurber"} },
      { from: "Tito, Josip Broz", to: { full: "Josip Broz Tito", first: "Josip Broz", last: "Tito"} },
      { from: "Tocqueville, Alexis de", to: { full: "Alexis de Tocqueville", first: "Alexis", last: "de Tocqueville"} },
      { from: "Todorov, Tzvetan", to: { full: "Tzvetan Todorov", first: "Tzvetan", last: "Todorov"} },
      { from: "Tohei, Koichi", to: { full: "Koichi Tohei", first: "Koichi", last: "Tohei"} },
      { from: "Tolkien, J. R. R.", to: { full: "J R R Tolkien", first: "J R R", last: "Tolkien"} },
      { from: "Tolstoy, Leo", to: { full: "Leo Tolstoy", first: "Leo", last: "Tolstoy"} },
      { from: "Tomlin, Lily", to: { full: "Lily Tomlin", first: "Lily", last: "Tomlin"} },
      { from: "Tora, Apisai", to: { full: "Apisai Tora", first: "Apisai", last: "Tora"} },
      { from: "Torre, Joe", to: { full: "Joe Torre", first: "Joe", last: "Torre"} },
      { from: "Torvalds, Linus", to: { full: "Linus Torvalds", first: "Linus", last: "Torvalds"} },
      { from: "Toynbee, Arnold", to: { full: "Arnold Toynbee", first: "Arnold", last: "Toynbee"} },
      { from: "Toynbee, Arnold Joseph", to: { full: "Arnold Joseph Toynbee", first: "Arnold Joseph", last: "Toynbee"} },
      { from: "Traficant, James A., Jr.", to: { full: "James A Traficant Jr", first: "James A", last: "Traficant", suffix: "Jr"} },
      { from: "Travaglia, Simon", to: { full: "Simon Travaglia", first: "Simon", last: "Travaglia"} },
      { from: "Travers, P. L.", to: { full: "P L Travers", first: "P L", last: "Travers"} },
      { from: "Trollope, Anthony", to: { full: "Anthony Trollope", first: "Anthony", last: "Trollope"} },
      { from: "Trotsky, Leon", to: { full: "Leon Trotsky", first: "Leon", last: "Trotsky"} },
      { from: "Trudeau, Pierre", to: { full: "Pierre Trudeau", first: "Pierre", last: "Trudeau"} },
      { from: "Truman, Harry S.", to: { full: "Harry S Truman", first: "Harry S", last: "Truman"} },
      { from: "Trump, Donald", to: { full: "Donald Trump", first: "Donald", last: "Trump"} },
      { from: "Truth, Sojourner", to: { full: "Sojourner Truth", first: "Sojourner", last: "Truth"} },
      { from: "Tucker, Gideon", to: { full: "Gideon Tucker", first: "Gideon", last: "Tucker"} },
      { from: "Tudor, John", to: { full: "John Tudor", first: "John", last: "Tudor"} },
      { from: "Tugia, Manasa", to: { full: "Manasa Tugia", first: "Manasa", last: "Tugia"} },
      { from: "Tuibua, Esala", to: { full: "Esala Tuibua", first: "Esala", last: "Tuibua"} },
      { from: "Turner, Ted", to: { full: "Ted Turner", first: "Ted", last: "Turner"} },
      { from: "Turtledove, Harry", to: { full: "Harry Turtledove", first: "Harry", last: "Turtledove"} },
      { from: "Tutu, Desmond", to: { full: "Desmond Tutu", first: "Desmond", last: "Tutu"} },
      { from: "Twain, Mark", to: { full: "Mark Twain", first: "Mark", last: "Twain"} },
      { from: "Tyger, Frank", to: { full: "Frank Tyger", first: "Frank", last: "Tyger"} },
      { from: "Tynan, Kenneth", to: { full: "Kenneth Tynan", first: "Kenneth", last: "Tynan"} },
      { from: "Tzara, Tristan", to: { full: "Tristan Tzara", first: "Tristan", last: "Tzara"} },

      { from: "Ueshiba, Morihei", to: { full: "Morihei Ueshiba", first: "Morihei", last: "Ueshiba"} },
      { from: "Unamuno, Miguel de", to: { full: "Miguel de Unamuno", first: "Miguel", last: "de Unamuno"} },
      { from: "Updike, John", to: { full: "John Updike", first: "John", last: "Updike"} },
      { from: "Ustinov, Peter", to: { full: "Peter Ustinov", first: "Peter", last: "Ustinov"} },

      { from: "Valenti, Jack", to: { full: "Jack Valenti", first: "Jack", last: "Valenti"} },
      { from: "Valéry, Paul", to: { full: "Paul Valéry", first: "Paul", last: "Valéry"} },
      { from: "Vance, Jack", to: { full: "Jack Vance", first: "Jack", last: "Vance"} },
      { from: "Van Gogh, Vincent", to: { full: "Vincent Van Gogh", first: "Vincent", last: "Van Gogh"} },
      { from: "Varese, Edgard", to: { full: "Edgard Varese", first: "Edgard", last: "Varese"} },
      { from: "Ventura, Jesse", to: { full: "Jesse Ventura", first: "Jesse", last: "Ventura"} },
      { from: "Venturi, Ken", to: { full: "Ken Venturi", first: "Ken", last: "Venturi"} },
      { from: "Vidal, Gore", to: { full: "Gore Vidal", first: "Gore", last: "Vidal"} },
      { from: "Vivekananda, Swami", to: { full: "Swami Vivekananda", first: "Swami", last: "Vivekananda"} },
      { from: "Vixie, Paul", to: { full: "Paul Vixie", first: "Paul", last: "Vixie"} },
      { from: "Von Karman, Theodore", to: { full: "Theodore Von Karman", first: "Theodore", last: "Von Karman"} },
      { from: "Vonnegut, Kurt", to: { full: "Kurt Vonnegut", first: "Kurt", last: "Vonnegut"} },
      { from: "Vosanibola, Josefa", to: { full: "Josefa Vosanibola", first: "Josefa", last: "Vosanibola"} },
      { from: "Vaughan, Norman D.", to: { full: "Norman D Vaughan", first: "Norman D", last: "Vaughan"} },

      { from: "Wagner, Jane", to: { full: "Jane Wagner", first: "Jane", last: "Wagner"} },
      { from: "Wainwright, Rufus", to: { full: "Rufus Wainwright", first: "Rufus", last: "Wainwright"} },
      { from: "Waitley, Denis", to: { full: "Denis Waitley", first: "Denis", last: "Waitley"} },
      { from: "Waits, Tom", to: { full: "Tom Waits", first: "Tom", last: "Waits"} },
      { from: "Walberg, Tim", to: { full: "Tim Walberg", first: "Tim", last: "Walberg"} },
      { from: "Wales, Jimbo", to: { full: "Jimbo Wales", first: "Jimbo", last: "Wales"} },
      { from: "Walesa, Lech", to: { full: "Lech Walesa", first: "Lech", last: "Walesa"} },
      { from: "Walken, Christopher", to: { full: "Christopher Walken", first: "Christopher", last: "Walken"} },
      { from: "Walker, Murray", to: { full: "Murray Walker", first: "Murray", last: "Walker"} },
      { from: "Wall, Larry", to: { full: "Larry Wall", first: "Larry", last: "Wall"} },
      { from: "Wallace, Alan", to: { full: "Alan Wallace", first: "Alan", last: "Wallace"} },
      { from: "Wallace, David Foster", to: { full: "David Foster Wallace", first: "David Foster", last: "Wallace"} },
      { from: "Waqabaca, Josaia", to: { full: "Josaia Waqabaca", first: "Josaia", last: "Waqabaca"} },
      { from: "Waradi, Taito", to: { full: "Taito Waradi", first: "Taito", last: "Waradi"} },
      { from: "Warhol, Andy", to: { full: "Andy Warhol", first: "Andy", last: "Warhol"} },
      { from: "Warner, Harold", to: { full: "Harold Warner", first: "Harold", last: "Warner"} },
      { from: "Warren, Earl", to: { full: "Earl Warren", first: "Earl", last: "Warren"} },
      { from: "Warren, Rick", to: { full: "Rick Warren", first: "Rick", last: "Warren"} },
      { from: "Warren, Robert Penn", to: { full: "Robert Penn Warren", first: "Robert Penn", last: "Warren"} },
      { from: "Washington, Booker T.", to: { full: "Booker T Washington", first: "Booker T", last: "Washington"} },
      { from: "Washington, George", to: { full: "George Washington", first: "George", last: "Washington"} },
      { from: "Washington, Martha", to: { full: "Martha Washington", first: "Martha", last: "Washington"} },
      { from: "Watson, Thomas J.", to: { full: "Thomas J Watson", first: "Thomas J", last: "Watson"} },
      { from: "Watterson, Bill", to: { full: "Bill Watterson", first: "Bill", last: "Watterson"} },
      { from: "Watts, Alan", to: { full: "Alan Watts", first: "Alan", last: "Watts"} },
      { from: "Waugh, Evelyn", to: { full: "Evelyn Waugh", first: "Evelyn", last: "Waugh"} },
      { from: "Weber, David", to: { full: "David Weber", first: "David", last: "Weber"} },
      { from: "Webster, Daniel", to: { full: "Daniel Webster", first: "Daniel", last: "Webster"} },
      { from: "Webster, Noah", to: { full: "Noah Webster", first: "Noah", last: "Webster"} },
      { from: "Weil, Simone", to: { full: "Simone Weil", first: "Simone", last: "Weil"} },
      { from: "Weinberger, David", to: { full: "David Weinberger", first: "David", last: "Weinberger"} },
      { from: "Welch, Jack", to: { full: "Jack Welch", first: "Jack", last: "Welch"} },
      { from: "Welles, Orson", to: { full: "Orson Welles", first: "Orson", last: "Welles"} },
      { from: "Wellesley, Arthur", to: { full: "Arthur Wellesley", first: "Arthur", last: "Wellesley"} },
      { from: "Wells, H. G. (Herbert George)", to: { full: "H G (Herbert George) Wells", first: "H G", nick: "Herbert George", last: "Wells"} },
      { from: "Wellstone, Paul", to: { full: "Paul Wellstone", first: "Paul", last: "Wellstone"} },
      { from: "Wesley, John", to: { full: "John Wesley", first: "John", last: "Wesley"} },
      { from: "West, Mae", to: { full: "Mae West", first: "Mae", last: "West"} },
      { from: "West, Morris", to: { full: "Morris West", first: "Morris", last: "West"} },
      { from: "Whedon, Joss", to: { full: "Joss Whedon", first: "Joss", last: "Whedon"} },
      { from: "White, Andrew Dickson", to: { full: "Andrew Dickson White", first: "Andrew Dickson", last: "White"} },
      { from: "White, E. B. (Elwyn Brooks)", to: { full: "E B (Elwyn Brooks) White", first: "E B", nick: "Elwyn Brooks", last: "White"} },
      { from: "White, Reggie", to: { full: "Reggie White", first: "Reggie", last: "White"} },
      { from: "White, T. H. (Terence Hanbury)", to: { full: "T H White", first: "T H", nick: "Terence Hanbury", last: "White"} },
      { from: "Whitehead, Alfred North", to: { full: "Alfred North Whitehead", first: "Alfred North", last: "Whitehead"} },
      { from: "Whitman, Walt", to: { full: "Walt Whitman", first: "Walt", last: "Whitman"} },
      { from: "Whittier, John Greenleaf", to: { full: "John Greenleaf Whittier", first: "John Greenleaf", last: "Whittier"} },
      { from: "Wiesel, Elie", to: { full: "Elie Wiesel", first: "Elie", last: "Wiesel"} },
      { from: "Wilber, Ken", to: { full: "Ken Wilber", first: "Ken", last: "Wilber"} },
      { from: "Wilberforce, William", to: { full: "William Wilberforce", first: "William", last: "Wilberforce"} },
      { from: "Wilcox, Ella Wheeler", to: { full: "Ella Wheeler Wilcox", first: "Ella Wheeler", last: "Wilcox"} },
      { from: "Wilde, Oscar", to: { full: "Oscar Wilde", first: "Oscar", last: "Wilde"} },
      { from: "Wilder, Thornton", to: { full: "Thornton Wilder", first: "Thornton", last: "Wilder"} },
      { from: "Wilkes, Maurice", to: { full: "Maurice Wilkes", first: "Maurice", last: "Wilkes"} },
      { skip: "Haven't figured this one yet",
        from: "William I, King of England", to: { full: "King of England William I", first: "King of England", last: "William I"} },
      { from: "Williams, Robin", to: { full: "Robin Williams", first: "Robin", last: "Williams"} },
      { from: "Williams, Roger", to: { full: "Roger Williams", first: "Roger", last: "Williams"} },
      { from: "Williams, Ted", to: { full: "Ted Williams", first: "Ted", last: "Williams"} },
      { from: "Williams, Tennessee", to: { full: "Tennessee Williams", first: "Tennessee", last: "Williams"} },
      { from: "Williamson, Henry", to: { full: "Henry Williamson", first: "Henry", last: "Williamson"} },
      { from: "Wilson, Robert Anton", to: { full: "Robert Anton Wilson", first: "Robert Anton", last: "Wilson"} },
      { from: "Wilson, Brian", to: { full: "Brian Wilson", first: "Brian", last: "Wilson"} },
      { from: "Wilson, Colin", to: { full: "Colin Wilson", first: "Colin", last: "Wilson"} },
      { from: "Wilson, Flip", to: { full: "Flip Wilson", first: "Flip", last: "Wilson"} },
      { from: "Wilson, Ron", to: { full: "Ron Wilson", first: "Ron", last: "Wilson"} },
      { from: "Wilson, (Thomas) Woodrow", to: { full: "Woodrow Wilson", first: "Woodrow", nick: "Thomas", last: "Wilson"} },
      { from: "Winfrey, Oprah", to: { full: "Oprah Winfrey", first: "Oprah", last: "Winfrey"} },
      { from: "Winner, Michael", to: { full: "Michael Winner", first: "Michael", last: "Winner"} },
      { from: "Winter, William", to: { full: "William Winter", first: "William", last: "Winter"} },
      { from: "Winchell, April", to: { full: "April Winchell", first: "April", last: "Winchell"} },
      { from: "Winchell, Walter", to: { full: "Walter Winchell", first: "Walter", last: "Winchell"} },
      { from: "Wittgenstein, Ludwig", to: { full: "Ludwig Wittgenstein", first: "Ludwig", last: "Wittgenstein"} },
      { from: "Wodehouse, P. G.", to: { full: "P G Wodehouse", first: "P G", last: "Wodehouse"} },
      { from: "Wolff, Christian", to: { full: "Christian Wolff", first: "Christian", last: "Wolff"} },
      { from: "Wolfowitz, Paul", to: { full: "Paul Wolfowitz", first: "Paul", last: "Wolfowitz"} },
      { from: "Woodward, Bob", to: { full: "Bob Woodward", first: "Bob", last: "Woodward"} },
      { from: "Woolf, Virginia", to: { full: "Virginia Woolf", first: "Virginia", last: "Woolf"} },
      { from: "Wordsworth, William", to: { full: "William Wordsworth", first: "William", last: "Wordsworth"} },
      { from: "Wozniak, Steve", to: { full: "Steve Wozniak", first: "Steve", last: "Wozniak"} },
      { from: "Wright, Frank Lloyd", to: { full: "Frank Lloyd Wright", first: "Frank Lloyd", last: "Wright"} },
      { from: "Wright, Steven", to: { full: "Steven Wright", first: "Steven", last: "Wright"} },
      { from: "Wright, Wilbur", to: { full: "Wilbur Wright", first: "Wilbur", last: "Wright"} },
      { from: "Wyden, Ron", to: { full: "Ron Wyden", first: "Ron", last: "Wyden"} },
      { from: "Wylie, Philip", to: { full: "Philip Wylie", first: "Philip", last: "Wylie"} },
      { from: "Wilson, Eugene S.", to: { full: "Eugene S Wilson", first: "Eugene S", last: "Wilson"} },

      { from: "Yamamoto, Isoroku", to: { full: "Isoroku Yamamoto", first: "Isoroku", last: "Yamamoto"} },
      { from: "Yashinsky, Edward", to: { full: "Edward Yashinsky", first: "Edward", last: "Yashinsky"} },
      { from: "Yeats, William Butler", to: { full: "William Butler Yeats", first: "William Butler", last: "Yeats"} },
      { from: "Yeltsin, Boris", to: { full: "Boris Yeltsin", first: "Boris", last: "Yeltsin"} },
      { from: "Yockey, Francis Parker", to: { full: "Francis Parker Yockey", first: "Francis Parker", last: "Yockey"} },
      { from: "Yorke, Thom", to: { full: "Thom Yorke", first: "Thom", last: "Yorke"} },
      { from: "Yoshida, Takeo", to: { full: "Takeo Yoshida", first: "Takeo", last: "Yoshida"} },
      { from: "Young, Cy", to: { full: "Cy Young", first: "Cy", last: "Young"} },
      { from: "Young, Edward", to: { full: "Edward Young", first: "Edward", last: "Young"} },
      { from: "Young, Neil", to: { full: "Neil Young", first: "Neil", last: "Young"} },
      { from: "Young, Tyler Shell", to: { full: "Tyler Shell Young", first: "Tyler Shell", last: "Young"} },
      { from: "Youngman, Henny", to: { full: "Henny Youngman", first: "Henny", last: "Youngman"} },
      { from: "Yourcenar, Marguerite", to: { full: "Marguerite Yourcenar", first: "Marguerite", last: "Yourcenar"} },
      { from: "Yutang, Lin", to: { full: "Lin Yutang", first: "Lin", last: "Yutang"} },

      { from: "Zacharek, Stephanie", to: { full: "Stephanie Zacharek", first: "Stephanie", last: "Zacharek"} },
      { from: "Zappa, Frank", to: { full: "Frank Zappa", first: "Frank", last: "Zappa"} },
      { from: "Zawinski, Jamie", to: { full: "Jamie Zawinski", first: "Jamie", last: "Zawinski"} },
      { from: "Zeldin, Theodore", to: { full: "Theodore Zeldin", first: "Theodore", last: "Zeldin"} },
      { skip: "Haven't figured this one yet",
        from: "Zhuangzi (Zhuang Zi; Zhuang Zhou; Chuang Tzu; Chuang Tse)", to: {} },
      { from: "Ziglar, Zig", to: { full: "Zig Ziglar", first: "Zig", last: "Ziglar"} },
      { from: "Zimmermann, Philip", to: { full: "Philip Zimmermann", first: "Philip", last: "Zimmermann"} },
      { from: "Zinck, Kenneth", to: { full: "Kenneth Zinck", first: "Kenneth", last: "Zinck"} },
      { from: "Zinn, Howard", to: { full: "Howard Zinn", first: "Howard", last: "Zinn"} },
      { from: "Zola, Emile", to: { full: "Emile Zola", first: "Emile", last: "Zola"} }
      ].each do |name|
        it "parses #{name[:from]}" do
          skip name[:skip] if name.has_key?(:skip)
          parsed = Nomener.parse(name[:from])
          parse_hash = parsed.to_h
          parse_hash.each_pair do |k,v|
            unless (v.nil? || v.empty?)
              expect(v).to eq(name[:to][k]), "got from #{k} - #{v} wanted #{name[:to][k]} #{parsed.inspect}"
            end
          end
          name[:to].each_pair do |k,v|
            unless (k == :full)
              expect(v).to eq(parse_hash[k]), "got from #{k} - #{v} wanted #{parse_hash[k]} #{parse_hash}"
            end
          end

        end
      end
    end
  end
